@@ -2,7 +2,7 @@
 //
 // The JACK Driver for the Core Audio Engine component of Rivendell
 //
-//   (C) Copyright 2002-2015 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,6 +25,8 @@
 #include <qsignalmapper.h>
 
 #include <rd.h>
+#include <rdapplication.h>
+#include <rddatedecode.h>
 #include <rddb.h>
 #include <rdescape_string.h>
 #include <rdringbuffer.h>
@@ -41,8 +43,6 @@ jack_client_t *jack_client;
 RDMeterAverage *jack_input_meter[RD_MAX_PORTS][2];
 RDMeterAverage *jack_output_meter[RD_MAX_PORTS][2];
 RDMeterAverage *jack_stream_output_meter[RD_MAX_STREAMS][2];
-//volatile jack_default_audio_sample_t jack_input_meter[RD_MAX_PORTS][2];
-//volatile jack_default_audio_sample_t jack_output_meter[RD_MAX_PORTS][2];
 volatile jack_default_audio_sample_t 
   jack_input_volume[RD_MAX_PORTS];
 volatile jack_default_audio_sample_t 
@@ -87,10 +87,14 @@ int JackProcess(jack_nframes_t nframes, void *arg)
   //
   for(int i=0;i<RD_MAX_PORTS;i++) {
     for(int j=0;j<2;j++) {
-      jack_input_buffer[i][j]=(jack_default_audio_sample_t *)
-	jack_port_get_buffer(jack_input_port[i][j],nframes);
-      jack_output_buffer[i][j]=(jack_default_audio_sample_t *)
-	jack_port_get_buffer(jack_output_port[i][j],nframes);
+      if(jack_input_port[i][j]!=NULL) {
+	jack_input_buffer[i][j]=(jack_default_audio_sample_t *)
+	  jack_port_get_buffer(jack_input_port[i][j],nframes);
+      }
+      if(jack_output_port[i][j]!=NULL) {
+	jack_output_buffer[i][j]=(jack_default_audio_sample_t *)
+	  jack_port_get_buffer(jack_output_port[i][j],nframes);
+      }
     }
   }
 
@@ -99,8 +103,10 @@ int JackProcess(jack_nframes_t nframes, void *arg)
   //
   for(int i=0;i<RD_MAX_PORTS;i++) {
     for(int j=0;j<2;j++) {
-      for(unsigned k=0;k<nframes;k++) {
-	jack_output_buffer[i][j][k]=0.0;
+      if(jack_output_port[i][j]!=NULL) {
+	for(unsigned k=0;k<nframes;k++) {
+	  jack_output_buffer[i][j][k]=0.0;
+	}
       }
     } 
   }
@@ -112,9 +118,11 @@ int JackProcess(jack_nframes_t nframes, void *arg)
     for(int j=0;j<RD_MAX_PORTS;j++) {
       if(jack_passthrough_volume[i][j]>0.0) {
 	for(int k=0;k<2;k++) {
-	  for(unsigned l=0;l<nframes;l++) {
-	    jack_output_buffer[j][k][l]+=
-	      jack_input_buffer[i][k][l]*jack_passthrough_volume[i][j];
+	  if((jack_output_port[j][k]!=NULL)&&(jack_input_port[i][k]!=NULL)) {
+	    for(unsigned l=0;l<nframes;l++) {
+	      jack_output_buffer[j][k][l]+=
+		jack_input_buffer[i][k][l]*jack_passthrough_volume[i][j];
+	    }
 	  }
 	}
       }
@@ -125,68 +133,70 @@ int JackProcess(jack_nframes_t nframes, void *arg)
   // Process Input Streams
   //
   for(int i=0;i<RD_MAX_PORTS;i++) {
-    if(jack_recording[i]) {
-      switch(jack_input_channels[i]) {
-      case 1: // mono
-	for(unsigned j=0;j<nframes;j++) {
-	  switch(jack_input_mode[jack_card_process][i]) {
-	  case 3: // R only
-	    jack_callback_buffer[j]=jack_input_volume[i]*
-	      jack_input_buffer[i][1][j];
-	    break;
-	  case 2: // L only
-	    jack_callback_buffer[j]=jack_input_volume[i]*
-	      jack_input_buffer[i][0][j];
-	    break;
-	  case 1: // swap, sum R+L
-	  case 0: // normal, sum L+R
-	  default:
-	    jack_callback_buffer[j]=jack_input_volume[i]*
-	      (jack_input_buffer[i][0][j]+jack_input_buffer[i][1][j]);
-	    break;
-	  }
-	} // for nframes
-	n=jack_record_ring[i]->
-	  write((char *)jack_callback_buffer,
-		nframes*sizeof(jack_default_audio_sample_t))/
-	  sizeof(jack_default_audio_sample_t);
-	break;
+    if(jack_input_port[i][0]!=NULL) {
+      if(jack_recording[i]) {
+	switch(jack_input_channels[i]) {
+	case 1: // mono
+	  for(unsigned j=0;j<nframes;j++) {
+	    switch(jack_input_mode[jack_card_process][i]) {
+	    case 3: // R only
+	      jack_callback_buffer[j]=jack_input_volume[i]*
+		jack_input_buffer[i][1][j];
+	      break;
+	    case 2: // L only
+	      jack_callback_buffer[j]=jack_input_volume[i]*
+		jack_input_buffer[i][0][j];
+	      break;
+	    case 1: // swap, sum R+L
+	    case 0: // normal, sum L+R
+	    default:
+	      jack_callback_buffer[j]=jack_input_volume[i]*
+		(jack_input_buffer[i][0][j]+jack_input_buffer[i][1][j]);
+	      break;
+	    }
+	  } // for nframes
+	  n=jack_record_ring[i]->
+	    write((char *)jack_callback_buffer,
+		  nframes*sizeof(jack_default_audio_sample_t))/
+	    sizeof(jack_default_audio_sample_t);
+	  break;
 
-      case 2: // stereo
-	for(unsigned j=0;j<nframes;j++) {
-	  switch(jack_input_mode[jack_card_process][i]) {
-	  case 3: // R only
-	    memset(&jack_callback_buffer[2*j],0,
-		   sizeof(jack_input_buffer[i][0][j]));
-	    jack_callback_buffer[2*j+1]=jack_input_volume[i]*
-	      jack_input_buffer[i][1][j];
-	    break;
-	  case 2: // L only
-	    jack_callback_buffer[2*j]=jack_input_volume[i]*
-	      jack_input_buffer[i][0][j];
-	    memset(&jack_callback_buffer[2*j+1],0,
-		   sizeof(jack_input_buffer[i][1][j]));
-	    break;
-	  case 1: // swap
-	    jack_callback_buffer[2*j]=jack_input_volume[i]*
-	      jack_input_buffer[i][1][j];
-	    jack_callback_buffer[2*j+1]=jack_input_volume[i]*
-	      jack_input_buffer[i][0][j];
-	    break;
-	  case 0: // normal
-	  default:
-	    jack_callback_buffer[2*j]=jack_input_volume[i]*
-	      jack_input_buffer[i][0][j];
-	    jack_callback_buffer[2*j+1]=jack_input_volume[i]*
-	      jack_input_buffer[i][1][j];
-	    break;
-	  }
-	} // for nframes
-	n=jack_record_ring[i]->
-	  write((char *)jack_callback_buffer,
-		2*nframes*sizeof(jack_default_audio_sample_t))/
-	  (2*sizeof(jack_default_audio_sample_t));
-	break;
+	case 2: // stereo
+	  for(unsigned j=0;j<nframes;j++) {
+	    switch(jack_input_mode[jack_card_process][i]) {
+	    case 3: // R only
+	      memset(&jack_callback_buffer[2*j],0,
+		     sizeof(jack_input_buffer[i][0][j]));
+	      jack_callback_buffer[2*j+1]=jack_input_volume[i]*
+		jack_input_buffer[i][1][j];
+	      break;
+	    case 2: // L only
+	      jack_callback_buffer[2*j]=jack_input_volume[i]*
+		jack_input_buffer[i][0][j];
+	      memset(&jack_callback_buffer[2*j+1],0,
+		     sizeof(jack_input_buffer[i][1][j]));
+	      break;
+	    case 1: // swap
+	      jack_callback_buffer[2*j]=jack_input_volume[i]*
+		jack_input_buffer[i][1][j];
+	      jack_callback_buffer[2*j+1]=jack_input_volume[i]*
+		jack_input_buffer[i][0][j];
+	      break;
+	    case 0: // normal
+	    default:
+	      jack_callback_buffer[2*j]=jack_input_volume[i]*
+		jack_input_buffer[i][0][j];
+	      jack_callback_buffer[2*j+1]=jack_input_volume[i]*
+		jack_input_buffer[i][1][j];
+	      break;
+	    }
+	  } // for nframes
+	  n=jack_record_ring[i]->
+	    write((char *)jack_callback_buffer,
+		  2*nframes*sizeof(jack_default_audio_sample_t))/
+	    (2*sizeof(jack_default_audio_sample_t));
+	  break;
+	}
       }
     }
   }
@@ -229,37 +239,39 @@ int JackProcess(jack_nframes_t nframes, void *arg)
 	break;
       }
       for(int j=0;j<RD_MAX_PORTS;j++) {
-	if(jack_output_volume[j][i]>0.0) {
-	  switch(jack_output_channels[i]) {
-	  case 1:
-	    for(unsigned k=0;k<n;k++) {
-	      jack_output_buffer[j][0][k]=
-		jack_output_buffer[j][0][k]+jack_output_volume[j][i]*
-		jack_callback_buffer[k];
-	      jack_output_buffer[j][1][k]=
-		jack_output_buffer[j][1][k]+jack_output_volume[j][i]*
-		jack_callback_buffer[k];
-	    }
-	    if(n!=nframes && jack_eof[i]) {
-	      jack_stopping[i]=true;
-	      jack_playing[i]=false;
-	    }
-	    break;
+	if(jack_output_port[j][0]!=NULL) {
+	  if(jack_output_volume[j][i]>0.0) {
+	    switch(jack_output_channels[i]) {
+	    case 1:
+	      for(unsigned k=0;k<n;k++) {
+		jack_output_buffer[j][0][k]=
+		  jack_output_buffer[j][0][k]+jack_output_volume[j][i]*
+		  jack_callback_buffer[k];
+		jack_output_buffer[j][1][k]=
+		  jack_output_buffer[j][1][k]+jack_output_volume[j][i]*
+		  jack_callback_buffer[k];
+	      }
+	      if(n!=nframes && jack_eof[i]) {
+		jack_stopping[i]=true;
+		jack_playing[i]=false;
+	      }
+	      break;
 
-	  case 2:
-	    for(unsigned k=0;k<n;k++) {
-	      jack_output_buffer[j][0][k]=
-		jack_output_buffer[j][0][k]+jack_output_volume[j][i]*
-		jack_callback_buffer[k*2];
-	      jack_output_buffer[j][1][k]=
-		jack_output_buffer[j][1][k]+jack_output_volume[j][i]*
-		jack_callback_buffer[k*2+1];
+	    case 2:
+	      for(unsigned k=0;k<n;k++) {
+		jack_output_buffer[j][0][k]=
+		  jack_output_buffer[j][0][k]+jack_output_volume[j][i]*
+		  jack_callback_buffer[k*2];
+		jack_output_buffer[j][1][k]=
+		  jack_output_buffer[j][1][k]+jack_output_volume[j][i]*
+		  jack_callback_buffer[k*2+1];
+	      }
+	      if(n!=nframes && jack_eof[i]) {
+		jack_stopping[i]=true;
+		jack_playing[i]=false;
+	      }
+	      break;
 	    }
-	    if(n!=nframes && jack_eof[i]) {
-	      jack_stopping[i]=true;
-	      jack_playing[i]=false;
-	    }
-	    break;
 	  }
 	}
       }
@@ -272,47 +284,49 @@ int JackProcess(jack_nframes_t nframes, void *arg)
   // Process Meters
   //
   for(int i=0;i<RD_MAX_PORTS;i++) {
-    // input meters (taking input mode into account)
-    in_meter[0]=0.0;
-    in_meter[1]=0.0;
-    for(unsigned k=0;k<nframes;k++) {
-      switch(jack_input_mode[jack_card_process][i]) {
-      case 3: // R only
-	if(jack_input_buffer[i][1][k]>in_meter[1]) 
-	  in_meter[1]=jack_input_buffer[i][1][k];
-	break;
-      case 2: // L only
-	if(jack_input_buffer[i][0][k]>in_meter[0]) 
-	  in_meter[0]=jack_input_buffer[i][0][k];
-	break;
-      case 1: // swap
-	if(jack_input_buffer[i][0][k]>in_meter[1]) 
-	  in_meter[1]=jack_input_buffer[i][0][k];
-	if(jack_input_buffer[i][1][k]>in_meter[0]) 
-	  in_meter[0]=jack_input_buffer[i][1][k];
-	break;
-      case 0: // normal
-      default:
-	if(jack_input_buffer[i][0][k]>in_meter[0]) 
-	  in_meter[0]=jack_input_buffer[i][0][k];
-	if(jack_input_buffer[i][1][k]>in_meter[1]) 
-	  in_meter[1]=jack_input_buffer[i][1][k];
-	break;
-      }
-    } // for nframes
-    jack_input_meter[i][0]->addValue(in_meter[0]);
-    jack_input_meter[i][1]->addValue(in_meter[1]);
-
-    // output meters
-    for(int j=0;j<2;j++) {
-      out_meter[j]=0.0;
+    if(jack_input_port[i][0]!=NULL) {
+      // input meters (taking input mode into account)
+      in_meter[0]=0.0;
+      in_meter[1]=0.0;
       for(unsigned k=0;k<nframes;k++) {
-	if(jack_output_buffer[i][j][k]>out_meter[j]) 
-	  out_meter[j]=jack_output_buffer[i][j][k];
+	switch(jack_input_mode[jack_card_process][i]) {
+	case 3: // R only
+	  if(jack_input_buffer[i][1][k]>in_meter[1]) 
+	    in_meter[1]=jack_input_buffer[i][1][k];
+	  break;
+	case 2: // L only
+	  if(jack_input_buffer[i][0][k]>in_meter[0]) 
+	    in_meter[0]=jack_input_buffer[i][0][k];
+	  break;
+	case 1: // swap
+	  if(jack_input_buffer[i][0][k]>in_meter[1]) 
+	    in_meter[1]=jack_input_buffer[i][0][k];
+	  if(jack_input_buffer[i][1][k]>in_meter[0]) 
+	    in_meter[0]=jack_input_buffer[i][1][k];
+	  break;
+	case 0: // normal
+	default:
+	  if(jack_input_buffer[i][0][k]>in_meter[0]) 
+	    in_meter[0]=jack_input_buffer[i][0][k];
+	  if(jack_input_buffer[i][1][k]>in_meter[1]) 
+	    in_meter[1]=jack_input_buffer[i][1][k];
+	  break;
+	}
+      } // for nframes
+      jack_input_meter[i][0]->addValue(in_meter[0]);
+      jack_input_meter[i][1]->addValue(in_meter[1]);
+    }
+    if(jack_output_port[i][0]!=NULL) {
+      // output meters
+      for(int j=0;j<2;j++) {
+	out_meter[j]=0.0;
+	for(unsigned k=0;k<nframes;k++) {
+	  if(jack_output_buffer[i][j][k]>out_meter[j]) 
+	    out_meter[j]=jack_output_buffer[i][j][k];
+	}
+	jack_output_meter[i][j]->addValue(out_meter[j]);
       }
-      jack_output_meter[i][j]->addValue(out_meter[j]);
     }
-
   } // for RD_MAX_PORTS
   return 0;
 }
@@ -414,14 +428,46 @@ void MainObject::jackRecordTimerData(int stream)
 }
 
 
+void MainObject::jackClientStartData()
+{
+#ifdef JACK
+  QString sql=QString("select ")+
+    "DESCRIPTION,"+   // 00
+    "COMMAND_LINE "+  // 01
+    "from JACK_CLIENTS where "+
+    "STATION_NAME=\""+RDEscapeString(rd_config->stationName())+"\"";
+  RDSqlQuery *q=new RDSqlQuery(sql);
+  while(q->next()) {
+    QString cmd=RDDateDecode(q->value(1).toString(),QDate::currentDate(),
+			     cae_station,rd_config,
+			     rd_config->provisioningServiceName(rd_config->stationName()));
+    QStringList args=cmd.split(" ",QString::SkipEmptyParts);
+    QString program=args.at(0);
+    args.removeFirst();
+    jack_clients.push_back(new QProcess(this));
+    jack_clients.back()->start(program,args);
+    if(jack_clients.back()->waitForStarted()) {
+      RDApplication::syslog(rd_config,LOG_INFO,"started JACK Client \"%s\"",
+	     (const char *)q->value(0).toString().toUtf8());
+    }
+    else {
+      RDApplication::syslog(rd_config,LOG_WARNING,
+			    "failed to start JACK Client \"%s\" [%s]",
+			    (const char *)q->value(0).toString().toUtf8(),
+			    (const char *)q->value(1).toString().toUtf8());
+    }
+    sleep(1);
+  }
+  delete q;
+#endif  // JACK
+}
+
+
 void MainObject::jackInit(RDStation *station)
 {
 #ifdef JACK
-  QString sql;
-  RDSqlQuery *q;
   jack_options_t jackopts=JackNullOption;
   jack_status_t jackstat=JackFailure;
-  RDConfig::LogPriority prio=RDConfig::LogDebug;
 
   jack_connected=false;
   jack_activated=false;
@@ -435,7 +481,7 @@ void MainObject::jackInit(RDStation *station)
     }
   }
   if(jack_card==RD_MAX_CARDS) {
-    LogLine(RDConfig::LogInfo,"no more RD cards available");
+    RDApplication::syslog(rd_config,LOG_INFO,"no more RD cards available");
     return;
   }
   QString name=QString().sprintf("rivendell_%d",jack_card);
@@ -444,15 +490,26 @@ void MainObject::jackInit(RDStation *station)
   // Start Jack Server
   //
   if(station->startJack()) {
-    QStringList fields=QStringList().split(" ",station->jackCommandLine());
-    QProcess *proc=new QProcess(fields,this);
-    if(proc->start()) {
-      LogLine(RDConfig::LogDebug,"JACK server started");
+    QStringList args=
+      station->jackCommandLine().split(" ",QString::SkipEmptyParts);
+    if(args.size()) {
+      QString program=args.at(0);
+      args.removeFirst();
+      QProcess *proc=new QProcess(this);
+      proc->start(program,args);
+      if(proc->waitForStarted()) {
+        RDApplication::syslog(rd_config,LOG_INFO,"JACK server started");
+      }
+      else {
+        RDApplication::syslog(rd_config,LOG_WARNING,
+			    "failed to start JACK server");
+      }
+      sleep(1);
     }
     else {
-      LogLine(RDConfig::LogErr,"failed to start JACK server");
+        RDApplication::syslog(rd_config,LOG_WARNING,
+			    "could not start JACK server: no command line specified");
     }
-    sleep(1);
   }
 
   //
@@ -469,61 +526,70 @@ void MainObject::jackInit(RDStation *station)
   if(jack_client==NULL) {
     if((jackstat&JackInvalidOption)!=0) {
       fprintf (stderr, "invalid or unsupported JACK option\n");
-      LogLine(prio,"invalid or unsupported JACK option");
+      RDApplication::syslog(rd_config,LOG_WARNING,
+			    "invalid or unsupported JACK option");
     }
 
     if((jackstat&JackServerError)!=0) {
       fprintf (stderr, "communication error with the JACK server\n");
-      LogLine(prio,"communication error with the JACK server");
+      RDApplication::syslog(rd_config,LOG_WARNING,
+			    "communication error with the JACK server");
     }
 
     if((jackstat&JackNoSuchClient)!=0) {
       fprintf (stderr, "requested JACK client does not exist\n");
-      LogLine(prio,"requested JACK client does not exist");
+      RDApplication::syslog(rd_config,LOG_WARNING,
+			    "requested JACK client does not exist");
     }
 
     if((jackstat&JackLoadFailure)!=0) {
       fprintf (stderr, "unable to load internal JACK client\n");
-      LogLine(prio,"unable to load internal JACK client");
+      RDApplication::syslog(rd_config,LOG_WARNING,
+			    "unable to load internal JACK client");
     }
 
     if((jackstat&JackInitFailure)!=0) {
       fprintf (stderr, "unable to initialize JACK client\n");
-      LogLine(prio,"unable to initialize JACK client");
+      RDApplication::syslog(rd_config,LOG_WARNING,
+			    "unable to initialize JACK client");
     }
 
     if((jackstat&JackShmFailure)!=0) {
       fprintf (stderr, "unable to access JACK shared memory\n");
-      LogLine(prio,"unable to access JACK shared memory");
+      RDApplication::syslog(rd_config,LOG_WARNING,
+			    "unable to access JACK shared memory");
     }
 
     if((jackstat&JackVersionError)!=0) {
       fprintf (stderr, "JACK protocol version mismatch\n");
-      LogLine(prio,"JACK protocol version mismatch");
+      RDApplication::syslog(rd_config,LOG_WARNING,
+			    "JACK protocol version mismatch");
     }
 
     if((jackstat&JackServerStarted)!=0) {
       fprintf (stderr, "JACK server started\n");
-      LogLine(prio,"JACK server started");
+      RDApplication::syslog(rd_config,LOG_WARNING,"JACK server started");
     }
 
     if((jackstat&JackServerFailed)!=0) {
       fprintf (stderr, "unable to communication with JACK server\n");
-      LogLine(prio,"unable to communicate with JACK server");
+      RDApplication::syslog(rd_config,LOG_WARNING,
+			    "unable to communicate with JACK server");
     }
 
     if((jackstat&JackNameNotUnique)!=0) {
       fprintf (stderr, "JACK client name not unique\n");
-      LogLine(prio,"JACK client name not unique");
+      RDApplication::syslog(rd_config,LOG_WARNING,
+			    "JACK client name not unique");
     }
 
     if((jackstat&JackFailure)!=0) {
       fprintf (stderr, "JACK general failure\n");
-      LogLine(prio,"JACK general failure");
+      RDApplication::syslog(rd_config,LOG_WARNING,"JACK general failure");
     }
     jack_card=-1;
     fprintf (stderr, "no connection to JACK server\n");
-    LogLine(prio,"no connection to JACK server");
+    RDApplication::syslog(rd_config,LOG_WARNING,"no connection to JACK server");
     return;
   }
   jack_connected=true;
@@ -535,29 +601,15 @@ void MainObject::jackInit(RDStation *station)
 #else
   jack_on_shutdown(jack_client,JackShutdown,0);
 #endif  // HAVE_JACK_INFO_SHUTDOWN
-  LogLine(RDConfig::LogDebug,"connected to JACK server");
+  RDApplication::syslog(rd_config,LOG_INFO,"connected to JACK server");
 
   //
   // Start JACK Clients
   //
-  sql=QString("select DESCRIPTION,COMMAND_LINE from JACK_CLIENTS where ")+
-    "STATION_NAME=\""+RDEscapeString(station->name())+"\"";
-  q=new RDSqlQuery(sql);
-  while(q->next()) {
-    QStringList fields=QStringList().split(" ",q->value(1).toString());
-    jack_clients.push_back(new QProcess(fields,this));
-    if(jack_clients.back()->start()) {
-      LogLine(RDConfig::LogDebug,"started JACK Client \""+
-	      q->value(0).toString()+"\"");
-    }
-    else {
-      LogLine(RDConfig::LogWarning,"failed to start JACK Client \""+
-	      q->value(0).toString()+"\" ["+
-	      q->value(1).toString()+"]");
-    }
-    sleep(1);
-  }
-  delete q;
+  jack_client_start_timer=new QTimer(this);
+  connect(jack_client_start_timer,SIGNAL(timeout()),
+	  this,SLOT(jackClientStartData()));
+  jack_client_start_timer->start(6000,true);
 
   //
   // Tell the database about us
@@ -620,6 +672,12 @@ void MainObject::jackInit(RDStation *station)
   // Register Ports
   //
   for(int i=0;i<RD_MAX_PORTS;i++) {
+    for(int j=0;j<2;j++) {
+      jack_output_port[i][j]=NULL;
+      jack_input_port[i][j]=NULL;
+    }
+  }
+  for(int i=0;i<station->jackPorts();i++) {
     name=QString().sprintf("playout_%dL",i);
     jack_output_port[i][0]=
       jack_port_register(jack_client,(const char *)name,
@@ -660,7 +718,7 @@ void MainObject::jackInit(RDStation *station)
   jack_sample_rate=jack_get_sample_rate(jack_client);
   if(jack_sample_rate!=system_sample_rate) {
     fprintf (stderr,"JACK sample rate mismatch!\n");
-    LogLine(RDConfig::LogWarning,"JACK sample rate mismatch!");
+    RDApplication::syslog(rd_config,LOG_WARNING,"JACK sample rate mismatch!");
   }
   jack_activated=true;
   cae_driver[jack_card]=RDStation::Jack;
@@ -673,7 +731,7 @@ void MainObject::jackInit(RDStation *station)
 void MainObject::jackFree()
 {
 #ifdef JACK
-  for(unsigned i=0;i<jack_clients.size();i++) {
+  for(int i=0;i<jack_clients.size();i++) {
     jack_clients[i]->kill();
     delete jack_clients[i];
   }
@@ -689,17 +747,16 @@ bool MainObject::jackLoadPlayback(int card,QString wavename,int *stream)
 {
 #ifdef JACK
   if((*stream=GetJackOutputStream())<0) {
-    LogLine(RDConfig::LogErr,QString().sprintf(
-            "Error: jackLoadPlayback(%s)   GetJackOutputStream():%d <0",
-            (const char *) wavename,
-            *stream) );
+    RDApplication::syslog(rd_config,LOG_DEBUG,
+			  "jackLoadPlayback(%s)   GetJackOutputStream():%d <0",
+	   (const char *)wavename.toUtf8(),*stream);
     return false;
   }
   jack_play_wave[*stream]=new RDWaveFile(wavename);
   if(!jack_play_wave[*stream]->openWave()) {
-    LogLine(RDConfig::LogNotice,QString().sprintf(
-            "Error: jackLoadPlayback(%s)   openWave() failed to open file",
-            (const char *) wavename) );
+    RDApplication::syslog(rd_config,LOG_DEBUG,
+			  "jackLoadPlayback(%s) openWave() failed to open file",
+	   (const char *)wavename.toUtf8());
     delete jack_play_wave[*stream];
     jack_play_wave[*stream]=NULL;
     FreeJackOutputStream(*stream);
@@ -716,12 +773,11 @@ bool MainObject::jackLoadPlayback(int card,QString wavename,int *stream)
     break;
 
   default:
-    LogLine(RDConfig::LogNotice,
-	    QString().sprintf(
-	    "Error: jackLoadPlayback(%s)   getFormatTag()%d || getBistsPerSample()%d failed",
-	    (const char *) wavename,
-	    jack_play_wave[*stream]->getFormatTag(),
-	    jack_play_wave[*stream]->getBitsPerSample() ));
+    RDApplication::syslog(rd_config,LOG_DEBUG,
+	"jackLoadPlayback(%s) getFormatTag()%d || getBistsPerSample()%d failed",
+	   (const char *) wavename.toUtf8(),
+	   jack_play_wave[*stream]->getFormatTag(),
+	   jack_play_wave[*stream]->getBitsPerSample());
     delete jack_play_wave[*stream];
     jack_play_wave[*stream]=NULL;
     FreeJackOutputStream(*stream);
@@ -912,9 +968,9 @@ bool MainObject::jackLoadRecord(int card,int stream,int coding,int chans,
       break;
 
     default:
-      LogLine(RDConfig::LogErr,QString().
-	sprintf("requested unsupported channel count %d, card: %d, stream: %d",
-		chans,card,stream));
+      RDApplication::syslog(rd_config,LOG_WARNING,
+	     "requested unsupported channel count %d, card: %d, stream: %d",
+	     chans,card,stream);
       delete jack_record_wave[stream];
       jack_record_wave[stream]=NULL;
       return false;
@@ -940,9 +996,9 @@ bool MainObject::jackLoadRecord(int card,int stream,int coding,int chans,
     break;
 
   default:
-    LogLine(RDConfig::LogErr,QString().
-	    sprintf("requested invalid audio encoding %d, card: %d, stream: %d",
-		    coding,card,stream));
+    RDApplication::syslog(rd_config,LOG_WARNING,
+	   "requested invalid audio encoding %d, card: %d, stream: %d",
+	   coding,card,stream);
     delete jack_record_wave[stream];
     jack_record_wave[stream]=NULL;
     return false;
@@ -1062,7 +1118,7 @@ bool MainObject::jackSetInputVolume(int card,int stream,int level)
   }
   if(level>-10000) {
     jack_input_volume[stream]=
-      (jack_default_audio_sample_t)pow10((double)level/2000.0);
+      (jack_default_audio_sample_t)pow(10.0,(double)level/2000.0);
     jack_input_volume_db[stream]=level;
   }
   else {
@@ -1085,7 +1141,7 @@ bool MainObject::jackSetOutputVolume(int card,int stream,int port,int level)
   }
   if(level>-10000) {
     jack_output_volume[port][stream]=
-      (jack_default_audio_sample_t)pow10((double)level/2000.0);
+      (jack_default_audio_sample_t)pow(10.0,(double)level/2000.0);
     jack_output_volume_db[port][stream]=level;
   }
   else {
@@ -1306,7 +1362,7 @@ bool MainObject::jackSetPassthroughLevel(int card,int in_port,int out_port,
   }
   if(level>-10000) {
     jack_passthrough_volume[in_port][out_port]=
-      (jack_default_audio_sample_t)pow10((double)level/2000.0);
+      (jack_default_audio_sample_t)pow(10.0,(double)level/2000.0);
     jack_passthrough_volume_db[in_port][out_port]=level;
   }
   else {
@@ -1320,28 +1376,6 @@ bool MainObject::jackSetPassthroughLevel(int card,int in_port,int out_port,
 }
 
 
-void MainObject::jackConnectPorts(const QString &out,const QString &in)
-{
-#ifdef JACK
-  if(jack_card<0) {
-    return;
-  }
-  jack_connect(jack_client,(const char *)in,(const char *)out);  
-#endif  // JACK
-}
-
-
-void MainObject::jackDisconnectPorts(const QString &out,const QString &in)
-{
-#ifdef JACK
-  if(jack_card<0) {
-    return;
-  }
-  jack_disconnect(jack_client,(const char *)in,(const char *)out);  
-#endif  // JACK
-}
-
-
 int MainObject::GetJackOutputStream()
 {
 #ifdef JACK
@@ -1438,9 +1472,8 @@ void MainObject::WriteJackBuffer(int stream,jack_default_audio_sample_t *buffer,
 	jack_record_wave[stream]->writeWave(mpeg,s);
       }
       else {
-	LogLine(RDConfig::LogErr,QString().
-	   sprintf("TwoLAME encode error, card: %d, stream: %d",jack_card,
-		   stream));
+	RDApplication::syslog(rd_config,LOG_WARNING,
+	       "TwoLAME encode error, card: %d, stream: %d",jack_card,stream);
       }
     }
     if(done) {
@@ -1643,9 +1676,8 @@ void MainObject::JackSessionSetup()
   QString dest=profile->stringValue("JackSession",dest_tag,"",&dest_ok);
   while(src_ok&&dest_ok) {
     if(jack_connect(jack_client,(const char *)src,(const char *)dest)!=0) {
-      LogLine(RDConfig::LogNotice,QString().
-	      sprintf("unable to connect %s to %s",
-		      (const char *)src,(const char *)dest));
+      RDApplication::syslog(rd_config,LOG_WARNING,"unable to connect %s to %s",
+	     (const char *)src.toUtf8(),(const char *)dest.toUtf8());
     }
     count++;
     src_tag=QString().sprintf("Source%d",count+1);
