@@ -2,7 +2,7 @@
 //
 // Export an Audio File using the RdXport Web Service
 //
-//   (C) Copyright 2010-2018 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2010,2016-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,6 +31,7 @@
 #include <qapplication.h>
 
 #include <rd.h>
+#include <rdapplication.h>
 #include <rdxport_interface.h>
 #include <rdformpost.h>
 #include <rdaudioexport.h>
@@ -51,12 +52,9 @@ int ExportProgressCallback(void *clientp,double dltotal,double dlnow,
 }
 
 
-RDAudioExport::RDAudioExport(RDStation *station,RDConfig *config,
-			     QObject *parent)
+RDAudioExport::RDAudioExport(QObject *parent)
   : QObject(parent)
 {
-  conv_station=station;
-  conv_config=config;
   conv_cart_number=0;
   conv_cut_number=0;
   conv_start_point=-1;
@@ -136,33 +134,74 @@ RDAudioExport::ErrorCode RDAudioExport::runExport(const QString &username,
   CURL *curl=NULL;
   FILE *f=NULL;
   char url[1024];
+  struct curl_httppost *first=NULL;
+  struct curl_httppost *last=NULL;
   RDAudioExport::ErrorCode ret;
   RDWebResult web_result;
 
   //
   // Generate POST Data
   //
-  QString post=QString().sprintf("COMMAND=%d&LOGIN_NAME=%s&PASSWORD=%s&CART_NUMBER=%u&CUT_NUMBER=%u&FORMAT=%d&CHANNELS=%d&SAMPLE_RATE=%d&BIT_RATE=%d&QUALITY=%d&START_POINT=%d&END_POINT=%d&NORMALIZATION_LEVEL=%d&ENABLE_METADATA=%d",
-				 RDXPORT_COMMAND_EXPORT,
-				 (const char *)RDFormPost::urlEncode(username),
-				 (const char *)RDFormPost::urlEncode(password),
-				 conv_cart_number,
-				 conv_cut_number,
-				 conv_settings->format(),
-				 conv_settings->channels(),
-				 conv_settings->sampleRate(),
-				 conv_settings->bitRate(),
-				 conv_settings->quality(),
-				 conv_start_point,
-				 conv_end_point,
-				 conv_settings->normalizationLevel(),
-				 conv_enable_metadata);
-
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"COMMAND",
+	       CURLFORM_COPYCONTENTS,
+	       (const char *)QString().sprintf("%u",RDXPORT_COMMAND_EXPORT),
+	       CURLFORM_END);
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"LOGIN_NAME",
+	       CURLFORM_COPYCONTENTS,(const char *)username.utf8(),CURLFORM_END);
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"PASSWORD",
+	       CURLFORM_COPYCONTENTS,(const char *)password.utf8(),CURLFORM_END);
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"CART_NUMBER",
+	       CURLFORM_COPYCONTENTS,
+	       (const char *)QString().sprintf("%u",conv_cart_number),
+	       CURLFORM_END);
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"CUT_NUMBER",
+	       CURLFORM_COPYCONTENTS,
+	       (const char *)QString().sprintf("%u",conv_cut_number),
+	       CURLFORM_END);
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"FORMAT",
+	       CURLFORM_COPYCONTENTS,
+	       (const char *)QString().sprintf("%u",conv_settings->format()),
+	       CURLFORM_END);
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"CHANNELS",
+	       CURLFORM_COPYCONTENTS,
+	       (const char *)QString().sprintf("%u",conv_settings->channels()),
+	       CURLFORM_END);
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"SAMPLE_RATE",
+	       CURLFORM_COPYCONTENTS,
+	       (const char *)QString().sprintf("%u",conv_settings->sampleRate()),
+	       CURLFORM_END);
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"BIT_RATE",
+	       CURLFORM_COPYCONTENTS,
+	       (const char *)QString().sprintf("%u",conv_settings->bitRate()),
+	       CURLFORM_END);
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"QUALITY",
+	       CURLFORM_COPYCONTENTS,
+	       (const char *)QString().sprintf("%u",conv_settings->quality()),
+	       CURLFORM_END);
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"START_POINT",
+	       CURLFORM_COPYCONTENTS,
+	       (const char *)QString().sprintf("%d",conv_start_point),
+	       CURLFORM_END);
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"END_POINT",
+	       CURLFORM_COPYCONTENTS,
+	       (const char *)QString().sprintf("%d",conv_end_point),
+	       CURLFORM_END);
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"NORMALIZATION_LEVEL",
+	       CURLFORM_COPYCONTENTS,
+	       (const char *)QString().sprintf("%d",conv_settings->
+					       normalizationLevel()),
+	       CURLFORM_END);
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"ENABLE_METADATA",
+	       CURLFORM_COPYCONTENTS,
+	       (const char *)QString().sprintf("%u",conv_enable_metadata),
+	       CURLFORM_END);
   if((curl=curl_easy_init())==NULL) {
+    curl_formfree(first);
     return RDAudioExport::ErrorInternal;
   }
-  if((f=fopen(conv_dst_filename,"w"))==NULL) {
+  if((f=fopen(conv_dst_filename.toUtf8(),"w"))==NULL) {
     curl_easy_cleanup(curl);
+    curl_formfree(first);
     return RDAudioExport::ErrorNoDestination;
   }
   //
@@ -170,13 +209,12 @@ RDAudioExport::ErrorCode RDAudioExport::runExport(const QString &username,
   // otherwise some versions of LibCurl will throw a 'bad/illegal format' 
   // error.
   //
-  strncpy(url,conv_station->webServiceUrl(conv_config),1024);
+  strncpy(url,rda->station()->webServiceUrl(rda->config()),1024);
   curl_easy_setopt(curl,CURLOPT_URL,url);
+  curl_easy_setopt(curl,CURLOPT_HTTPPOST,first);
   curl_easy_setopt(curl,CURLOPT_WRITEDATA,f);
-  curl_easy_setopt(curl,CURLOPT_POST,1);
-  curl_easy_setopt(curl,CURLOPT_POSTFIELDS,(const char *)post);
   curl_easy_setopt(curl,CURLOPT_USERAGENT,
-		   (const char *)conv_config->userAgent());
+		   (const char *)rda->config()->userAgent());
   curl_easy_setopt(curl,CURLOPT_TIMEOUT,RD_CURL_TIMEOUT);
   curl_easy_setopt(curl,CURLOPT_PROGRESSFUNCTION,ExportProgressCallback);
   curl_easy_setopt(curl,CURLOPT_PROGRESSDATA,this);
@@ -188,7 +226,8 @@ RDAudioExport::ErrorCode RDAudioExport::runExport(const QString &username,
 
   case CURLE_ABORTED_BY_CALLBACK:
     curl_easy_cleanup(curl);
-    unlink(conv_dst_filename);
+    curl_formfree(first);
+    unlink(conv_dst_filename.toUtf8());
     return RDAudioExport::ErrorAborted;
 
   case CURLE_UNSUPPORTED_PROTOCOL:
@@ -202,6 +241,7 @@ RDAudioExport::ErrorCode RDAudioExport::runExport(const QString &username,
   case CURLE_HTTP_POST_ERROR:
   default:
     curl_easy_cleanup(curl);
+    curl_formfree(first);
     return RDAudioExport::ErrorInternal;
 
   case CURLE_URL_MALFORMAT:
@@ -209,15 +249,16 @@ RDAudioExport::ErrorCode RDAudioExport::runExport(const QString &username,
   case CURLE_COULDNT_CONNECT:
   case 9:  // CURLE_REMOTE_ACCESS_DENIED:
     curl_easy_cleanup(curl);
+    curl_formfree(first);
     return RDAudioExport::ErrorUrlInvalid;
   }
   curl_easy_getinfo(curl,CURLINFO_RESPONSE_CODE,&response_code);
   curl_easy_cleanup(curl);
+  curl_formfree(first);
   fclose(f);
 
   if(response_code==200) {
     *conv_err=RDAudioConvert::ErrorOk;
-    chmod(conv_dst_filename,conv_config->tuningExportedFileMode());
     return RDAudioExport::ErrorOk;
   }
 
@@ -237,7 +278,7 @@ RDAudioExport::ErrorCode RDAudioExport::runExport(const QString &username,
   default:
     ret=RDAudioExport::ErrorConverter;
   }
-  unlink(conv_dst_filename);
+  unlink(conv_dst_filename.toUtf8());
 
   return ret;
 }
