@@ -2,9 +2,7 @@
 //
 // Import an Audio File using the RdXport Web Service
 //
-//   (C) Copyright 2010 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdaudioimport.h,v 1.4 2011/12/23 22:04:11 cvs Exp $
+//   (C) Copyright 2010-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,7 +23,6 @@
 
 #include <qobject.h>
 
-#include <rdstation.h>
 #include <rdsettings.h>
 #include <rdaudioconvert.h>
 
@@ -37,7 +34,7 @@ class RDAudioImport : public QObject
 		  ErrorNoDestination=3,ErrorInternal=5,ErrorUrlInvalid=7,
 		  ErrorService=8,ErrorInvalidUser=9,ErrorAborted=10,
 		  ErrorConverter=11};
-  RDAudioImport(RDStation *station,QObject *parent=0,const char *name=0);
+  RDAudioImport(QObject *parent=0);
   void setCartNumber(unsigned cartnum);
   void setCutNumber(unsigned cutnum);
   void setSourceFile(const QString &filename);
@@ -54,7 +51,6 @@ class RDAudioImport : public QObject
   void abort();
 
  private:
-  RDStation *conv_station;
   unsigned conv_cart_number;
   unsigned conv_cut_number;
   QString conv_src_filename;
