@@ -2,7 +2,7 @@
 //
 //  Small library for handling common configuration file tasks
 // 
-//   (C) Copyright 1996-2003 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 1996-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -25,22 +25,22 @@
 #include <fcntl.h>
 #include <string.h>
 
+#include <qdir.h>
 #include <qhostaddress.h>
+#include <qtextstream.h>
 #include <qvariant.h>
 #include <qmessagebox.h>
 #include <qdir.h>
-#ifdef WIN32
-#define RDCONF_FILE_SEPARATOR '\\'
-#else
 #define RDCONF_FILE_SEPARATOR '/'
 #include <unistd.h>
 #include <netdb.h>
 #include <sys/timex.h>
 #include <time.h>
-#endif
-#include <rddb.h>
-#include <rdconf.h>
-#include <rdescape_string.h>
+
+#include "rddb.h"
+#include "rdconf.h"
+#include "rddatetime.h"
+#include "rdescape_string.h"
 
 #define BUFFER_SIZE 1024
 
@@ -55,21 +55,12 @@ int GetPrivateProfileBool(const char *sFilename,const char *cHeader,
   if(temp[0]==0) {
     return bDefault;
   }
-#ifdef WIN32
-  if((!stricmp(temp,"yes"))||(!stricmp(temp,"on"))) {
-    return true;
-  }
-  if((!stricmp(temp,"no"))||(!stricmp(temp,"off"))) {
-    return false;
-  }
-#else
   if((!strcasecmp(temp,"yes"))||(!strcasecmp(temp,"on"))) {
     return true;
   }
   if((!strcasecmp(temp,"no"))||(!strcasecmp(temp,"off"))) {
     return false;
   }
-#endif
   return bDefault;
 }
 
@@ -148,13 +139,6 @@ int GetIni(const char *sFileName,const char *cHeader,const char *cLabel,
   int iFileStat;
 
   strcpy(sName,sFileName);
-#ifdef WIN32
-  for(int i=0;i<strlen(sName);i++) {
-    if(sName[i]=='/') {
-      sName[i]='\\';
-    }
-  }
-#endif  // WIN32
   cIniName=fopen(sName,"r");
   if(cIniName==NULL) {
     return 2;	/* ini file doesn't exist! */
@@ -229,7 +213,6 @@ void Prepend(char *sPathname,char *sFilename)
 }
 
   
-#ifndef WIN32
 int IncrementIndex(char *sPathname,int dMaxIndex)
 {
   int dLockname=-1;
@@ -294,7 +277,6 @@ int IncrementIndex(char *sPathname,int dMaxIndex)
 
   return dIndex;
 }
-#endif
 
 
 /*
@@ -321,7 +303,6 @@ void StripLevel(char *sString)
 
 
 
-#ifndef WIN32
 bool GetLock(const char *sLockname)
 {
   int fd;
@@ -342,17 +323,12 @@ bool GetLock(const char *sLockname)
   close(fd);
   return true;
 }
-#endif
 
 
-
-
-#ifndef WIN32
 void ClearLock(const char *sLockname)
 {
   unlink(sLockname);
 }
-#endif  // WIN32
 
 
 QString RDGetPathPart(QString path)
@@ -433,7 +409,6 @@ QFont::Weight RDGetFontWeight(QString string)
 }
 
 
-#ifndef WIN32
 bool RDDetach(const QString &coredir)
 {
   if(!coredir.isEmpty()) {
@@ -444,7 +419,6 @@ bool RDDetach(const QString &coredir)
   }
   return true;
 }
-#endif
 
 
 bool RDBool(QString string)
@@ -465,7 +439,6 @@ QString RDYesNo(bool state)
 }
 
 
-#ifndef WIN32
 QHostAddress RDGetHostAddr()
 {
   FILE *file;
@@ -488,20 +461,15 @@ QHostAddress RDGetHostAddr()
     (host_ent->h_addr_list[0][3]&0xff);
   return QHostAddress((Q_UINT32)host_address);
 }
-#endif  // WIN32
 
 
 QString RDGetDisplay(bool strip_point)
 {
-#ifdef WIN32
-  return QString("win32");
-#else
   QString display;
   int l;
 
   if(getenv("DISPLAY")[0]==':') {
-    display=QString().sprintf("%s%s",(const char *)RDGetHostAddr().toString(),
-			     getenv("DISPLAY"));
+    display=RDGetHostAddr().toString()+QString(getenv("DISPLAY"));
   }
   else {
     display=QString(getenv("DISPLAY"));
@@ -515,7 +483,6 @@ QString RDGetDisplay(bool strip_point)
     }
   }
   return display;
-#endif  // WIN32
 }
 
 
@@ -527,7 +494,7 @@ bool RDDoesRowExist(const QString &table,const QString &name,
 
   sql="select `"+name+"` from `"+table+"` where `"+name+"`="+
     "\""+RDEscapeString(test)+"\"";
-  q=new RDSqlQuery(sql,db);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     delete q;
     return true;
@@ -545,7 +512,7 @@ bool RDDoesRowExist(const QString &table,const QString &name,unsigned test,
 
   sql="select `"+name+"` from `"+table+"` where `"+name+"`="+
     QString().sprintf("%d",test);
-  q=new RDSqlQuery(sql,db);
+  q=new RDSqlQuery(sql);
   if(q->size()>0) {
     delete q;
     return true;
@@ -557,7 +524,7 @@ bool RDDoesRowExist(const QString &table,const QString &name,unsigned test,
 
 QVariant RDGetSqlValue(const QString &table,const QString &name,
 		       const QString &test,const QString &param,
-		       QSqlDatabase *db,bool *valid)
+		       bool *valid)
 {
   RDSqlQuery *q;
   QString sql;
@@ -565,36 +532,7 @@ QVariant RDGetSqlValue(const QString &table,const QString &name,
 
   sql="select `"+param+"` from `"+table+"` where `"+name+"`="+
     "\""+RDEscapeString(test)+"\"";
-  q=new RDSqlQuery(sql,db);
-  if(q->isActive()) {
-    q->first();
-    v=q->value(0);
-    if(valid!=NULL) {
-      *valid=!q->isNull(0);
-    }
-    delete q;
-    return v;
-  }
-  delete q;
-  return QVariant();
-}
-
-
-QVariant RDGetSqlValue(const QString &table,
-		       const QString &name1,const QString &test1,
-		       const QString &name2,const QString &test2,
-                       const QString &name3,const QString &test3,
-		       const QString &param,QSqlDatabase *db,bool *valid)
-{
-  RDSqlQuery *q;
-  QString sql;
-  QVariant v;
-
-  sql="select `"+param+"` from `"+table+"` where "+
-    "(`"+name1+"`=\""+RDEscapeString(test1)+"\")&&"+
-    "(`"+name2+"`=\""+RDEscapeString(test1)+"\")&&"+
-    "(`"+name3+"`=\""+RDEscapeString(test1)+"\")";
-  q=new RDSqlQuery(sql,db);
+  q=new RDSqlQuery(sql);
   if(q->isActive()) {
     q->first();
     v=q->value(0);
@@ -617,7 +555,7 @@ bool RDIsSqlNull(const QString &table,const QString &name,const QString &test,
 
   sql="select `"+param+"` from `"+table+"` where `"+name+"`="+
     "\""+RDEscapeString(test)+"\"";
-  q=new RDSqlQuery(sql,db);
+  q=new RDSqlQuery(sql);
   if(q->isActive()) {
     q->first();
     if(q->isNull(0)) {
@@ -642,7 +580,7 @@ bool RDIsSqlNull(const QString &table,const QString &name,unsigned test,
 
   sql="select `"+param+"` from `"+table+"` where `"+name+"`="+
     QString().sprintf("%d",test);
-  q=new RDSqlQuery(sql,db);
+  q=new RDSqlQuery(sql);
   if(q->isActive()) {
     q->first();
     if(q->isNull(0)) {
@@ -660,7 +598,7 @@ bool RDIsSqlNull(const QString &table,const QString &name,unsigned test,
 
 
 QVariant RDGetSqlValue(const QString &table,const QString &name,unsigned test,
-		       const QString &param,QSqlDatabase *db,bool *valid)
+		       const QString &param,bool *valid)
 {
   RDSqlQuery *q;
   QString sql;
@@ -668,7 +606,7 @@ QVariant RDGetSqlValue(const QString &table,const QString &name,unsigned test,
 
   sql="select `"+param+"` from `"+table+"` where `"+name+"`="+
     QString().sprintf("%u",test);
-  q=new RDSqlQuery(sql,db);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     v=q->value(0);
     if(valid!=NULL) {
@@ -702,29 +640,30 @@ QString RDGetTimeLength(int mseconds,bool leadzero,bool tenths)
   tenthsecs=mseconds/100;
   if(leadzero) {
     if(tenths) {
-     return QString().sprintf("%s%d:%02d:%02d.%d",negative,hour,min,seconds,
-			      tenthsecs);
+      return QString(negative)+
+	QString().sprintf("%d:%02d:%02d.%d",hour,min,seconds,tenthsecs);
     }
-    return QString().sprintf("%s%d:%02d:%02d",negative,hour,min,seconds);
+    return QString(negative)+
+      QString().sprintf("%d:%02d:%02d",hour,min,seconds);
   }
   if((hour==0)&&(min==0)) {
     if(tenths) {
-      return QString().sprintf("%s:%02d.%d",negative,seconds,tenthsecs);
+      return QString(negative)+QString().sprintf(":%02d.%d",seconds,tenthsecs);
     }
-    return QString().sprintf("%s:%02d",negative,seconds);
+    return QString(negative)+QString().sprintf(":%02d",seconds);
   }
   if(hour==0) {
     if(tenths) {
-      return QString().sprintf("%s%2d:%02d.%d",negative,min,seconds,
-			       tenthsecs);
+      return QString(negative)+
+	QString().sprintf("%2d:%02d.%d",min,seconds,tenthsecs);
     }
-    return QString().sprintf("%s%2d:%02d",negative,min,seconds);
+    return QString(negative)+QString().sprintf("%2d:%02d",min,seconds);
   }
   if(tenths) {
-    return QString().sprintf("%s%2d:%02d:%02d.%d",negative,hour,min,seconds,
-			     tenthsecs);
+    return QString(negative)+
+      QString().sprintf("%2d:%02d:%02d.%d",hour,min,seconds,tenthsecs);
   }
-  return QString().sprintf("%s%2d:%02d:%02d",negative,hour,min,seconds);
+  return QString(negative)+QString().sprintf("%2d:%02d:%02d",hour,min,seconds);
 }
 
 
@@ -737,7 +676,7 @@ int RDSetTimeLength(const QString &str)
   if(str.isEmpty()) {
     return -1;
   }
-  for(unsigned i=0;i<str.length();i++) {
+  for(int i=0;i<str.length();i++) {
     if(str.at(i)==':') {
       istate--;
     }
@@ -745,7 +684,7 @@ int RDSetTimeLength(const QString &str)
   if(istate<0) {
     return -1;
   }
-  for(unsigned i=0;i<str.length();i++) {
+  for(int i=0;i<str.length();i++) {
     if(str.at(i).isNumber()) {
       field+=str.at(i);
     }
@@ -801,8 +740,7 @@ int RDSetTimeLength(const QString &str)
   return res;
 }
 
-
-#ifndef WIN32
+/*
 bool RDCopy(const QString &srcfile,const QString &destfile)
 {
   int src_fd;
@@ -839,18 +777,89 @@ bool RDCopy(const QString &srcfile,const QString &destfile)
   close(dest_fd);
   return true;
 }
-#endif  // WIN32
+*/
+
+bool RDCopy(const QString &srcfile,const QString &destfile)
+{
+  int src_fd;
+  int dest_fd;
+
+  if((src_fd=open((const char *)srcfile,O_RDONLY))<0) {
+    return false;
+  }
+  if((dest_fd=open((const char *)destfile,O_WRONLY|O_CREAT,S_IWUSR))<0) {
+    close(src_fd);
+    return false;
+  }
+  bool ret=RDCopy(src_fd,dest_fd);
+  close(src_fd);
+  close(dest_fd);
+
+  return ret;
+}
+
+
+bool RDCopy(const QString &srcfile,int dest_fd)
+{
+  int src_fd;
+
+  if((src_fd=open((const char *)srcfile,O_RDONLY))<0) {
+    return false;
+  }
+  bool ret=RDCopy(src_fd,dest_fd);
+  close(src_fd);
+
+  return ret;
+}
+
+
+bool RDCopy(int src_fd,const QString &destfile)
+{
+  int dest_fd;
+
+  if((dest_fd=open((const char *)destfile,O_WRONLY|O_CREAT,S_IWUSR))<0) {
+    return false;
+  }
+  bool ret=RDCopy(src_fd,dest_fd);
+  close(dest_fd);
+
+  return ret;
+}
+
+
+bool RDCopy(int src_fd,int dest_fd)
+{
+  struct stat src_stat;
+  struct stat dest_stat;
+  char *buf=NULL;
+  int n;
+
+  if(fstat(src_fd,&src_stat)<0) {
+    return false;
+  }
+  if(fstat(dest_fd,&dest_stat)<0) {
+    return false;
+  }
+  if(fchmod(dest_fd,src_stat.st_mode)<0) {
+    return false;
+  }
+  buf=(char *)malloc(dest_stat.st_blksize);
+  while((n=read(src_fd,buf,dest_stat.st_blksize))==dest_stat.st_blksize) {
+    write(dest_fd,buf,dest_stat.st_blksize);
+  }
+  write(dest_fd,buf,n);
+  free(buf);
+
+  return true;
+}
 
 
-#ifndef WIN32
 bool RDWritePid(const QString &dirname,const QString &filename,int owner,
 		int group)
 {
   FILE *file;
   mode_t prev_mask;
-  QString pathname=QString().sprintf("%s/%s",
-				     (const char *)dirname,
-				     (const char *)filename);
+  QString pathname=dirname+"/"+filename;
 
   prev_mask = umask(0113);      // Set umask so pid files are user and group writable.
   file=fopen((const char *)pathname,"w");
@@ -868,9 +877,7 @@ bool RDWritePid(const QString &dirname,const QString &filename,int owner,
 
 void RDDeletePid(const QString &dirname,const QString &filename)
 {
-  QString pid=QString().sprintf("%s/%s",
-				(const char *)dirname,
-				(const char *)filename);
+  QString pid=dirname+"/"+filename;
   unlink((const char *)pid);
 }
 
@@ -912,7 +919,6 @@ bool RDTimeSynced()
   }
   return false;
 }
-#endif  // WIN32
 
 
 QString RDGetHomeDir(bool *found)
@@ -936,7 +942,7 @@ QString RDTruncateAfterWord(QString str,int word,bool add_dots)
   int quan=0;
   int point;
 
-  for(unsigned i=0;i<simple.length();i++) {
+  for(int i=0;i<simple.length();i++) {
     if(simple.at(i).isSpace()) {
       quan++;
       point=i;
@@ -963,16 +969,27 @@ QString RDHomeDir()
 }
 
 
+QString RDTempDir()
+{
+  char path[PATH_MAX]="/tmp/rddbmgrXXXXXX";
+
+  return QString(mkdtemp(path));
+}
+
+
 QString RDTempFile()
 {
-#ifndef WIN32
-  return QString(tmpnam(NULL));
-#endif  // WIN32
+  int fd=-1;
+  char dirname[PATH_MAX];
+  strncpy(dirname,"/tmp/rivendellXXXXXX",PATH_MAX);
+  if((fd=mkstemp(dirname))>0) {
+    close(fd);
+    return QString(dirname);
+  }
   return QString();
 }
 
 
-#ifndef WIN32
 QString RDTimeZoneName(const QDateTime &datetime)
 {
   char name[20];
@@ -980,7 +997,6 @@ QString RDTimeZoneName(const QDateTime &datetime)
   strftime(name,20,"%Z",localtime(&time));
   return QString(name);
 }
-#endif  // WIN32
 
 
 QString RDDowCode(int dow)
@@ -1042,22 +1058,26 @@ QTime RDUtcToLocal(const QTime &gmttime)
   return gmttime.addSecs(-RDTimeZoneOffset());
 }
 
-
+/*
 int RDTimeZoneOffset()
 {
-#ifdef WIN32
-  return 0;
-#else
   time_t t=time(&t);
   struct tm *tm=localtime(&t);
   time_t local_time=3600*tm->tm_hour+60*tm->tm_min+tm->tm_sec;
   tm=gmtime(&t);
   time_t gmt_time=3600*tm->tm_hour+60*tm->tm_min+tm->tm_sec;
 
-  return gmt_time-local_time;
-#endif  // WIN32
-}
+  int offset=gmt_time-local_time;
+  if(offset>43200) {
+    offset=offset-86400;
+  }
+  if(offset<-43200) {
+    offset=offset+86400;
+  }
 
+  return offset;
+}
+*/
 
 QColor RDGetTextColor(const QColor &background_color)
 {
@@ -1092,7 +1112,6 @@ bool RDProcessActive(const QString &cmd)
 
 bool RDProcessActive(const QStringList &cmds)
 {
-#ifndef WIN32
   QStringList dirs;
   QDir *proc_dir=new QDir("/proc");
   bool ok=false;
@@ -1102,15 +1121,15 @@ bool RDProcessActive(const QStringList &cmds)
 
   proc_dir->setFilter(QDir::Dirs);
   dirs=proc_dir->entryList();
-  for(unsigned i=0;i<dirs.size();i++) {
+  for(int i=0;i<dirs.size();i++) {
     dirs[i].toInt(&ok);
     if(ok) {
       if((f=fopen(QString("/proc/")+dirs[i]+"/cmdline","r"))!=NULL) {
 	if(fgets(line,1024,f)!=NULL) {
-	  QStringList f1=f1.split(" ",QString(line));
-	  QStringList f2=f2.split("/",f1[0]);
+	  QStringList f1=QString(line).split(" ",QString::SkipEmptyParts);
+	  QStringList f2=f1[0].split("/",QString::SkipEmptyParts);
 	  cmdline=f2[f2.size()-1];
-	  for(unsigned j=0;j<cmds.size();j++) {
+	  for(int j=0;j<cmds.size();j++) {
 	    if(cmdline==cmds[j]) {
 	      fclose(f);
 	      return true;
@@ -1123,7 +1142,6 @@ bool RDProcessActive(const QStringList &cmds)
   }
 
   delete proc_dir;
-#endif  // WIN32
   return false;
 }
 
@@ -1149,41 +1167,85 @@ bool RDModulesActive()
 
 QByteArray RDStringToData(const QString &str)
 {
-  QByteArray ret;
-#ifndef WIN32
   int istate=0;
-  QString hexcode="";
+  unsigned n;
+  QString code;
+  QByteArray ret;
+  bool ok=false;
 
-  for(unsigned i=0;i<str.length();i++) {
+  for(int i=0;i<str.length();i++) {
     switch(istate) {
     case 0:
-      if((str.at(i)=='%')&&(i<(str.length()-2))) {
-	hexcode="";
+      if(str.at(i)==QChar('%')) {
 	istate=1;
       }
       else {
-	ret.resize(ret.size()+1);
-	ret[ret.size()-1]=str.at(i);
+	ret+=str.at(i);
       }
       break;
 
     case 1:
-      hexcode=str.at(i);
+      n=str.mid(i,1).toUInt(&ok);
+      if((!ok)||(n>9)) {
+	istate=0;
+      }
+      code=str.mid(i,1);
       istate=2;
       break;
 
     case 2:
-      hexcode+=str.at(i);
-      ret.resize(ret.size()+1);
-      ret[ret.size()-1]=0xFF&hexcode.toUInt(NULL,16);
-      istate=0;
-      break;
-
-    default:
+      n=str.mid(i,1).toUInt(&ok);
+      if((!ok)||(n>9)) {
+	istate=0;
+      }
+      code+=str.mid(i,1);
+      ret+=code.toUInt(NULL,16);
       istate=0;
       break;
     }
   }
-#endif  // WIN32
+
   return ret;
 }
+
+
+QString RDStringToHex(const QString &str)
+{
+  QByteArray bytes=str.toUtf8();
+  QString ret="";
+
+  for(int i=0;i<bytes.length();i++) {
+    ret+=QString().sprintf("%02X ",0xFF&bytes[i]);
+  }
+
+  return ret;
+}
+
+
+QList<pid_t> RDGetPids(const QString &program)
+{
+  QList<pid_t> pids;
+  bool ok=false;
+
+  QDir procdir("/proc");
+  QStringList files=
+    procdir.entryList(QDir::Dirs|QDir::NoDotAndDotDot,QDir::Name);
+
+  for(int i=0;i<files.size();i++) {
+    pid_t pid=files.at(i).toInt(&ok);
+    if(ok) {
+      QFile file(QString("/proc/")+files.at(i)+"/cmdline");
+      if(file.open(QIODevice::ReadOnly)) {
+	QTextStream strm(&file);
+	strm.setCodec("UTF-8");
+	QStringList f0=strm.readLine().split(" ");
+	QStringList f1=f0.at(0).split("/");
+	if(f1.back().left(f1.back().length()-1)==program.trimmed()) {
+	  pids.push_back(pid);
+	}
+      }
+    }
+  }
+
+  return pids;
+}
