@@ -33,6 +33,7 @@
 #include <qfileinfo.h>
 
 #include <rd.h>
+#include <rdapplication.h>
 #include <rdsystemuser.h>
 #include <rddelete.h>
 
@@ -62,7 +63,7 @@ int DeleteErrorCallback(CURL *curl,curl_infotype type,char *msg,size_t size,
   }
   memset(&str,0,size+1);
   memcpy(str,msg,size);
-  syslog(LOG_DEBUG,"CURL MSG: %s",str);
+  rda->syslog(LOG_DEBUG,"CURL MSG: %s",str);
   return 0;
 }
 
@@ -94,21 +95,19 @@ RDDelete::ErrorCode RDDelete::runDelete(const QString &username,
   QString xml="";
 
   if((curl=curl_easy_init())==NULL) {
-    syslog(LOG_ERR,"unable to initialize curl library\n");
+    rda->syslog(LOG_ERR,"unable to initialize curl library\n");
     return RDDelete::ErrorInternal;
   }
   strncpy(urlstr,(const char *)(conv_target_url.protocol()+"://"+
-				conv_target_url.host()+"/"),1024);
+				conv_target_url.host()+"/").utf8(),1024);
   curl_easy_setopt(curl,CURLOPT_URL,urlstr);
-  strncpy(userpwd,(const char *)QString().
-		   sprintf("%s:%s",(const char *)username,
-			   (const char *)password),256);
+  strncpy(userpwd,(QString(username)+":"+password).utf8(),256);
   curl_easy_setopt(curl,CURLOPT_USERPWD,userpwd);
   curl_easy_setopt(curl,CURLOPT_HTTPAUTH,CURLAUTH_ANY);
   curl_easy_setopt(curl,CURLOPT_WRITEFUNCTION,DeleteWriteCallback);
   curl_easy_setopt(curl,CURLOPT_WRITEDATA,&xml);
   curl_easy_setopt(curl,CURLOPT_USERAGENT,
-		   (const char *)conv_config->userAgent());
+		   (const char *)conv_config->userAgent().utf8());
   if(log_debug) {
     curl_easy_setopt(curl,CURLOPT_VERBOSE,1);
     curl_easy_setopt(curl,CURLOPT_DEBUGFUNCTION,DeleteErrorCallback);
@@ -162,7 +161,7 @@ RDDelete::ErrorCode RDDelete::runDelete(const QString &username,
     break;
   }
   if(log_debug) {
-    syslog(LOG_NOTICE,curl_easy_strerror(err));
+    rda->syslog(LOG_INFO,curl_easy_strerror(err));
   }
   curl_slist_free_all(cmds);
   curl_easy_cleanup(curl);
