@@ -2,7 +2,7 @@
 //
 // Abstract a Rivendell RSS Feed
 //
-//   (C) Copyright 2002-2007,2010,2016-2017 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,7 +21,7 @@
 #include <math.h>
 
 #include <qfile.h>
-#include <qurl.h>
+#include <q3url.h>
 #include <qapplication.h>
 
 #include <rddb.h>
@@ -47,8 +47,8 @@ RDFeed::RDFeed(const QString &keyname,RDConfig *config,QObject *parent)
   feed_keyname=keyname;
   feed_config=config;
 
-  sql=QString().sprintf("select ID from FEEDS where KEY_NAME=\"%s\"",
-			(const char *)RDEscapeString(keyname));
+  sql=QString("select ID from FEEDS where ")+
+    "KEY_NAME=\""+RDEscapeString(keyname)+"\"";
   q=new RDSqlQuery(sql);
   if(q->first()) {
     feed_id=q->value(0).toUInt();
@@ -500,7 +500,7 @@ void RDFeed::setMediaLinkMode(RDFeed::MediaLinkMode mode) const
 QString RDFeed::audioUrl(RDFeed::MediaLinkMode mode,
 			 const QString &cgi_hostname,unsigned cast_id)
 {
-  QUrl url(baseUrl());
+  Q3Url url(baseUrl());
   QString ret;
   RDPodcast *cast;
 
@@ -511,19 +511,14 @@ QString RDFeed::audioUrl(RDFeed::MediaLinkMode mode,
 
     case RDFeed::LinkDirect:
       cast=new RDPodcast(feed_config,cast_id);
-      ret=QString().sprintf("%s/%s",
-			    (const char *)baseUrl(),
-			    (const char *)cast->audioFilename());
+      ret=baseUrl()+"/"+cast->audioFilename();
       delete cast;
       break;
 
     case RDFeed::LinkCounted:
-      ret=QString().sprintf("http://%s%s/rd-bin/rdfeed.%s?%s&cast_id=%d",
-			    (const char *)basePreamble(),
-			    (const char *)cgi_hostname,
-			    (const char *)uploadExtension(),
-			    (const char *)keyName(),
-			    cast_id);
+      ret=QString("http://")+basePreamble()+cgi_hostname+
+	"/rd-bin/rdfeed."+uploadExtension()+"?"+keyName()+
+	QString().sprintf("&cast_id=%d",cast_id);
       break;
   }
   return ret;
@@ -542,6 +537,7 @@ unsigned RDFeed::postCut(RDUser *user,RDStation *station,
   RDUpload *upload=NULL;
   RDUpload::ErrorCode upload_err;
   RDAudioConvert::ErrorCode audio_conv_err;
+  RDAudioExport::ErrorCode export_err;
 
   emit postProgressChanged(0);
   emit postProgressChanged(1);
@@ -556,7 +552,7 @@ unsigned RDFeed::postCut(RDUser *user,RDStation *station,
     *err=RDFeed::ErrorCannotOpenFile;
     return 0;
   }
-  RDAudioExport *conv=new RDAudioExport(station,config,this);
+  RDAudioExport *conv=new RDAudioExport(this);
   conv->setCartNumber(cut->cartNumber());
   conv->setCutNumber(cut->cutNumber());
   conv->setDestinationFile(tmpfile);
@@ -568,7 +564,7 @@ unsigned RDFeed::postCut(RDUser *user,RDStation *station,
   settings->setBitRate(uploadBitRate());
   settings->setNormalizationLevel(normalizeLevel()/100);
   conv->setDestinationSettings(settings);
-  switch(conv->runExport(user->name(),user->password(),&audio_conv_err)) {
+  switch((export_err=conv->runExport(user->name(),user->password(),&audio_conv_err))) {
   case RDAudioExport::ErrorOk:
     break;
 
@@ -605,7 +601,7 @@ unsigned RDFeed::postCut(RDUser *user,RDStation *station,
   unsigned cast_id=CreateCast(&destfile,length,cut->length());
   delete cut;
   cast=new RDPodcast(feed_config,cast_id);
-  upload=new RDUpload(feed_config,this);
+  upload=new RDUpload(this);
   upload->setSourceFile(tmpfile);
   upload->setDestinationUrl(purgeUrl()+"/"+cast->audioFilename());
   switch((upload_err=upload->runUpload(purgeUsername(),purgePassword(),
@@ -660,7 +656,7 @@ unsigned RDFeed::postFile(RDStation *station,const QString &srcfile,Error *err,
   // Convert Cut
   //
   tmpfile=GetTempFilename();
-  RDAudioConvert *conv=new RDAudioConvert(feed_config,this);
+  RDAudioConvert *conv=new RDAudioConvert(this);
   conv->setSourceFile(srcfile);
   conv->setDestinationFile(tmpfile);
   RDSettings *settings=new RDSettings();
@@ -718,7 +714,7 @@ unsigned RDFeed::postFile(RDStation *station,const QString &srcfile,Error *err,
 
   unsigned cast_id=CreateCast(&destfile,length,time_length);
   RDPodcast *cast=new RDPodcast(feed_config,cast_id);
-  upload=new RDUpload(feed_config,this);
+  upload=new RDUpload(this);
   upload->setSourceFile(tmpfile);
   upload->setDestinationUrl(purgeUrl()+"/"+cast->audioFilename());
   switch((upload_err=upload->runUpload(purgeUsername(),purgePassword(),
@@ -733,7 +729,6 @@ unsigned RDFeed::postFile(RDStation *station,const QString &srcfile,Error *err,
   default:
     emit postProgressChanged(totalPostSteps());
     *err=RDFeed::ErrorUploadFailed;
-    printf("Upload Error: %s\n",(const char *)RDUpload::errorText(upload_err));
     sql=QString().sprintf("delete from PODCASTS where ID=%u",cast_id);
     q=new RDSqlQuery(sql);
     delete q;
@@ -745,7 +740,7 @@ unsigned RDFeed::postFile(RDStation *station,const QString &srcfile,Error *err,
   }
   delete upload;
   delete cast;
-  unlink(QString().sprintf("%s.wav",(const char *)tmpfile));
+  unlink(QString(tmpfile)+".wav");
   unlink(tmpfile);
   emit postProgressChanged(totalPostSteps());
 
@@ -813,21 +808,15 @@ unsigned RDFeed::CreateCast(QString *filename,int bytes,int msecs) const
   //
   // Create Entry
   //
-  sql=QString().sprintf("insert into PODCASTS set \
-                         FEED_ID=%u,\
-                         ITEM_TITLE=\"%s\",\
-                         ITEM_DESCRIPTION=\"%s\",\
-                         ITEM_CATEGORY=\"%s\",\
-                         ITEM_LINK=\"%s\",\
-                         SHELF_LIFE=%d,\
-                         EFFECTIVE_DATETIME=UTC_TIMESTAMP(),\
-                         ORIGIN_DATETIME=UTC_TIMESTAMP()",
-			feed_id,
-			(const char *)RDEscapeString(q->value(0).toString()),
-			(const char *)RDEscapeString(q->value(1).toString()),
-			(const char *)RDEscapeString(q->value(2).toString()),
-			(const char *)RDEscapeString(q->value(3).toString()),
-			q->value(4).toInt());
+  sql=QString("insert into PODCASTS set ")+
+    QString().sprintf("FEED_ID=%u,",feed_id)+
+    "ITEM_TITLE=\""+RDEscapeString(q->value(0).toString())+"\","+
+    "ITEM_DESCRIPTION=\""+RDEscapeString(q->value(1).toString())+"\","+
+    "ITEM_CATEGORY=\""+RDEscapeString(q->value(2).toString())+"\","+
+    "ITEM_LINK=\""+RDEscapeString(q->value(3).toString())+"\","+
+    QString().sprintf("SHELF_LIFE=%d,",q->value(4).toInt())+
+    "EFFECTIVE_DATETIME=UTC_TIMESTAMP(),"+
+    "ORIGIN_DATETIME=UTC_TIMESTAMP()";
   q1=new RDSqlQuery(sql);
   delete q1;
 
@@ -844,15 +833,13 @@ unsigned RDFeed::CreateCast(QString *filename,int bytes,int msecs) const
   //
   // Generate the Filename
   //
-  *filename=QString().
-    sprintf("%s.%s",
-	    (const char *)QString().sprintf("%06u_%06u",feed_id,cast_id),
-	    (const char *)q->value(6).toString());
-  sql=QString().sprintf("update PODCASTS set AUDIO_FILENAME=\"%s\",\
-                         AUDIO_LENGTH=%d,\
-                         AUDIO_TIME=%d where ID=%u",
-			(const char *)(*filename),
-			bytes,msecs,cast_id);
+  *filename=
+    QString().sprintf("%06u_%06u",feed_id,cast_id)+"."+q->value(6).toString();
+  sql=QString("update PODCASTS set ")+
+    "AUDIO_FILENAME=\""+RDEscapeString(*filename)+"\","+
+    QString().sprintf("AUDIO_LENGTH=%d,",bytes)+
+    QString().sprintf("AUDIO_TIME=%d where ",msecs)+
+    QString().sprintf("ID=%u",cast_id);
   q1=new RDSqlQuery(sql);
   delete q1;
   delete q;
@@ -878,10 +865,9 @@ void RDFeed::SetRow(const QString &param,int value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE FEEDS SET %s=%d WHERE KEY_NAME=\"%s\"",
-			(const char *)param,
-			value,
-			(const char *)feed_keyname);
+  sql=QString("update FEEDS set ")+
+    param+QString().sprintf("=%d where ",value)+
+    "KEY_NAME=\""+RDEscapeString(feed_keyname)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -892,10 +878,9 @@ void RDFeed::SetRow(const QString &param,const QString &value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE FEEDS SET %s=\"%s\" WHERE KEY_NAME=\"%s\"",
-			(const char *)param,
-			(const char *)RDEscapeString(value),
-			(const char *)feed_keyname);
+  sql=QString("update FEEDS set ")+
+    param+"=\""+RDEscapeString(value)+"\" where "+
+    "KEY_NAME=\""+RDEscapeString(feed_keyname)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -906,10 +891,9 @@ void RDFeed::SetRow(const QString &param,const QDateTime &value,
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE FEEDS SET %s=%s WHERE KEY_NAME=\"%s\"",
-			(const char *)param,
-			(const char *)RDCheckDateTime(value, format),
-			(const char *)feed_keyname);
+  sql=QString().sprintf("update FEEDS set ")+
+    param+"="+RDCheckDateTime(value,format)+" where "+
+    "KEY_NAME=\""+RDEscapeString(feed_keyname)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 }
