@@ -2,9 +2,7 @@
 //
 // Prompt for a password.
 //
-//   (C) Copyright 2007 Fred Gleason <fredg@salemradiolabs.com>
-//
-//      $Id: rdgetpasswd.h,v 1.1 2007/02/16 18:58:31 fredg Exp $
+//   (C) Copyright 2007-2019 Fred Gleason <fredg@salemradiolabs.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,15 +21,15 @@
 #ifndef GETPASSWD_H
 #define GETPASSWD_H
 
-#include <qdialog.h>
 #include <qlineedit.h>
 
+#include <rddialog.h>
 
-class RDGetPasswd : public QDialog
+class RDGetPasswd : public RDDialog
 {
   Q_OBJECT
   public:
-   RDGetPasswd(QString *passwd,QWidget *parent=0,const char *name=0);
+   RDGetPasswd(QString *passwd,QWidget *parent=0);
    ~RDGetPasswd();
    QSize sizeHint() const;
    QSizePolicy sizePolicy() const;
