@@ -2,9 +2,7 @@
 //
 // Connection to the Rivendell Interprocess Communication Daemon
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdripc.h,v 1.24.8.1 2012/11/16 18:10:40 cvs Exp $
+//   (C) Copyright 2002-2004,2016-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,11 +21,14 @@
 #include <qsqldatabase.h>
 #include <qstring.h>
 #include <qobject.h>
-#include <qsocket.h>
 #include <qlabel.h>
 #include <qtimer.h>
+#include <qtcpsocket.h>
 
+#include <rdconfig.h>
 #include <rdmacro.h>
+#include <rdnotification.h>
+#include <rdstation.h>
 
 #ifndef RDRIPC_H
 #define RDRIPC_H
@@ -40,7 +41,7 @@ class RDRipc : public QObject
 {
   Q_OBJECT
  public:
-  RDRipc(QString stationname,QObject *parent=0,const char *name=0);
+ RDRipc(RDStation *station,RDConfig *config,QObject *parent=0);
   ~RDRipc();
   QString user() const;
   QString station() const;
@@ -54,6 +55,7 @@ class RDRipc : public QObject
   void sendGpoMask(int matrix);
   void sendGpiCart(int matrix);
   void sendGpoCart(int matrix);
+  void sendNotification(const RDNotification &notify);
   void sendOnairFlag();
   void sendRml(RDMacro *macro);
   void reloadHeartbeat();
@@ -67,29 +69,29 @@ class RDRipc : public QObject
   void gpoMaskChanged(int matrix,int line,bool state);
   void gpiCartChanged(int matrix,int line,int off_cartnum,int on_cartnum);
   void gpoCartChanged(int matrix,int line,int off_cartnum,int on_cartnum);
+  void notificationReceived(RDNotification *notify);
   void onairFlagChanged(bool state);
   void rmlReceived(RDMacro *rml);
   
  private slots:
   void connectedData();
-  void errorData(int errorcode);
+  void errorData(QAbstractSocket::SocketError err);
   void readyData();
 
  private:
-  void SendCommand(QString cmd);
+  void SendCommand(const QString &cmd);
   void DispatchCommand();
-  QSocket *ripc_socket;
+  QTcpSocket *ripc_socket;
   QString ripc_user;
   QString ripc_password;
-  QString ripc_stationname;
+  RDStation *ripc_station;
+  RDConfig *ripc_config;
   bool ripc_onair_flag;
   bool ripc_ignore_mask;
   bool debug;
-  char args[RIPC_MAX_ARGS][RIPC_MAX_LENGTH];
-  int argnum;
-  int argptr;
+  QString ripc_accum;
   bool ripc_connected;
 };
 
 
-#endif 
+#endif  // RDRIPC_H
