@@ -2,9 +2,7 @@
 //
 // Abstract a Rivendell User
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rduser.h,v 1.19 2008/04/01 20:51:39 grauf Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,19 +27,28 @@ class RDUser
 {
  public:
   RDUser(const QString &name);
+  RDUser();
   QString name() const;
+  void setName(const QString &name);
   bool exists() const;
   bool authenticated(bool webuser) const;
   bool checkPassword(const QString &password,bool webuser);
+  QString password() const;
   void setPassword(const QString &password);
   bool enableWeb() const;
   void setEnableWeb(bool state) const;
+  bool localAuthentication() const;
+  void setLocalAuthentication(bool state) const;
+  QString pamService() const;
+  void setPamService(const QString &str) const;
   QString fullName() const;
   void setFullName(const QString &name) const;
   QString description() const;
   void setDescription(const QString &desc) const;
   QString phone() const;
   void setPhone(const QString &phone) const;
+  int webapiAuthTimeout() const;
+  void setWebapiAuthTimeout(int sec) const;
   bool adminConfig() const;
   void setAdminConfig(bool priv) const;
   bool createCarts() const;
@@ -52,6 +59,8 @@ class RDUser
   void setModifyCarts(bool priv) const;
   bool editAudio() const;
   void setEditAudio(bool priv) const;
+  bool webgetLogin() const;
+  void setWebgetLogin(bool priv) const;
   bool createLog() const;
   void setCreateLog(bool priv) const;
   bool deleteLog() const;
@@ -80,6 +89,9 @@ class RDUser
   void setEditPodcast(bool priv) const;
   bool deletePodcast() const;
   void setDeletePodcast(bool priv) const;
+  bool groupAuthorized(const QString &group_name);
+  QStringList groups() const;
+  bool cartAuthorized(unsigned cartnum) const;
 
   /** Check a default service to ensure it is valid for the current user.
    *
@@ -100,6 +112,7 @@ class RDUser
 
  private:
   void SetRow(const QString &param,const QString &value) const;
+  void SetRow(const QString &param,int value) const;
   void SetRow(const QString &param,bool value) const;
   QString user_name;
   QString user_password;
