@@ -2,7 +2,7 @@
 //
 // Edit a List of Autofill Carts
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,13 +21,13 @@
 #ifndef AUTOFILL_CARTS_H
 #define AUTOFILL_CARTS_H
 
-#include <qdialog.h>
 #include <qsqldatabase.h>
-#include <qlistview.h>
+#include <q3listview.h>
 
+#include <rddialog.h>
 #include <rdsvc.h>
 
-class AutofillCarts : public QDialog
+class AutofillCarts : public RDDialog
 {
  Q_OBJECT
  public:
@@ -45,7 +45,7 @@ class AutofillCarts : public QDialog
  private:
   void RefreshList();
   RDSvc *svc_svc;
-  QListView *svc_cart_list;
+  Q3ListView *svc_cart_list;
   QString svc_cart_filter;
   QString svc_cart_group;
 };
