@@ -2,7 +2,7 @@
 //
 // Edit a Rivendell Feed
 //
-//   (C) Copyright 2002-2007,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,21 +21,22 @@
 #ifndef EDIT_FEED_H
 #define EDIT_FEED_H
 
-#include <qdialog.h>
-#include <qtextedit.h>
-#include <qspinbox.h>
-#include <qlineedit.h>
-#include <qsqldatabase.h>
 #include <qcheckbox.h>
-#include <qlabel.h>
 #include <qcombobox.h>
+#include <qgroupbox.h>
+#include <qlabel.h>
+#include <qlineedit.h>
 #include <qpushbutton.h>
+#include <qspinbox.h>
 
+#include <q3textedit.h>
+
+#include <rddialog.h>
 #include <rdfeed.h>
 #include <rdsettings.h>
 #include <rdstation.h>
 
-class EditFeed : public QDialog
+class EditFeed : public RDDialog
 {
  Q_OBJECT
  public:
@@ -48,20 +49,16 @@ class EditFeed : public QDialog
   void purgeUsernameChangedData(const QString &username);
   void setFormatData();
   void normalizeCheckData(bool state);
-  void editData();
   void redirectToggledData(bool state);
   void okData();
   void cancelData();
   
- protected:
-  void paintEvent(QPaintEvent *e);
-
  private:
   void RedirectChanged(bool state);
   RDFeed *feed_feed;
   QLineEdit *feed_keyname_edit;
   QLineEdit *feed_channel_title_edit;
-  QTextEdit *feed_channel_description_edit;
+  Q3TextEdit *feed_channel_description_edit;
   QLineEdit *feed_channel_category_edit;
   QLineEdit *feed_channel_link_edit;
   QLineEdit *feed_channel_copyright_edit;
@@ -74,9 +71,9 @@ class EditFeed : public QDialog
   QLineEdit *feed_purge_username_edit;
   QLabel *feed_purge_password_label;
   QLineEdit *feed_purge_password_edit;
-  QTextEdit *feed_header_xml_edit;
-  QTextEdit *feed_channel_xml_edit;
-  QTextEdit *feed_item_xml_edit;
+  Q3TextEdit *feed_header_xml_edit;
+  Q3TextEdit *feed_channel_xml_edit;
+  Q3TextEdit *feed_item_xml_edit;
   QSpinBox *feed_max_shelf_life_spin;
   QCheckBox *feed_autopost_box;
   QCheckBox *feed_keep_metadata_box;
@@ -92,8 +89,7 @@ class EditFeed : public QDialog
   QLabel *feed_redirect_label;
   QLineEdit *feed_redirect_edit;
   QPushButton *feed_format_button;
-  QPushButton *feed_metadata_button;
-
+  QGroupBox *feed_channel_section_groupbox;
   QLabel *feed_channel_title_label;
   QLabel *feed_channel_category_label;
   QLabel *feed_channel_link_label;
@@ -117,7 +113,6 @@ class EditFeed : public QDialog
   QLabel *feed_header_xml_label;
   QLabel *feed_channel_xml_label;
   QLabel *feed_item_xml_label;
-  QLabel *feed_channel_section_label;
 };
 
 
