@@ -2,9 +2,7 @@
 //
 // Edit an RDAirPlay Configuration
 //
-//   (C) Copyright 2002-2010 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_rdairplay.h,v 1.29.6.3 2013/03/22 15:11:51 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,19 +21,18 @@
 #ifndef EDIT_RDAIRPLAY_H
 #define EDIT_RDAIRPLAY_H
 
-#include <qdialog.h>
-#include <qsqldatabase.h>
 #include <qlineedit.h>
 #include <qcombobox.h>
 #include <qspinbox.h>
-#include <qdatetimeedit.h>
+#include <q3datetimeedit.h>
 #include <qlabel.h>
 #include <qcheckbox.h>
-#include <qbuttongroup.h>
+#include <q3buttongroup.h>
 
 #include <rd.h>
 #include <rdairplay_conf.h>
 #include <rdcardselector.h>
+#include <rddialog.h>
 #include <rdstation.h>
 
 /*
@@ -44,12 +41,11 @@
 #define LOG_PLAY_PORTS 2
 #define MAX_MANUAL_SEGUE 10
 
-class EditRDAirPlay : public QDialog
+class EditRDAirPlay : public RDDialog
 {
  Q_OBJECT
  public:
-  EditRDAirPlay(RDStation *station,RDStation *cae_station,
-		QWidget *parent=0,const char *name=0);
+  EditRDAirPlay(RDStation *station,RDStation *cae_station,QWidget *parent=0);
   ~EditRDAirPlay();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -59,11 +55,14 @@ class EditRDAirPlay : public QDialog
   void editGpiosData(int num);
   void exitPasswordChangedData(const QString &str);
   void logActivatedData(int lognum);
+  void virtualLogActivatedData(int vlognum);
+  void virtualModeActivatedData(int vlognum);
   void startModeChangedData(int mode);
   void selectData();
-  void nownextData();
   void editHotKeys();
   void selectSkinData();
+  void modeControlActivatedData(int n);
+  void logStartupModeActivatedData(int n);
   void okData();
   void cancelData();
 
@@ -78,8 +77,16 @@ class EditRDAirPlay : public QDialog
   QLabel *air_stop_rml_label[RDAirPlayConf::LastChannel];
   QLineEdit *air_stop_rml_edit[RDAirPlayConf::LastChannel];
   QPushButton *air_channel_button[RDAirPlayConf::LastChannel];
-  QLabel *air_startup_label;
-  QComboBox *air_startup_box;
+  QComboBox *air_virtual_machine_box;
+  RDCardSelector *air_virtual_card_sel;
+  QLabel *air_virtual_start_rml_label;
+  QLineEdit *air_virtual_start_rml_edit;
+  QLabel *air_virtual_stop_rml_label;
+  QLineEdit *air_virtual_stop_rml_edit;
+  int air_virtual_cards[RD_RDVAIRPLAY_LOG_QUAN];
+  int air_virtual_ports[RD_RDVAIRPLAY_LOG_QUAN];
+  QString air_virtual_start_rmls[RD_RDVAIRPLAY_LOG_QUAN];
+  QString air_virtual_stop_rmls[RD_RDVAIRPLAY_LOG_QUAN];
   QLabel *air_segue_label;
   QLineEdit *air_segue_edit;
   QLabel *air_trans_label;
@@ -103,7 +110,7 @@ class EditRDAirPlay : public QDialog
   QSpinBox *air_aux2_box;
   QCheckBox *air_auxlog_box[2];
   QCheckBox *air_clearfilter_box;
-  QButtonGroup *air_bar_group;
+  Q3ButtonGroup *air_bar_group;
   QCheckBox *air_flash_box;
   QCheckBox *air_panel_pause_box;
   QCheckBox *air_show_counters_box;
@@ -118,19 +125,31 @@ class EditRDAirPlay : public QDialog
   QLineEdit *air_exitpasswd_edit;
   bool air_exitpasswd_changed;
   int air_logmachine;
+  int air_virtual_logmachine;
   QComboBox *air_logmachine_box;
   QComboBox *air_startmode_box;
-  RDAirPlayConf::StartMode air_startmode[RDAIRPLAY_LOG_QUANTITY];
+  QMap<int,RDAirPlayConf::StartMode> air_startmodes;
   QLineEdit *air_startlog_edit;
   QLabel *air_startlog_label;
   QPushButton *air_startlog_button;
-  QString air_startlog[RDAIRPLAY_LOG_QUANTITY];
+  QMap<int,QString> air_startlogs;
   QCheckBox *air_autorestart_box;
-  bool air_autorestart[RDAIRPLAY_LOG_QUANTITY];
+  QMap<int,bool> air_autorestarts;
   QLabel *air_autorestart_label;
   QLineEdit *air_skin_edit;
+  QLineEdit *air_title_template_edit;
+  QLineEdit *air_artist_template_edit;
+  QLineEdit *air_outcue_template_edit;
+  QLineEdit *air_description_template_edit;
+  QComboBox *air_modecontrol_box;
+  QLabel *air_logstartmode_label[RDAIRPLAY_LOG_QUANTITY];
+  QComboBox *air_logstartmode_box[RDAIRPLAY_LOG_QUANTITY];
+  QComboBox *air_virtual_logstartsel_box;
+  QComboBox *air_virtual_logstartmode_box;
+  int air_virtual_logstartmachine;
+  RDAirPlayConf::OpMode air_virtual_opmodes[RD_RDVAIRPLAY_LOG_QUAN];
 };
 
 
-#endif
+#endif  // EDIT_RDAIRPLAY_H
 
