@@ -2,7 +2,7 @@
 //
 // Edit a Rivendell TTY Configuration
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,26 +18,22 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qstring.h>
-#include <qpushbutton.h>
-#include <qtextedit.h>
-#include <qpainter.h>
-#include <qevent.h>
 #include <qmessagebox.h>
-#include <qcheckbox.h>
-#include <qbuttongroup.h>
 
+#include <rdapplication.h>
 #include <rddb.h>
-#include <edit_ttys.h>
+#include <rdescape_string.h>
+#include <rdmatrix.h>
 #include <rdstation.h>
 #include <rdtextvalidator.h>
-#include <rdmacro.h>
-#include <globals.h>
+
+#include "edit_ttys.h"
+#include "globals.h"
 
 EditTtys::EditTtys(QString station,QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
-  QString str;
+  setModal(true);
 
   //
   // Fix the Window Size
@@ -51,13 +47,7 @@ EditTtys::EditTtys(QString station,QWidget *parent)
   for(int i=0;i<MAX_TTYS;i++) {
     edit_port_modified[i]=false;
   }
-  setCaption(tr("Edit Serial Ports"));
-
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
+  setWindowTitle("RDAdmin- "+tr("Edit Serial Ports"));
 
   //
   // Text Validator
@@ -72,9 +62,9 @@ EditTtys::EditTtys(QString station,QWidget *parent)
   edit_port_box->setInsertionPolicy(QComboBox::NoInsertion);
   connect(edit_port_box,SIGNAL(activated(int)),this,SLOT(idSelectedData()));
   QLabel *label=new QLabel(edit_port_box,tr("Port ID:"),this);
-  label->setGeometry(10,14,60,22);
-  label->setFont(font);
-  label->setAlignment(AlignRight);
+  label->setGeometry(10,10,60,24);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Enable Button
@@ -84,9 +74,9 @@ EditTtys::EditTtys(QString station,QWidget *parent)
   connect(edit_enable_button,SIGNAL(stateChanged(int)),
 	  this,SLOT(enableButtonData(int)));
   label=new QLabel(edit_enable_button,tr("Enabled"),this);
-  label->setGeometry(200,14,60,22);
-  label->setFont(font);
-  label->setAlignment(AlignRight);
+  label->setGeometry(200,10,60,22);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // The TTY Port
@@ -95,9 +85,9 @@ EditTtys::EditTtys(QString station,QWidget *parent)
   edit_port_edit->setGeometry(145,54,100,20);
   edit_port_edit->setValidator(validator);
   edit_port_label=new QLabel(edit_port_edit,tr("TTY Device:"),this);
-  edit_port_label->setGeometry(20,56,120,22);
-  edit_port_label->setFont(font);
-  edit_port_label->setAlignment(AlignRight);
+  edit_port_label->setGeometry(20,54,120,20);
+  edit_port_label->setFont(labelFont());
+  edit_port_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   
   //
   // Baudrate Selector
@@ -106,9 +96,9 @@ EditTtys::EditTtys(QString station,QWidget *parent)
   edit_baudrate_box->setGeometry(145,80,90,24);
   edit_baudrate_box->setInsertionPolicy(QComboBox::NoInsertion);
   edit_baudrate_label=new QLabel(edit_baudrate_box,tr("Baud Rate:"),this);
-  edit_baudrate_label->setGeometry(20,84,120,22);
-  edit_baudrate_label->setFont(font);
-  edit_baudrate_label->setAlignment(AlignRight);
+  edit_baudrate_label->setGeometry(20,80,120,24);
+  edit_baudrate_label->setFont(labelFont());
+  edit_baudrate_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Parity Selector
@@ -117,9 +107,9 @@ EditTtys::EditTtys(QString station,QWidget *parent)
   edit_parity_box->setGeometry(145,108,90,24); 
   edit_parity_box->setInsertionPolicy(QComboBox::NoInsertion);
   edit_parity_label=new QLabel(edit_parity_box,tr("Parity:"),this);
-  edit_parity_label->setGeometry(20,110,120,22);
-  edit_parity_label->setFont(font);
-  edit_parity_label->setAlignment(AlignRight);
+  edit_parity_label->setGeometry(20,108,120,24);
+  edit_parity_label->setFont(labelFont());
+  edit_parity_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Data Bits Selector
@@ -128,9 +118,9 @@ EditTtys::EditTtys(QString station,QWidget *parent)
   edit_databits_box->setGeometry(145,136,60,24);
   edit_databits_box->setInsertionPolicy(QComboBox::NoInsertion);
   edit_databits_label=new QLabel(edit_databits_box,tr("Data Bits:"),this);
-  edit_databits_label->setGeometry(20,138,120,22);
-  edit_databits_label->setFont(font);
-  edit_databits_label->setAlignment(AlignRight);
+  edit_databits_label->setGeometry(20,136,120,24);
+  edit_databits_label->setFont(labelFont());
+  edit_databits_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Stop Bits Selector
@@ -139,9 +129,9 @@ EditTtys::EditTtys(QString station,QWidget *parent)
   edit_stopbits_box->setGeometry(145,164,60,24);
   edit_stopbits_box->setInsertionPolicy(QComboBox::NoInsertion);
   edit_stopbits_label=new QLabel(edit_stopbits_box,tr("Stop Bits:"),this);
-  edit_stopbits_label->setGeometry(20,166,120,22);
-  edit_stopbits_label->setFont(font);
-  edit_stopbits_label->setAlignment(AlignRight);
+  edit_stopbits_label->setGeometry(20,164,120,24);
+  edit_stopbits_label->setFont(labelFont());
+  edit_stopbits_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Termination Character Selector
@@ -151,25 +141,24 @@ EditTtys::EditTtys(QString station,QWidget *parent)
   edit_termination_box->setInsertionPolicy(QComboBox::NoInsertion);
   edit_termination_label=
     new QLabel(edit_termination_box,tr("Terminator:"),this);
-  edit_termination_label->setGeometry(20,194,120,22);
-  edit_termination_label->setFont(font);
-  edit_termination_label->setAlignment(AlignRight);
+  edit_termination_label->setGeometry(20,192,120,24);
+  edit_termination_label->setFont(labelFont());
+  edit_termination_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   //  Close Button
   //
   QPushButton *close_button=new QPushButton(this);
   close_button->setGeometry(210,230,80,50);
-  close_button->setFont(font);
+  close_button->setFont(buttonFont());
   close_button->setText(tr("&Close"));
   connect(close_button,SIGNAL(clicked()),this,SLOT(closeData()));
 
   //
   // Populate Data
   //
-  str=QString(tr("Serial"));
   for(int i=0;i<MAX_TTYS;i++) {
-    edit_port_box->insertItem(QString().sprintf("%s%d",(const char *)str,i));
+    edit_port_box->insertItem(tr("Serial")+QString().sprintf("%d",i));
   }
   edit_baudrate_box->insertItem("50");
   edit_baudrate_box->insertItem("75");
@@ -253,6 +242,34 @@ void EditTtys::idSelectedData()
 
 void EditTtys::enableButtonData(int state)
 {
+  QString sql;
+  RDSqlQuery *q;
+
+  if(!state) {
+    sql=QString("select ")+
+      "NAME,"+    // 00
+      "MATRIX,"+  // 01
+      "TYPE "+    // 02
+      "from MATRICES where "+
+      "STATION_NAME=\""+RDEscapeString(edit_station)+"\" && "+
+      QString().sprintf("(PORT_TYPE=%d && PORT=%d) || ",
+			RDMatrix::TtyPort,edit_port_box->currentIndex())+
+      QString().sprintf("(PORT_TYPE_2=%d && PORT_2=%d)",
+			RDMatrix::TtyPort,edit_port_box->currentIndex());
+    q=new RDSqlQuery(sql);
+    if(q->first()) {
+      QMessageBox::information(this,"RDAdmin - "+tr("Error"),
+			       tr("This port is currently in use by the following Switcher/GPIO device")+":\n"+
+			       "\t"+tr("Matrix")+QString().sprintf(": %d.\n",q->value(1).toInt())+
+			       "\t"+tr("Type")+": "+RDMatrix::typeString((RDMatrix::Type)q->value(2).toInt())+"\n"+
+			       "\t"+tr("Description")+": "+q->value(0).toString());
+      delete q;
+      edit_enable_button->setChecked(true);
+      return;
+    }
+    delete q;
+  }
+
   if(state==0) {  // Off
     SetEnable(false);
   }
@@ -277,21 +294,20 @@ void EditTtys::closeData()
   macro.setCommand(RDMacro::SY);
   macro.setRole(RDMacro::Cmd);
   macro.setEchoRequested(false);
-  macro.setArgQuantity(1);
   for(int i=0;i<MAX_TTYS;i++) {
     if(edit_port_modified[i]) {
       sql=QString().sprintf("select MATRIX from MATRICES where PORT=%d",i);
       q=new RDSqlQuery(sql);
       if(q->first()) {
 	macro.setCommand(RDMacro::SZ);
-	macro.setArg(0,q->value(0).toInt());
+	macro.addArg(q->value(0).toInt());
       }
       else {
 	macro.setCommand(RDMacro::SY);
-	macro.setArg(0,i);
+	macro.addArg(i);
       }
       macro.setAddress(rmt_station->address());
-      rdripc->sendRml(&macro);
+      rda->ripc()->sendRml(&macro);
       delete q;
     }
   }
@@ -309,63 +325,81 @@ void EditTtys::ReadRecord(int id)
   edit_tty=new RDTty(edit_station,id,true);
   edit_port_edit->setText(edit_tty->port());
   switch(edit_tty->baudRate()) {
-      case 50:
-	edit_baudrate_box->setCurrentItem(0);
-	break;
-      case 75:
-	edit_baudrate_box->setCurrentItem(1);
-	break;
-      case 110:
-	edit_baudrate_box->setCurrentItem(2);
-	break;
-      case 134:
-	edit_baudrate_box->setCurrentItem(3);
-	break;
-      case 150:
-	edit_baudrate_box->setCurrentItem(4);
-	break;
-      case 200:
-	edit_baudrate_box->setCurrentItem(5);
-	break;
-      case 300:
-	edit_baudrate_box->setCurrentItem(6);
-	break;
-      case 600:
-	edit_baudrate_box->setCurrentItem(7);
-	break;
-      case 1200:
-	edit_baudrate_box->setCurrentItem(8);
-	break;
-      case 1800:
-	edit_baudrate_box->setCurrentItem(9);
-	break;
-      case 2400:
-	edit_baudrate_box->setCurrentItem(10);
-	break;
-      case 4800:
-	edit_baudrate_box->setCurrentItem(11);
-	break;
-      case 9600:
-	edit_baudrate_box->setCurrentItem(12);
-	break;
-      case 19200:
-	edit_baudrate_box->setCurrentItem(13);
-	break;
-      case 38400:
-	edit_baudrate_box->setCurrentItem(14);
-	break;
-      case 57600:
-	edit_baudrate_box->setCurrentItem(15);
-	break;
-      case 115200:
-	edit_baudrate_box->setCurrentItem(16);
-	break;
-      case 230400:
-	edit_baudrate_box->setCurrentItem(17);
-	break;
-      default:
-	edit_baudrate_box->setCurrentItem(12);
-	break;	
+  case 50:
+    edit_baudrate_box->setCurrentItem(0);
+    break;
+
+  case 75:
+    edit_baudrate_box->setCurrentItem(1);
+    break;
+
+  case 110:
+    edit_baudrate_box->setCurrentItem(2);
+    break;
+
+  case 134:
+    edit_baudrate_box->setCurrentItem(3);
+    break;
+
+  case 150:
+    edit_baudrate_box->setCurrentItem(4);
+    break;
+
+  case 200:
+    edit_baudrate_box->setCurrentItem(5);
+    break;
+
+  case 300:
+    edit_baudrate_box->setCurrentItem(6);
+    break;
+
+  case 600:
+    edit_baudrate_box->setCurrentItem(7);
+    break;
+
+  case 1200:
+    edit_baudrate_box->setCurrentItem(8);
+    break;
+
+  case 1800:
+    edit_baudrate_box->setCurrentItem(9);
+    break;
+
+  case 2400:
+    edit_baudrate_box->setCurrentItem(10);
+    break;
+
+  case 4800:
+    edit_baudrate_box->setCurrentItem(11);
+    break;
+
+  case 9600:
+    edit_baudrate_box->setCurrentItem(12);
+    break;
+
+  case 19200:
+    edit_baudrate_box->setCurrentItem(13);
+    break;
+
+  case 38400:
+    edit_baudrate_box->setCurrentItem(14);
+    break;
+
+  case 57600:
+    edit_baudrate_box->setCurrentItem(15);
+    break;
+
+  case 115200:
+    edit_baudrate_box->setCurrentItem(16);
+    break;
+
+  case 230400:
+    edit_baudrate_box->setCurrentItem(17);
+    break;
+
+  default:
+    edit_baudrate_box->setCurrentItem(12);
+    break;	
   }
   edit_parity_box->setCurrentItem(edit_tty->parity());
   edit_databits_box->setCurrentItem(edit_tty->dataBits()-5);
