@@ -2,7 +2,7 @@
 //
 // List Rivendell Feeds
 //
-//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,9 +22,10 @@
 #include <unistd.h>
 #include <stdlib.h>
 
+#include <qapplication.h>
 #include <qlabel.h>
 #include <qmessagebox.h>
-#include <qapplication.h>
+#include <qprogressdialog.h>
 
 #include <rdapplication.h>
 #include <rddb.h>
@@ -219,15 +220,14 @@ void ListFeeds::deleteData()
   RDPodcast *cast;
   sql=QString().sprintf("select ID from PODCASTS where FEED_ID=%d",item->id());
   q=new RDSqlQuery(sql);
-  Q3ProgressDialog *pd=
-    new Q3ProgressDialog(tr("Deleting Audio..."),tr("Cancel"),q->size()+1,this,
-			 NULL);
-  pd->setCaption(tr("Deleting"));
-  pd->setProgress(0);
+  QProgressDialog *pd=new QProgressDialog(tr("Deleting Audio..."),tr("Cancel"),
+					  0,q->size()+1,this);
+  pd->setWindowTitle("RDAdmin - "+tr("Deleting"));
+  pd->setValue(0);
   qApp->processEvents();
   sleep(1);
   while(q->next()) {
-    pd->setProgress(pd->progress()+1);
+    pd->setValue(pd->value()+1);
     qApp->processEvents();
     cast=new RDPodcast(rda->config(),q->value(0).toUInt());
     cast->removeAudio(feed,&errs,rda->config()->logXloadDebugData());
