@@ -2,7 +2,7 @@
 //
 // List Rivendell GPIs
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,16 +21,15 @@
 #ifndef LIST_GPIS_H
 #define LIST_GPIS_H
 
-#include <qdialog.h>
-#include <qsqldatabase.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
-#include <qlistview.h>
+#include <q3listview.h>
 
-#include <rduser.h>
+#include <rddialog.h>
 #include <rdmatrix.h>
+#include <rduser.h>
 
-class ListGpis : public QDialog
+class ListGpis : public RDDialog
 {
  Q_OBJECT
  public:
@@ -40,7 +39,7 @@ class ListGpis : public QDialog
 
  private slots:
   void editData();
-  void doubleClickedData(QListViewItem *,const QPoint &,int);
+  void doubleClickedData(Q3ListViewItem *,const QPoint &,int);
   void okData();
   void cancelData();
 
@@ -51,7 +50,7 @@ class ListGpis : public QDialog
   RDMatrix *list_matrix;
   RDMatrix::GpioType list_type;
   QString list_tablename;
-  QListView *list_list_view;
+  Q3ListView *list_list_view;
   QLabel *list_list_label;
   int list_size;
   QPushButton *list_edit_button;
