@@ -1,10 +1,8 @@
 // view_node_info.h
 //
-// Edit a Rivendell LiveWire Node
+// Edit a Rivendell Livewire Node
 //
-//   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: view_node_info.h,v 1.3 2010/07/29 19:32:35 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,21 +21,18 @@
 #ifndef VIEW_NODE_INFO_H
 #define VIEW_NODE_INFO_H
 
-#include <qdialog.h>
 #include <qlineedit.h>
-#include <qspinbox.h>
-#include <qdialog.h>
 
-#include <rdlivewire.h>
+#include <rddialog.h>
 #include <rdlistview.h>
 #include <rdlistviewitem.h>
+#include <rdlivewire.h>
 
-
-class ViewNodeInfo : public QDialog
+class ViewNodeInfo : public RDDialog
 {
  Q_OBJECT
  public:
-  ViewNodeInfo(QWidget *parent=0,const char *name=0);
+  ViewNodeInfo(QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
 
