@@ -2,7 +2,7 @@
 //
 // The pie counter widget for Rivendell
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,15 +21,10 @@
 #ifndef PIE_COUNTER_H
 #define PIE_COUNTER_H
 
-#include <qwidget.h>
-#include <qdatetime.h>
 #include <qlabel.h>
-#include <qpixmap.h>
 
-#include <rdlog_line.h>
 #include <rdairplay_conf.h>
-
-#include <mode_display.h>
+#include <rdwidget.h>
 
 //
 // Inner pie timer
@@ -48,7 +43,7 @@
 #define PIE_Y_PADDING 7
 
 
-class PieCounter : public QWidget
+class PieCounter : public RDWidget
 {
  Q_OBJECT
  public:
@@ -67,7 +62,6 @@ class PieCounter : public QWidget
   void start(int offset=0);
   void stop();
   void setLogline(RDLogLine *logline);
-  void setErasePixmap(const QPixmap &pix);
 
  public slots:
   void setOnairFlag(bool state);
@@ -90,10 +84,12 @@ class PieCounter : public QWidget
   RDAirPlayConf::OpMode pie_op_mode;
   RDLogLine::TransType pie_trans_type;
   int air_line;
-  QColor onair_off_color;
+  QPalette time_label_palette;
+  QPalette talk_label_palette;
+  QPalette onair_on_palette;
+  QPalette onair_off_palette;
   RDLogLine *pie_logline;
   QPixmap pie_pixmap;
-  bool pie_onair;
 };
 
 #endif
