@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>EditEvent</name>
     <message>
@@ -205,59 +207,59 @@
     <name>ListLog</name>
     <message>
         <source>EST TIME</source>
-        <translation>OMTR TID</translation>
+        <translation type="obsolete">OMTR TID</translation>
     </message>
     <message>
         <source>LEN</source>
-        <translation>LENGD</translation>
+        <translation type="obsolete">LENGD</translation>
     </message>
     <message>
         <source>TRANS</source>
-        <translation>OVERT</translation>
+        <translation type="obsolete">OVERT</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>KORG</translation>
+        <translation type="obsolete">KORG</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TITTEL</translation>
+        <translation type="obsolete">TITTEL</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>ARTIST</translation>
+        <translation type="obsolete">ARTIST</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPPE</translation>
+        <translation type="obsolete">GRUPPE</translation>
     </message>
     <message>
         <source>TIME</source>
-        <translation>TID</translation>
+        <translation type="obsolete">TID</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>KLIENT</translation>
+        <translation type="obsolete">KLIENT</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGENT</translation>
+        <translation type="obsolete">AGENT</translation>
     </message>
     <message>
         <source>LABEL</source>
-        <translation>SELSKAP</translation>
+        <translation type="obsolete">SELSKAP</translation>
     </message>
     <message>
         <source>LINE ID</source>
-        <translation>LINJE-ID</translation>
+        <translation type="obsolete">LINJE-ID</translation>
     </message>
     <message>
         <source>COUNT</source>
-        <translation>TELLING</translation>
+        <translation type="obsolete">TELLING</translation>
     </message>
     <message>
         <source>STATUS</source>
-        <translation>STATUS</translation>
+        <translation type="obsolete">STATUS</translation>
     </message>
     <message>
         <source>Select</source>
@@ -295,11 +297,11 @@ logg</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>Loggen eksisterer</translation>
+        <translation type="obsolete">Loggen eksisterer</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>Loggen finst frå før!</translation>
+        <translation type="obsolete">Loggen finst frå før!</translation>
     </message>
     <message>
         <source>--- end of log ---</source>
@@ -359,7 +361,7 @@ logg</translation>
     </message>
     <message>
         <source>T</source>
-        <translation>S</translation>
+        <translation type="unfinished">S</translation>
     </message>
     <message>
         <source>Pause</source>
@@ -400,7 +402,71 @@ Tail</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ALBUM</source>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Len</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Marker</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Line ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Count</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Status</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Est. Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sch. Time</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -408,19 +474,19 @@ Tail</source>
     <name>ListLogs</name>
     <message>
         <source>Select a Log</source>
-        <translation>Vel ein logg</translation>
+        <translation type="obsolete">Vel ein logg</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NAMN</translation>
+        <translation type="obsolete">NAMN</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>SKILDRING</translation>
+        <translation type="obsolete">SKILDRING</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>TENEST</translation>
+        <translation type="obsolete">TENEST</translation>
     </message>
     <message>
         <source>Load</source>
@@ -436,7 +502,7 @@ Tail</source>
     </message>
     <message>
         <source>Save &amp;As</source>
-        <translation>Lagre &amp;som</translation>
+        <translation type="obsolete">Lagre &amp;som</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -446,6 +512,46 @@ Tail</source>
         <source>Rename Log</source>
         <translation>Døyp om loggen</translation>
     </message>
+    <message>
+        <source>ALL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save As</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log Locked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You must refresh the log before it can be saved.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LogLineBox</name>
@@ -503,7 +609,7 @@ Tail</source>
     </message>
     <message>
         <source>T</source>
-        <translation>S</translation>
+        <translation type="obsolete">S</translation>
     </message>
 </context>
 <context>
@@ -522,7 +628,7 @@ Tail</source>
     </message>
     <message>
         <source>Database Error</source>
-        <translation>Databasefeil</translation>
+        <translation type="obsolete">Databasefeil</translation>
     </message>
     <message>
         <source>ADD</source>
@@ -579,7 +685,7 @@ panel</translation>
     <message>
         <source>LOG
 REFRESHING</source>
-        <translation>LOGGEN
+        <translation type="obsolete">LOGGEN
 LASTAR PÅ NYTT</translation>
     </message>
     <message>
@@ -606,6 +712,30 @@ LASTAR PÅ NYTT</translation>
         <source>Host:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Memory Warning</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to lock all memory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown command option</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Warning</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Main Log channel assignments are invalid!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ModeDisplay</name>
@@ -626,11 +756,11 @@ LASTAR PÅ NYTT</translation>
         <translation>Manuelt</translation>
     </message>
     <message>
-        <source>Aux1</source>
+        <source>A1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Aux2</source>
+        <source>A2</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
