@@ -2,15 +2,12 @@
 //
 //   Events List Widget for RDCatch
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: catch_listview.cpp,v 1.5 2010/09/13 23:14:26 cvs Exp $
+//   (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
 //   published by the Free Software Foundation.
 //
-//
 //   This program is distributed in the hope that it will be useful,
 //   but WITHOUT ANY WARRANTY; without even the implied warranty of
 //   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -20,27 +17,28 @@
 //   License along with this program; if not, write to the Free Software
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-//
 
-#include <qheader.h>
+#include <q3header.h>
+#include <Q3PopupMenu>
+#include <QMouseEvent>
 
+#include <rdapplication.h>
 #include <rdcart.h>
-#include <rdrecording.h>
 #include <rdedit_audio.h>
+#include <rdrecording.h>
 
-#include <globals.h>
-#include <catch_listview.h>
+#include "catch_listview.h"
+#include "globals.h"
 
-
-CatchListView::CatchListView(QWidget *parent,const char *name)
-  : RDListView(parent,name)
+CatchListView::CatchListView(QWidget *parent)
+  : RDListView(parent)
 {
   catch_parent=parent;
 
   //
   // Right-Click Menu
   //
-  catch_menu=new QPopupMenu(NULL,"catch_menu");
+  catch_menu=new Q3PopupMenu(NULL);
   connect(catch_menu,SIGNAL(aboutToShow()),this,SLOT(aboutToShowData()));
   catch_menu->
     insertItem(tr("Edit Cue Markers"),this,SLOT(editAudioMenuData()),0,0);
@@ -57,8 +55,8 @@ void CatchListView::editAudioMenuData()
 {
   RDCart *rdcart=new RDCart(catch_cutname.left(6).toUInt());
   RDEditAudio *edit=
-    new RDEditAudio(rdcart,catch_cutname,catch_cae,catch_user,rdstation_conf,
-		    catch_audition_card,catch_audition_port,1500,-400,this);
+    new RDEditAudio(rdcart,catch_cutname,catch_audition_card,
+		    catch_audition_port,1500,-400,this);
   if(edit->exec()!=-1) {
     rdcart->updateLength();
   }
@@ -69,43 +67,43 @@ void CatchListView::editAudioMenuData()
 
 void CatchListView::contentsMousePressEvent(QMouseEvent *e)
 {
-  QListView::contentsMousePressEvent(e);
-  QListView::contentsMousePressEvent(e);
+  Q3ListView::contentsMousePressEvent(e);
+  Q3ListView::contentsMousePressEvent(e);
   catch_menu_item=selectedItem();
   if(catch_menu_item==NULL) {
     catch_cutname="";
   }
   else {
     switch(catch_menu_item->text(28).toUInt()) {
-	case RDRecording::Recording:
-	case RDRecording::Playout:
-	case RDRecording::Upload:
-	case RDRecording::Download:
-	  catch_cutname=catch_menu_item->text(25);
-	  break;
+    case RDRecording::Recording:
+    case RDRecording::Playout:
+    case RDRecording::Upload:
+    case RDRecording::Download:
+      catch_cutname=catch_menu_item->text(25);
+      break;
 
-	case RDRecording::MacroEvent:
-	case RDRecording::SwitchEvent:
-	  catch_cutname="";
-	  break;
+    case RDRecording::MacroEvent:
+    case RDRecording::SwitchEvent:
+      catch_cutname="";
+      break;
     }
   }
   switch(e->button()) {
-      case QMouseEvent::RightButton:
-	catch_menu->setGeometry(e->globalX(),e->globalY(),
-				catch_menu->sizeHint().width(),
-				catch_menu->sizeHint().height());
-	catch_menu->exec();
-	break;
+  case Qt::RightButton:
+    catch_menu->setGeometry(e->globalX(),e->globalY(),
+			    catch_menu->sizeHint().width(),
+			    catch_menu->sizeHint().height());
+    catch_menu->exec();
+    break;
 
-      default:
-	e->ignore();
-	break;
+  default:
+    e->ignore();
+    break;
   }
 }
 
 
 void CatchListView::contentsMouseDoubleClickEvent(QMouseEvent *e)
 {
-  QListView::contentsMouseDoubleClickEvent(e);
+  Q3ListView::contentsMouseDoubleClickEvent(e);
 }
