@@ -2,15 +2,12 @@
 //
 //   Events List Widget for RDCatch
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: catch_listview.h,v 1.2 2007-02-14 21:53:27 fredg Exp $
+//   (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
 //   published by the Free Software Foundation.
 //
-//
 //   This program is distributed in the hope that it will be useful,
 //   but WITHOUT ANY WARRANTY; without even the implied warranty of
 //   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -20,22 +17,20 @@
 //   License along with this program; if not, write to the Free Software
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-//
 
 #ifndef CATCH_LISTVIEW_H
 #define CATCH_LISTVIEW_H
 
-#include <qpopupmenu.h>
+#include <q3popupmenu.h>
 
 #include <rdlistview.h>
 
-
 class CatchListView : public RDListView
 {
   Q_OBJECT
 
  public:
-  CatchListView(QWidget *parent,const char *name=0);
+  CatchListView(QWidget *parent);
 
  private slots:
   void aboutToShowData();
@@ -46,8 +41,8 @@ class CatchListView : public RDListView
   void contentsMouseDoubleClickEvent(QMouseEvent *e);
 
  private:
-  QPopupMenu *catch_menu;
-  QListViewItem *catch_menu_item;
+  Q3PopupMenu *catch_menu;
+  Q3ListViewItem *catch_menu_item;
   QString catch_cutname;
   QWidget *catch_parent;
 };
