@@ -2,9 +2,7 @@
 //
 //   The audio card subsystem for the HPI Library.
 //
-//   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
-//
-//    $Id: rdhpisoundcard.cpp,v 1.10.6.3 2012/08/07 15:48:04 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -19,18 +17,22 @@
 //   License along with this program; if not, write to the Free Software
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-//
 
 #include <syslog.h>
-
-#include <qtimer.h>
-#include <rdhpisoundcard.h>
-
 #include <unistd.h>
 
-RDHPISoundCard::RDHPISoundCard(QObject *parent,const char *name)
-  : QObject(parent,name)
+#include <qtimer.h>
+#include <unistd.h>
+
+#include <rdapplication.h>
+
+#include "rdhpisoundcard.h"
+
+RDHPISoundCard::RDHPISoundCard(RDConfig *config,QObject *parent)
+  : QObject(parent)
 {
+  card_config=config;
+
   card_quantity=0;
   fade_type=RDHPISoundCard::Log;
   for(int i=0;i<HPI_MAX_ADAPTERS;i++) {
@@ -166,22 +168,25 @@ bool RDHPISoundCard::setClockSource(int card,RDHPISoundCard::ClockSource src)
   hpi_err_t hpi_err=0;
 
   switch(src) {
-      case RDHPISoundCard::Internal:
-	hpi_err=HPI_SampleClock_SetSource(NULL,
-					  clock_source_control[card],
-					  HPI_SAMPLECLOCK_SOURCE_LOCAL);
-	break;
-      case RDHPISoundCard::AesEbu:
-      case RDHPISoundCard::SpDiff:
-	hpi_err=HPI_SampleClock_SetSource(NULL,
-					  clock_source_control[card],
-					  HPI_SAMPLECLOCK_SOURCE_AESEBU_SYNC);
-	break;
-      case RDHPISoundCard::WordClock:
-	hpi_err=HPI_SampleClock_SetSource(NULL,
-					  clock_source_control[card],
-					  HPI_SAMPLECLOCK_SOURCE_WORD);
-	break;
+  case RDHPISoundCard::Internal:
+    hpi_err=HPI_SampleClock_SetSource(NULL,
+				      clock_source_control[card],
+				      HPI_SAMPLECLOCK_SOURCE_LOCAL);
+    break;
+
+  case RDHPISoundCard::AesEbu:
+  case RDHPISoundCard::SpDiff:
+    hpi_err=LogHpi(HPI_SampleClock_SetSource(NULL,
+					     clock_source_control[card],
+					     HPI_SAMPLECLOCK_SOURCE_AESEBU_SYNC),__LINE__);
+    break;
+
+  case RDHPISoundCard::WordClock:
+    hpi_err=LogHpi(HPI_SampleClock_SetSource(NULL,
+					     clock_source_control[card],
+					     HPI_SAMPLECLOCK_SOURCE_WORD),
+		   __LINE__);
+    break;
   }
   return hpi_err==0;
 }
@@ -189,36 +194,60 @@ bool RDHPISoundCard::setClockSource(int card,RDHPISoundCard::ClockSource src)
 
 bool RDHPISoundCard::haveTimescaling(int card) const
 {
+  if(card>=HPI_MAX_ADAPTERS) {
+    return false;
+  }
+
   return timescale_support[card];
 }
 
 
 bool RDHPISoundCard::haveInputVolume(int card,int stream,int port) const
 {
+  if(card>=HPI_MAX_ADAPTERS||stream>=HPI_MAX_STREAMS||port>=HPI_MAX_NODES) {
+    return false;
+  }
+
   return input_stream_volume[card][stream][port];
 }
 
 
 bool RDHPISoundCard::haveOutputVolume(int card,int stream,int port) const
 {
+  if(card>=HPI_MAX_ADAPTERS||stream>=HPI_MAX_STREAMS||port>=HPI_MAX_NODES) {
+    return false;
+  }
+
   return output_stream_volume[card][stream][port];
 }
 
 
 bool RDHPISoundCard::haveInputLevel(int card,int port) const
 {
+  if(card>=HPI_MAX_ADAPTERS||port>=HPI_MAX_NODES) {
+    return false;
+  }
+
   return input_port_level[card][port];
 }
 
 
 bool RDHPISoundCard::haveOutputLevel(int card,int port) const
 {
+  if(card>=HPI_MAX_ADAPTERS||port>=HPI_MAX_NODES) {
+    return false;
+  }
+
   return output_port_level[card][port];
 }
 
 
 bool RDHPISoundCard::haveInputStreamVOX(int card,int stream) const
 {
+  if(card>=HPI_MAX_ADAPTERS||stream>=HPI_MAX_STREAMS) {
+    return false;
+  }
+
   return input_stream_vox[card][stream];
 }
 
@@ -229,7 +258,7 @@ RDHPISoundCard::SourceNode RDHPISoundCard::getInputPortMux(int card,int port)
   uint16_t index;
 
   LogHpi(HPI_Multiplexer_GetSource(NULL,input_mux_control[card][port],
-				   &type,&index));
+				   &type,&index),__LINE__);
   return (RDHPISoundCard::SourceNode)type;
 }
 
@@ -237,23 +266,25 @@ RDHPISoundCard::SourceNode RDHPISoundCard::getInputPortMux(int card,int port)
 bool RDHPISoundCard::setInputPortMux(int card,int port,RDHPISoundCard::SourceNode node)
 {
   switch(node) {
-      case RDHPISoundCard::LineIn:
-	if(HPI_Multiplexer_SetSource(NULL,
-				     input_mux_control[card][port],
-				     node,0)!=0) {
-	  return false;
-	}
-	break;
-      case RDHPISoundCard::AesEbuIn:
-	if(HPI_Multiplexer_SetSource(NULL,
-				     input_mux_control[card][port],node,
-				     input_mux_index[card][port][1])!=0) {
-	  return false;
-	}
-	break;
-      default:
-	return false;
-	break;
+  case RDHPISoundCard::LineIn:
+    if(HPI_Multiplexer_SetSource(NULL,
+				 input_mux_control[card][port],node,0)!=0) {
+      return false;
+    }
+    break;
+
+  case RDHPISoundCard::AesEbuIn:
+    if(LogHpi(HPI_Multiplexer_SetSource(NULL,
+					input_mux_control[card][port],node,
+					input_mux_index[card][port][1]),
+	      __LINE__)!=0) {
+      return false;
+    }
+    break;
+
+  default:
+    return false;
+    break;
   }
   return true;
 }
@@ -264,9 +295,15 @@ unsigned short RDHPISoundCard::getInputPortError(int card,int port)
   uint16_t error_word=0;
 
   if(input_port_aesebu[card][port]) {
-    LogHpi(HPI_AESEBU_Receiver_GetErrorStatus(NULL,
-					input_port_aesebu_control[card][port],
-					      &error_word));
+    if(HPI_AESEBU_Receiver_GetErrorStatus(NULL,
+					  input_port_aesebu_control[card][port],
+					  &error_word)==0) {
+      //
+      // Do nothing
+      //
+      // Needed to suppress the goofy 'result unused' compiler warnings.
+      //
+    }
   }
   return error_word;
 }
@@ -282,16 +319,23 @@ void RDHPISoundCard::setFadeProfile(RDHPISoundCard::FadeProfile profile)
 {
   fade_type=profile;
   switch(fade_type) {
-      case RDHPISoundCard::Linear:
-	hpi_fade_type=HPI_VOLUME_AUTOFADE_LINEAR;
-	break;
-      case RDHPISoundCard::Log:
-	hpi_fade_type=HPI_VOLUME_AUTOFADE_LOG;
-	break;
+  case RDHPISoundCard::Linear:
+    hpi_fade_type=HPI_VOLUME_AUTOFADE_LINEAR;
+    break;
+
+  case RDHPISoundCard::Log:
+    hpi_fade_type=HPI_VOLUME_AUTOFADE_LOG;
+    break;
   }
 }
 
 
+RDConfig *RDHPISoundCard::config() const
+{
+  return card_config;
+}
+
+
 bool RDHPISoundCard::haveInputStreamMeter(int card,int stream) const
 {
   return input_stream_meter[card][stream];
@@ -369,7 +413,8 @@ bool RDHPISoundCard::inputStreamMeter(int card,int stream,short *level)
     return false;
   }
   LogHpi(HPI_MeterGetPeak(NULL,
-			  input_stream_meter_control[card][stream],level));
+			  input_stream_meter_control[card][stream],level),
+	 __LINE__);
   return true;
 }
 
@@ -382,8 +427,8 @@ bool RDHPISoundCard::outputStreamMeter(int card,int stream,short *level)
   if(stream>=card_output_streams[card]) {
     return false;
   }
-  LogHpi(HPI_MeterGetPeak(NULL,
-			  output_stream_meter_control[card][stream],level));
+  LogHpi(HPI_MeterGetPeak(NULL,output_stream_meter_control[card][stream],
+			  level),__LINE__);
   return true;
 }
 
@@ -396,8 +441,8 @@ bool RDHPISoundCard::inputPortMeter(int card,int port,short *level)
   if(port>=card_input_ports[card]) {
     return false;
   }
-  LogHpi(HPI_MeterGetPeak(NULL,
-			  input_port_meter_control[card][port],level));
+  LogHpi(HPI_MeterGetPeak(NULL,input_port_meter_control[card][port],level),
+	 __LINE__);
   return true;
 }
 
@@ -410,7 +455,8 @@ bool RDHPISoundCard::outputPortMeter(int card,int port,short *level)
   if(port>=card_output_ports[card]) {
     return false;
   }
-  LogHpi(HPI_MeterGetPeak(NULL,output_port_meter_control[card][port],level));
+  LogHpi(HPI_MeterGetPeak(NULL,output_port_meter_control[card][port],level),
+	 __LINE__);
   return true;
 }
 
@@ -436,15 +482,17 @@ bool RDHPISoundCard::haveInputPortMux(int card,int port) const
 bool RDHPISoundCard::queryInputPortMux(int card,int port,SourceNode node) const
 {
   switch(node) {
-      case RDHPISoundCard::LineIn:
-	return input_port_mux_type[card][port][0];
-	break;
-      case RDHPISoundCard::AesEbuIn:
-	return input_port_mux_type[card][port][1];
-	break;
-      default:
-	return false;
-	break;
+  case RDHPISoundCard::LineIn:
+    return input_port_mux_type[card][port][0];
+    break;
+
+  case RDHPISoundCard::AesEbuIn:
+    return input_port_mux_type[card][port][1];
+    break;
+
+  default:
+    return false;
+    break;
   }
 }
 
@@ -459,8 +507,8 @@ int RDHPISoundCard::getInputVolume(int card,int stream,int port)
 {
   short gain[2];
 
-  LogHpi(HPI_VolumeGetGain(NULL,
-			input_stream_volume_control[card][stream][port],gain));
+  LogHpi(HPI_VolumeGetGain(NULL,input_stream_volume_control[card][stream][port],
+			   gain),__LINE__);
   return gain[0];
 }
 
@@ -469,8 +517,7 @@ int RDHPISoundCard::getOutputVolume(int card,int stream,int port)
 {
   short gain[2];
 
-  LogHpi(HPI_VolumeGetGain(NULL,
-			output_stream_volume_control[card][stream][port],gain));
+  LogHpi(HPI_VolumeGetGain(NULL,output_stream_volume_control[card][stream][port],gain),__LINE__);
   return gain[0];
 }
 
@@ -479,7 +526,8 @@ int RDHPISoundCard::getInputLevel(int card,int port)
 {
   short gain[2];
 
-  LogHpi(HPI_VolumeGetGain(NULL,input_port_level_control[card][port],gain));
+  LogHpi(HPI_VolumeGetGain(NULL,input_port_level_control[card][port],gain),
+	 __LINE__);
   return gain[0];
 }
 
@@ -488,7 +536,8 @@ int RDHPISoundCard::getOutputLevel(int card,int port)
 {
   short gain[2];
 
-  LogHpi(HPI_VolumeGetGain(NULL,output_port_level_control[card][port],gain));
+  LogHpi(HPI_VolumeGetGain(NULL,output_port_level_control[card][port],gain),
+	 __LINE__);
   return gain[0];
 }
 
@@ -502,8 +551,8 @@ void RDHPISoundCard::setInputVolume(int card,int stream,int level)
   short gain[2];
   gain[0]=level;
   gain[1]=level;
-  LogHpi(HPI_VolumeSetGain(NULL,
-			   input_stream_volume_control[card][stream][0],gain));
+  LogHpi(HPI_VolumeSetGain(NULL,input_stream_volume_control[card][stream][0],
+			   gain),__LINE__);
 }
 
 
@@ -517,7 +566,7 @@ void RDHPISoundCard::setOutputVolume(int card,int stream,int port,int level)
   gain[1]=level;
   LogHpi(HPI_VolumeSetGain(NULL,
 			   output_stream_volume_control[card][stream][port],
-			   gain));
+			   gain),__LINE__);
 }
 
 
@@ -534,7 +583,7 @@ void RDHPISoundCard::fadeOutputVolume(int card,int stream,int port,
   gain[1]=level;
   LogHpi(HPI_VolumeAutoFadeProfile(NULL,
 			      output_stream_volume_control[card][stream][port],
-				   gain,length,hpi_fade_type));
+				   gain,length,hpi_fade_type),__LINE__);
 }
 
 
@@ -548,7 +597,8 @@ void RDHPISoundCard::setInputLevel(int card,int port,int level)
   for(unsigned i=0;i<HPI_MAX_CHANNELS;i++) {
     gain[i]=level;
   }
-  LogHpi(HPI_LevelSetGain(NULL,input_port_level_control[card][port],gain));
+  LogHpi(HPI_LevelSetGain(NULL,input_port_level_control[card][port],gain),
+	 __LINE__);
 }
 
 
@@ -562,7 +612,8 @@ void RDHPISoundCard::setOutputLevel(int card,int port,int level)
   for(unsigned i=0;i<HPI_MAX_CHANNELS;i++) {
     gain[i]=level;
   }
-  LogHpi(HPI_LevelSetGain(NULL,output_port_level_control[card][port],gain));
+  LogHpi(HPI_LevelSetGain(NULL,output_port_level_control[card][port],gain),
+	 __LINE__);
 }
 
 
@@ -572,7 +623,8 @@ void RDHPISoundCard::setInputMode(int card,int port,
   if(!haveInputMode(card,port)) {
     return;
   }
-  LogHpi(HPI_ChannelModeSet(NULL,input_port_mode_control[card][port],mode+1));
+  LogHpi(HPI_ChannelModeSet(NULL,input_port_mode_control[card][port],mode+1),
+	 __LINE__);
 }
 
 
@@ -583,13 +635,14 @@ void RDHPISoundCard::setOutputMode(int card,int stream,
     return;
   }
   LogHpi(HPI_ChannelModeSet(NULL,output_stream_mode_control[card][stream],
-			    mode+1));
+			    mode+1),__LINE__);
 }
 
 
 void RDHPISoundCard::setInputStreamVOX(int card,int stream,short gain)
 {
-  LogHpi(HPI_VoxSetThreshold(NULL,input_stream_vox_control[card][stream],gain));
+  LogHpi(HPI_VoxSetThreshold(NULL,input_stream_vox_control[card][stream],gain),
+	 __LINE__);
 }
 
 
@@ -610,7 +663,7 @@ bool RDHPISoundCard::setPassthroughVolume(int card,int in_port,int out_port,
   gain[1]=level;
   LogHpi(HPI_VolumeSetGain(NULL,
 		       passthrough_port_volume_control[card][in_port][out_port],
-			   gain));
+			   gain),__LINE__);
   return true;
 }
 
@@ -647,18 +700,19 @@ void RDHPISoundCard::HPIProbe()
 
   hpi_fade_type=HPI_VOLUME_AUTOFADE_LOG;
 #if HPI_VER < 0x00030600
-  LogHpi(HPI_SubSysGetVersion(NULL,&dummy_hpi));
-  HPI_SubSysFindAdapters(NULL,(uint16_t *)&card_quantity,
-			 hpi_adapter_list,HPI_MAX_ADAPTERS);  
+  LogHpi(HPI_SubSysGetVersion(NULL,&dummy_hpi),__LINE__);
+  LogHpi(HPI_SubSysFindAdapters(NULL,(uint16_t *)&card_quantity,
+				hpi_adapter_list,HPI_MAX_ADAPTERS),__LINE__);  
 #else
-  LogHpi(HPI_SubSysGetVersionEx(NULL,&dummy_hpi));
-  LogHpi(HPI_SubSysGetNumAdapters(NULL,&card_quantity));
+  LogHpi(HPI_SubSysGetVersionEx(NULL,&dummy_hpi),__LINE__);
+  LogHpi(HPI_SubSysGetNumAdapters(NULL,&card_quantity),__LINE__);
 #endif  // HPI_VER
   for(int i=0;i<card_quantity;i++) {
 #if HPI_VER < 0x00030600
     card_index[i]=i;
 #else
-    LogHpi(HPI_SubSysGetAdapter(NULL,i,card_index+i,hpi_adapter_list+i));
+    LogHpi(HPI_SubSysGetAdapter(NULL,i,card_index+i,hpi_adapter_list+i),
+	   __LINE__);
 #endif  // HPI_VER
     if((hpi_adapter_list[i]&0xF000)==0x6000) { 
       timescale_support[i]=true;
@@ -667,35 +721,32 @@ void RDHPISoundCard::HPIProbe()
       timescale_support[i]=false;
     }
     switch(hpi_adapter_list[i]) {
-	case 0x5111:
-	  input_mux_type[i]=true;
-	  break;
+    case 0x5111:
+    case 0x5211:
+      input_mux_type[i]=true;
+      break;
 
-	default:
-	  input_mux_type[i]=false;
-	  break;
+    default:
+      input_mux_type[i]=false;
+      break;
     }
     card_input_ports[i]=0;
     card_output_ports[i]=0;
     card_description[i]=QString().sprintf("AudioScience %04X [%d]",
 					  hpi_adapter_list[i],i+1);
-    LogHpi(HPI_AdapterOpen(NULL,card_index[i]));
+    LogHpi(HPI_AdapterOpen(NULL,card_index[i]),__LINE__);
     LogHpi(HPI_AdapterGetInfo(NULL,card_index[i],
 			      &card_output_streams[i],
 			      &card_input_streams[i],
 			      &dummy_version,(uint32_t *)&dummy_serial,
-			      &dummy_type));
+			      &dummy_type),__LINE__);
     hpi_info[i].setSerialNumber(dummy_serial);
     hpi_info[i].setHpiVersion(dummy_hpi);
-    /*
-    hpi_info[i].setHpiMajorVersion(dummy_hpi>>8);
-    hpi_info[i].setHpiMinorVersion(dummy_hpi&255);
-    */
     hpi_info[i].setDspMajorVersion((dummy_version>>13)&7);
     hpi_info[i].setDspMinorVersion((dummy_version>>7)&63);
     hpi_info[i].setPcbVersion((char)(((dummy_version>>3)&7)+'A'));
     hpi_info[i].setAssemblyVersion(dummy_version&7);
-    LogHpi(HPI_AdapterClose(NULL,card_index[i]));
+    LogHpi(HPI_AdapterClose(NULL,card_index[i]),__LINE__);
     str=QString(tr("Input Stream"));
     for(int j=0;j<card_input_streams[i];j++) {
       input_stream_description[i][j]=
@@ -714,7 +765,7 @@ void RDHPISoundCard::HPIProbe()
   // Mixer Initialization
   //
   for(int i=0;i<card_quantity;i++) {
-    LogHpi(HPI_MixerOpen(NULL,card_index[i],&hpi_mixer[i]));
+    LogHpi(HPI_MixerOpen(NULL,card_index[i],&hpi_mixer[i]),__LINE__);
 
     //
     // Get Input Ports
@@ -749,11 +800,16 @@ void RDHPISoundCard::HPIProbe()
     //
     str=QString(tr("Output Port"));
     for(int k=0;k<HPI_MAX_NODES;k++) {
-      if(HPI_MixerGetControl(NULL,hpi_mixer[i],
-			     HPI_SOURCENODE_OSTREAM,0,
-			     HPI_DESTNODE_LINEOUT,k,
-			     HPI_CONTROL_VOLUME,
-			     &output_stream_volume_control[i][0][k])==0) {
+      if((HPI_MixerGetControl(NULL,hpi_mixer[i],
+			      HPI_SOURCENODE_OSTREAM,0,
+			      HPI_DESTNODE_LINEOUT,k,
+			      HPI_CONTROL_VOLUME,
+			      &output_stream_volume_control[i][0][k])==0)||
+	 (HPI_MixerGetControl(NULL,hpi_mixer[i],
+			      HPI_SOURCENODE_OSTREAM,0,
+			      HPI_DESTNODE_AESEBU_OUT,k,
+			      HPI_CONTROL_VOLUME,
+			      &output_stream_volume_control[i][0][k])==0)) {
 	output_stream_volume[i][0][k]=true;
 	card_output_ports[i]++;
 	output_port_description[i][k]=
@@ -766,42 +822,44 @@ void RDHPISoundCard::HPIProbe()
 			       HPI_SOURCENODE_CLOCK_SOURCE,0,
 			       0,0,
 			       HPI_CONTROL_SAMPLECLOCK,
-			       &clock_source_control[i]));
+			       &clock_source_control[i]),__LINE__);
     for(int j=0;j<card_input_streams[i];j++) {
-      if(HPI_MixerGetControl(NULL,hpi_mixer[i],  // VOX Controls
-			     0,0,
-			     HPI_DESTNODE_ISTREAM,j,
-			     HPI_CONTROL_VOX,
-			     &input_stream_vox_control[i][j])==0) {
+      if(LogHpi(HPI_MixerGetControl(NULL,hpi_mixer[i],  // VOX Controls
+				    0,0,
+				    HPI_DESTNODE_ISTREAM,j,
+				    HPI_CONTROL_VOX,
+				    &input_stream_vox_control[i][j]),
+		__LINE__)==0) {
 	input_stream_vox[i][j]=true;
       }
       else {
 	input_stream_vox[i][j]=false;
       }
 
-
       if(input_mux_type[i]) {
-	if(HPI_MixerGetControl(NULL,hpi_mixer[i],  // MUX Controls
-			       0,0,
-			       HPI_DESTNODE_ISTREAM,j,
-			       HPI_CONTROL_MULTIPLEXER,
-			       &input_mux_control[i][j])==0) {
+	if(LogHpi(HPI_MixerGetControl(NULL,hpi_mixer[i],  // MUX Controls
+				      0,0,
+				      HPI_DESTNODE_ISTREAM,j,
+				      HPI_CONTROL_MULTIPLEXER,
+				      &input_mux_control[i][j]),__LINE__)==0) {
 	  input_stream_mux[i][j]=true;
 	  l=0;
 	  input_port_mux_type[i][j][0]=false;
 	  input_port_mux_type[i][j][1]=false;
-	  while(HPI_Multiplexer_QuerySource(NULL,
-					    input_mux_control[i][j],
-					    l++,&type,&index)==0) {
+	  while(LogHpi(HPI_Multiplexer_QuerySource(NULL,
+						   input_mux_control[i][j],
+						   l++,&type,&index),
+		       __LINE__)==0) {
 	    switch(type) {
-		case HPI_SOURCENODE_LINEIN:
-		  input_port_mux_type[i][j][0]=true;
-		  input_mux_index[i][j][0]=index;
-		  break;
-		case HPI_SOURCENODE_AESEBU_IN:
-		  input_port_mux_type[i][j][1]=true;
-		  input_mux_index[i][j][1]=index;
-		  break;
+	    case HPI_SOURCENODE_LINEIN:
+	      input_port_mux_type[i][j][0]=true;
+	      input_mux_index[i][j][0]=index;
+	      break;
+
+	    case HPI_SOURCENODE_AESEBU_IN:
+	      input_port_mux_type[i][j][1]=true;
+	      input_mux_index[i][j][1]=index;
+	      break;
 	    }
 	  }
 	}
@@ -822,11 +880,16 @@ void RDHPISoundCard::HPIProbe()
 	else {
 	  input_stream_volume[i][j][k]=false;
 	}
-	if(HPI_MixerGetControl(NULL,hpi_mixer[i],
-			       HPI_SOURCENODE_OSTREAM,j,
-			       HPI_DESTNODE_LINEOUT,k,
-			       HPI_CONTROL_VOLUME,
-			       &output_stream_volume_control[i][j][k])==0) {
+	if((HPI_MixerGetControl(NULL,hpi_mixer[i],
+				HPI_SOURCENODE_OSTREAM,j,
+				HPI_DESTNODE_LINEOUT,k,
+				HPI_CONTROL_VOLUME,
+				&output_stream_volume_control[i][j][k])==0)||
+	   (HPI_MixerGetControl(NULL,hpi_mixer[i],
+				HPI_SOURCENODE_OSTREAM,j,
+				HPI_DESTNODE_AESEBU_OUT,k,
+				HPI_CONTROL_VOLUME,
+				&output_stream_volume_control[i][j][k])==0)) {
 	  output_stream_volume[i][j][k]=true;
 	}
 	else {
@@ -843,11 +906,12 @@ void RDHPISoundCard::HPIProbe()
       else {
 	input_stream_meter[i][j]=false;
       }
-      if(HPI_MixerGetControl(NULL,hpi_mixer[i],
-			     HPI_SOURCENODE_OSTREAM,j,
-			     0,0,
-			     HPI_CONTROL_METER,
-			     &output_stream_meter_control[i][j])==0) {
+      if(LogHpi(HPI_MixerGetControl(NULL,hpi_mixer[i],
+				    HPI_SOURCENODE_OSTREAM,j,
+				    0,0,
+				    HPI_CONTROL_METER,
+				    &output_stream_meter_control[i][j]),
+		__LINE__)==0) {
 	output_stream_meter[i][j]=true;
       }
       else {
@@ -865,11 +929,16 @@ void RDHPISoundCard::HPIProbe()
       else {
 	input_port_level[i][j]=false;
       }
-      if(HPI_MixerGetControl(NULL,hpi_mixer[i],  // Output Level Controls
-			     0,0,
-			     HPI_DESTNODE_LINEOUT,j,
-			     HPI_CONTROL_LEVEL,
-			     &output_port_level_control[i][j])==0) {
+      if((HPI_MixerGetControl(NULL,hpi_mixer[i],  // Output Level Controls
+			      0,0,
+			      HPI_DESTNODE_LINEOUT,j,
+			      HPI_CONTROL_LEVEL,
+			      &output_port_level_control[i][j])==0)||
+	 (HPI_MixerGetControl(NULL,hpi_mixer[i],
+			      0,0,
+			      HPI_DESTNODE_AESEBU_OUT,j,
+			      HPI_CONTROL_LEVEL,
+			      &output_port_level_control[i][j])==0)) {
 	output_port_level[i][j]=true;
       }
       else {
@@ -885,11 +954,16 @@ void RDHPISoundCard::HPIProbe()
       else {
 	input_port_meter[i][j]=false;
       }
-      if(HPI_MixerGetControl(NULL,hpi_mixer[i],  // Output Port Meter
+      if((HPI_MixerGetControl(NULL,hpi_mixer[i],  // Output Port Meter
 			     0,0,
 			     HPI_DESTNODE_LINEOUT,j,
 			     HPI_CONTROL_METER,
-			     &output_port_meter_control[i][j])==0) {
+			     &output_port_meter_control[i][j])==0)||
+	 (HPI_MixerGetControl(NULL,hpi_mixer[i],
+			      0,0,
+			      HPI_DESTNODE_AESEBU_OUT,j,
+			      HPI_CONTROL_METER,
+			      &output_port_meter_control[i][j])==0)) {
 	output_port_meter[i][j]=true;
       }
       else {
@@ -915,18 +989,18 @@ void RDHPISoundCard::HPIProbe()
 	  l=0;
 	  input_port_mux_type[i][j][0]=false;
 	  input_port_mux_type[i][j][1]=false;
-	  while(HPI_Multiplexer_QuerySource(NULL,
-					    input_mux_control[i][j],
+	  while(HPI_Multiplexer_QuerySource(NULL,input_mux_control[i][j],
 					    l++,&type,&index)==0) {
 	    switch(type) {
-		case HPI_SOURCENODE_LINEIN:
-		  input_port_mux_type[i][j][0]=true;
-		  input_mux_index[i][j][0]=index;
-		  break;
-		case HPI_SOURCENODE_AESEBU_IN:
-		  input_port_mux_type[i][j][1]=true;
-		  input_mux_index[i][j][1]=index;
-		  break;
+	    case HPI_SOURCENODE_LINEIN:
+	      input_port_mux_type[i][j][0]=true;
+	      input_mux_index[i][j][0]=index;
+	      break;
+
+	    case HPI_SOURCENODE_AESEBU_IN:
+	      input_port_mux_type[i][j][1]=true;
+	      input_mux_index[i][j][1]=index;
+	      break;
 	    }
 	  }
 	}
@@ -941,11 +1015,16 @@ void RDHPISoundCard::HPIProbe()
     //
     for(int j=0;j<HPI_MAX_NODES;j++) {
       for(int k=0;k<HPI_MAX_NODES;k++) {
-	if(HPI_MixerGetControl(NULL,hpi_mixer[i],
-			       HPI_SOURCENODE_LINEIN,j,
-			       HPI_DESTNODE_LINEOUT,k,
-			       HPI_CONTROL_VOLUME,
-			       &passthrough_port_volume_control[i][j][k])==0) {
+	if((HPI_MixerGetControl(NULL,hpi_mixer[i],
+				HPI_SOURCENODE_LINEIN,j,
+				HPI_DESTNODE_LINEOUT,k,
+				HPI_CONTROL_VOLUME,
+				&passthrough_port_volume_control[i][j][k])==0)||
+	   (HPI_MixerGetControl(NULL,hpi_mixer[i],
+				HPI_SOURCENODE_LINEIN,j,
+				HPI_DESTNODE_AESEBU_OUT,k,
+				HPI_CONTROL_VOLUME,
+				&passthrough_port_volume_control[i][j][k])==0)) {
 	  passthrough_port_volume[i][j][k]=true;
 	}
 	else {
@@ -960,13 +1039,14 @@ void RDHPISoundCard::HPIProbe()
 }
 
 
-hpi_err_t RDHPISoundCard::LogHpi(hpi_err_t err)
+hpi_err_t RDHPISoundCard::LogHpi(hpi_err_t err,int lineno)
 {
   char err_txt[200];
 
   if(err!=0) {
     HPI_GetErrorText(err,err_txt);
-    syslog(LOG_NOTICE,"HPI Error: %s",err_txt);
+    RDApplication::syslog(card_config,LOG_WARNING,
+			  "HPI Error: %s, %s line %d",err_txt,__FILE__,lineno);
   }
   return err;
 }
