@@ -2,7 +2,7 @@
 //
 // CD Disk Ripper Dialog for Rivendell.
 //
-//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,9 +25,11 @@
 #include <rdcdripper.h>
 #include <rdconf.h>
 #include <rdcut_dialog.h>
+#include <rddisclookup_factory.h>
 #include <rdgroup.h>
 #include <rdlist_groups.h>
 #include <rdtempdirectory.h>
+#include <rdtextfile.h>
 
 #include "disk_ripper.h"
 #include "globals.h"
@@ -36,7 +38,6 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
 		       bool profile_rip,QWidget *parent) 
   : RDDialog(parent)
 {
-  rip_isrc_read=false;
   rip_filter_text=filter;
   rip_group_text=group;
   rip_schedcode_text=schedcode;
@@ -55,20 +56,6 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   //
   rip_wavedata_dialog=new RDWaveDataDialog("RDLibrary",this);
 
-  //
-  // Create Temporary Directory
-  //
-  char path[PATH_MAX];
-  strncpy(path,RDTempDirectory::basePath(),PATH_MAX);
-  strcat(path,"/XXXXXX");
-  if(mkdtemp(path)==NULL) {
-    QMessageBox::warning(this,"RDLibrary - "+tr("Ripper Error"),
-			 tr("Unable to create temporary directory!"));
-  }
-  else {
-    rip_cdda_dir.setPath(path);
-  }
-
   //
   // The CDROM Drive
   //
@@ -86,16 +73,19 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   rip_cdrom->open();
 
   //
-  // CDDB Stuff
+  // Disc Metadata Lookup
   //
   if(rip_profile_rip) {
-    rip_cddb_lookup=new RDCddbLookup("RDLibrary",stdout,this);
+    rip_disc_lookup=RDDiscLookupFactory(rda->libraryConf()->cdServerType(),
+					"RDLibrary",stdout,this);
   }
   else {
-    rip_cddb_lookup=new RDCddbLookup("RDLibrary",NULL,this);
+    rip_disc_lookup=RDDiscLookupFactory(rda->libraryConf()->cdServerType(),
+					"RDLibrary",NULL,this);
   }
-  connect(rip_cddb_lookup,SIGNAL(lookupDone(RDCddbLookup::Result)),
-	  this,SLOT(cddbDoneData(RDCddbLookup::Result)));
+  connect(rip_disc_lookup,
+	  SIGNAL(lookupDone(RDDiscLookup::Result,const QString &)),
+	  this,SLOT(lookupDoneData(RDDiscLookup::Result,const QString &)));
 
   //
   // Artist Label
@@ -126,17 +116,43 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   rip_other_edit->setReadOnly(true);
 
   //
-  // Apply FreeDB Check Box
+  // Apply Lookup Data Check Box
   //
   rip_apply_box=new QCheckBox(this);
   rip_apply_box->setChecked(true);
   rip_apply_box->setDisabled(true);
-  rip_apply_label=
-    new QLabel(rip_apply_box,tr("Apply FreeDB Values to Carts"),this);
+  rip_apply_label=new QLabel(rip_apply_box,tr("Apply")+" "+
+			     rip_disc_lookup->sourceName()+" "+
+			     tr("Values to Carts"),this);
   rip_apply_label->setFont(labelFont());
   rip_apply_label->setAlignment(Qt::AlignLeft);
   rip_apply_box->setChecked(false);
   rip_apply_label->setDisabled(true);
+  rip_apply_box->setVisible(!rip_disc_lookup->sourceName().isNull());
+  rip_apply_label->setVisible(!rip_disc_lookup->sourceName().isNull());
+
+  //
+  // Web Browser Button/Label
+  //
+  rip_browser_button=new QPushButton(this);
+  rip_browser_button->setPixmap(rip_disc_lookup->sourceLogo());
+  rip_browser_button->setDisabled(true);
+  rip_browser_label=new QLabel(this);
+  rip_browser_label->setPixmap(rip_disc_lookup->sourceLogo());
+  rip_browser_label->setDisabled(true);
+  connect(rip_browser_button,SIGNAL(clicked()),this,SLOT(openBrowserData()));
+  if(rip_disc_lookup->sourceLogo().isNull()) {
+    rip_browser_button->hide();
+    rip_browser_label->hide();
+  }
+  else {
+    if(rda->station()->browserPath().isEmpty()) {
+      rip_browser_button->hide();
+    }
+    else {
+      rip_browser_label->hide();
+    }
+  }
 
   //
   // Track List
@@ -326,14 +342,6 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
 
 DiskRipper::~DiskRipper()
 {
-  QStringList files=rip_cdda_dir.entryList();
-  for(int i=0;i<files.size();i++) {
-    if((files[i]!=".")&&(files[i]!="..")) {
-      rip_cdda_dir.remove(files[i]);
-    }
-  }
-  rmdir(rip_cdda_dir.path());
-
   rip_cdrom->close();
   delete rip_cdrom;
   delete rip_track_list;
@@ -402,17 +410,6 @@ void DiskRipper::ripDiskButtonData()
   }
   rip_disk_bar->setMaximum(tracks);
 
-  //
-  // Read ISRCs
-  //
-  if(!rip_isrc_read) {
-    if(rda->libraryConf()->readIsrc()) {
-      rip_cddb_lookup->
-	readIsrc(rip_cdda_dir.path(),rda->libraryConf()->ripperDevice());
-    }
-    rip_isrc_read=true;
-  }
-
   //
   // Set Artist and Album
   //
@@ -477,8 +474,6 @@ void DiskRipper::ripDiskButtonData()
     item=(RDListViewItem *)item->nextSibling();
   }
 
-//  rip_cdrom->eject();
-
   if(rip_aborting) {
     QMessageBox::information(this,tr("Rip Complete"),tr("Rip aborted!"));
   }
@@ -498,6 +493,8 @@ void DiskRipper::ejectedData()
   rip_apply_box->setChecked(false);
   rip_apply_box->setDisabled(true);
   rip_apply_label->setDisabled(true);
+  rip_browser_button->setDisabled(true);
+  rip_browser_label->setDisabled(true);
 }
 
 
@@ -755,9 +752,6 @@ void DiskRipper::mediaChangedData()
 {
   RDListViewItem *l;
 
-  QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-
-  rip_isrc_read=false;
   rip_cutnames.clear();
   rip_end_track.clear();
   for(unsigned i=0;i<rip_wave_datas.size();i++) {
@@ -786,15 +780,11 @@ void DiskRipper::mediaChangedData()
     }
     l->setText(1,RDGetTimeLength(rip_cdrom->trackLength(i)));
   }
-  rip_cddb_record.clear();
-  rip_cdrom->setCddbRecord(&rip_cddb_record);
-  rip_cddb_lookup->setCddbRecord(&rip_cddb_record);
-  rip_cddb_lookup->
-    lookupRecord(rip_cdda_dir.path(),rda->libraryConf()->ripperDevice(),
-		 rda->libraryConf()->cddbServer(),8880,
-		 RIPPER_CDDB_USER,PACKAGE_NAME,VERSION);
+  rip_disc_record.clear();
+  rip_cdrom->setCddbRecord(&rip_disc_record);
+  rip_disc_lookup->setCddbRecord(&rip_disc_record);
 
-  QApplication::restoreOverrideCursor();
+  rip_disc_lookup->lookup();
 }
 
 
@@ -812,36 +802,43 @@ void DiskRipper::stoppedData()
 }
 
 
-void DiskRipper::cddbDoneData(RDCddbLookup::Result result)
+void DiskRipper::lookupDoneData(RDDiscLookup::Result result,
+			      const QString &err_msg)
 {
   switch(result) {
-      case RDCddbLookup::ExactMatch:
-	if(rip_cdrom->status()!=RDCdPlayer::Ok) {
-	  return;
-	}
-	rip_artist_edit->setText(rip_cddb_record.discArtist());
-	rip_album_edit->setText(rip_cddb_record.discAlbum());
-	rip_other_edit->setText(rip_cddb_record.discExtended());
-	for(int i=0;i<rip_cddb_record.tracks();i++) {
-	  rip_track_list->findItem(QString().sprintf("%d",i+1),0)->
-	    setText(2,rip_cddb_record.trackTitle(i));
-	  rip_track_list->findItem(QString().sprintf("%d",i+1),0)->
-	    setText(3,rip_cddb_record.trackExtended(i));
-	  rip_wave_datas[i]->setTitle(rip_cddb_record.trackTitle(i));
-	  rip_wave_datas[i]->setArtist(rip_cddb_record.discArtist());
-	  rip_wave_datas[i]->setAlbum(rip_cddb_record.discAlbum());
-	}
-	rip_apply_box->setChecked(true);
-	rip_apply_box->setEnabled(true);
-	rip_apply_label->setEnabled(true);
-	break;
-      case RDCddbLookup::PartialMatch:
-	rip_track=-1;
-	printf("Partial Match!\n");
-	break;
-      default:
-	rip_track=-1;
-	break;
+  case RDDiscLookup::ExactMatch:
+    if(rip_cdrom->status()!=RDCdPlayer::Ok) {
+      return;
+    }
+    rip_artist_edit->setText(rip_disc_record.discArtist());
+    rip_album_edit->setText(rip_disc_record.discAlbum());
+    rip_other_edit->setText(rip_disc_record.discExtended());
+    for(int i=0;i<rip_disc_record.tracks();i++) {
+      rip_track_list->findItem(QString().sprintf("%d",i+1),0)->
+	setText(2,rip_disc_record.trackTitle(i));
+      rip_track_list->findItem(QString().sprintf("%d",i+1),0)->
+	setText(3,rip_disc_record.trackExtended(i));
+      rip_wave_datas[i]->setTitle(rip_disc_record.trackTitle(i));
+      rip_wave_datas[i]->setArtist(rip_disc_record.discArtist());
+      rip_wave_datas[i]->setAlbum(rip_disc_record.discAlbum());
+      rip_wave_datas[i]->setLabel(rip_disc_record.discLabel());
+    }
+    rip_apply_box->setChecked(true);
+    rip_apply_box->setEnabled(true);
+    rip_apply_label->setEnabled(true);
+    rip_browser_button->setDisabled(rip_disc_lookup->sourceUrl().isNull());
+    rip_browser_label->setDisabled(rip_disc_lookup->sourceUrl().isNull());
+    break;
+
+  case RDDiscLookup::NoMatch:
+    rip_track=-1;
+    break;
+
+  case RDDiscLookup::LookupError:
+    QMessageBox::warning(this,"RDLibrary - "+rip_disc_lookup->sourceName()+
+			 " "+tr("Lookup Error"),err_msg);
+    rip_track=-1;
+    break;
   }
 }
 
@@ -905,6 +902,12 @@ void DiskRipper::selectionChangedData()
 }
 
 
+void DiskRipper::openBrowserData()
+{
+  RDWebBrowser(rip_disc_lookup->sourceUrl());
+}
+
+
 void DiskRipper::doubleClickedData(Q3ListViewItem *item,const QPoint &pt,
 				   int col)
 {
@@ -931,6 +934,8 @@ void DiskRipper::resizeEvent(QResizeEvent *e)
   rip_other_edit->setGeometry(65,53,size().width()-125,60);
   rip_apply_box->setGeometry(65,118,15,15);
   rip_apply_label->setGeometry(85,118,250,20);
+  rip_browser_button->setGeometry(size().width()-260,117,200,35);
+  rip_browser_label->setGeometry(size().width()-260,117,200,35);
   rip_track_label->setGeometry(100,140,100,14);
   rip_track_list->setGeometry(100,156,size().width()-202,size().height()-342);
   rip_diskbar_label->setGeometry(10,size().height()-174,size().width()-110,20);
@@ -947,14 +952,14 @@ void DiskRipper::resizeEvent(QResizeEvent *e)
   rip_clear_button->setGeometry(size().width()-90,480,80,50);
   rip_normalizebox_label->setGeometry(30,size().height()-78,85,20);
   rip_normalize_box->setGeometry(10,size().height()-78,20,20);
-  rip_normalize_spin->setGeometry(170,size().height()-79,40,20);
   rip_normalize_label->setGeometry(120,size().height()-78,45,20);
-  rip_normalize_unit->setGeometry(215,size().height()-78,40,20);
+  rip_normalize_spin->setGeometry(170,size().height()-79,50,20);
+  rip_normalize_unit->setGeometry(225,size().height()-78,40,20);
   rip_autotrimbox_label->setGeometry(30,size().height()-54,85,20);
   rip_autotrim_box->setGeometry(10,size().height()-54,20,20);
-  rip_autotrim_spin->setGeometry(170,size().height()-54,40,20);
   rip_autotrim_label->setGeometry(120,size().height()-54,45,20);
-  rip_autotrim_unit->setGeometry(215,size().height()-54,40,20);
+  rip_autotrim_spin->setGeometry(170,size().height()-54,50,20);
+  rip_autotrim_unit->setGeometry(225,size().height()-54,40,20);
   rip_channels_label->setGeometry(10,size().height()-30,75,20);
   rip_channels_box->setGeometry(90,size().height()-30,50,20);
   rip_rip_button->setGeometry(size().width()-200,size().height()-60,80,50);
@@ -1058,7 +1063,9 @@ void DiskRipper::RipTrack(int track,int end_track,QString cutname,QString title)
     case RDAudioImport::ErrorOk:
       cart->setMetadata(rip_wave_datas[track-1]);
       cut->setDescription(rip_wave_datas[track-1]->title());
-      cut->setIsrc(rip_cddb_record.isrc(rip_track_number-1));
+      cut->setIsrc(rip_disc_record.isrc(rip_track_number-1));
+      cut->setRecordingMbId(rip_disc_record.trackRecordingMbId(rip_track_number-1));
+      cut->setReleaseMbId(rip_disc_record.discReleaseMbId());
       cart->clearPending();
       SendNotification(RDNotification::AddAction,cart->number());
       break;
