@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AddMeta</name>
     <message>
@@ -30,39 +32,39 @@
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Starte um:</translation>
+        <translation type="obsolete">Starte um:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>Aktion wenn vorheriges Event noch läuft</translation>
+        <translation type="obsolete">Aktion wenn vorheriges Event noch läuft</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Sofort starten</translation>
+        <translation type="obsolete">Sofort starten</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Als Nächstes</translation>
+        <translation type="obsolete">Als Nächstes</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Warte bis zu</translation>
+        <translation type="obsolete">Warte bis zu</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Abspielen</translation>
+        <translation type="obsolete">Abspielen</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Übergang</translation>
+        <translation type="obsolete">Übergang</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Stop</translation>
+        <translation type="obsolete">Stop</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Übergangstyp:</translation>
+        <translation type="obsolete">Übergangstyp:</translation>
     </message>
     <message>
         <source>Log Name</source>
@@ -78,15 +80,15 @@
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>Abbre&amp;chen</translation>
+        <translation type="obsolete">Abbre&amp;chen</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Übergang wenn der vorheriger Cart eher aufhört</translation>
+        <translation type="obsolete">Übergang wenn der vorheriger Cart eher aufhört</translation>
     </message>
 </context>
 <context>
@@ -145,55 +147,55 @@
     </message>
     <message>
         <source>TIME</source>
-        <translation>Zeit</translation>
+        <translation type="obsolete">Zeit</translation>
     </message>
     <message>
         <source>TRANS</source>
-        <translation>ÜBERGANG</translation>
+        <translation type="obsolete">ÜBERGANG</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>CART</translation>
+        <translation type="obsolete">CART</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPPE</translation>
+        <translation type="obsolete">GRUPPE</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>LÄNGE</translation>
+        <translation type="obsolete">LÄNGE</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TITEL</translation>
+        <translation type="obsolete">TITEL</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>KÜNSTLER</translation>
+        <translation type="obsolete">KÜNSTLER</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>KUNDE</translation>
+        <translation type="obsolete">KUNDE</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGENTUR</translation>
+        <translation type="obsolete">AGENTUR</translation>
     </message>
     <message>
         <source>LABEL</source>
-        <translation>LABEL</translation>
+        <translation type="obsolete">LABEL</translation>
     </message>
     <message>
         <source>SOURCE</source>
-        <translation>QUELLE</translation>
+        <translation type="obsolete">QUELLE</translation>
     </message>
     <message>
         <source>LINE ID</source>
-        <translation>LINE ID</translation>
+        <translation type="obsolete">LINE ID</translation>
     </message>
     <message>
         <source>COUNT</source>
-        <translation>ZÄHLER</translation>
+        <translation type="obsolete">ZÄHLER</translation>
     </message>
     <message>
         <source>Insert
@@ -379,7 +381,7 @@ die für den gewählten Service ungültig sind!</translation>
     </message>
     <message>
         <source>Run Length</source>
-        <translation>Laufzeit</translation>
+        <translation type="unfinished">Laufzeit</translation>
     </message>
     <message>
         <source>Selected:</source>
@@ -397,10 +399,6 @@ die für den gewählten Service ungültig sind!</translation>
         <source>Unable to save log, audio deletion error!</source>
         <translation>Kann Logdatei nicht speichern, Audiolöschfehler!</translation>
     </message>
-    <message>
-        <source>EXT DATA</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Link Start</source>
         <translation type="unfinished"></translation>
@@ -437,6 +435,82 @@ die für den gewählten Service ungültig sind!</translation>
         <source>Log already being edited by</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished">Cart</translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished">Titel</translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished">Künstler</translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished">Label</translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ext Data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Line ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Count</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scheduled</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Start Times As</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sch. Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Estimated</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Est. Time</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditLogLine</name>
@@ -446,39 +520,39 @@ die für den gewählten Service ungültig sind!</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Starte um:</translation>
+        <translation type="obsolete">Starte um:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>Aktion wenn vorheriges Event noch läuft</translation>
+        <translation type="obsolete">Aktion wenn vorheriges Event noch läuft</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Sofort starten</translation>
+        <translation type="obsolete">Sofort starten</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Als Nächstes</translation>
+        <translation type="obsolete">Als Nächstes</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Warte bis zu</translation>
+        <translation type="obsolete">Warte bis zu</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Abspielen</translation>
+        <translation type="obsolete">Abspielen</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Übergang</translation>
+        <translation type="obsolete">Übergang</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Stop</translation>
+        <translation type="obsolete">Stop</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Übergangstyp:</translation>
+        <translation type="obsolete">Übergangstyp:</translation>
     </message>
     <message>
         <source>Cart</source>
@@ -500,15 +574,15 @@ auswählen</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>Abbre&amp;chen</translation>
+        <translation type="obsolete">Abbre&amp;chen</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Übergang wenn der vorheriger Cart eher aufhört</translation>
+        <translation type="obsolete">Übergang wenn der vorheriger Cart eher aufhört</translation>
     </message>
     <message>
         <source>Missing Cart</source>
@@ -534,11 +608,11 @@ Gruppe des ausgewählten Service!</translation>
     </message>
     <message>
         <source>Duplicate Start Time</source>
-        <translation>Doppelte Startzeit</translation>
+        <translation type="obsolete">Doppelte Startzeit</translation>
     </message>
     <message>
         <source>An event is already scheduled with this start time!</source>
-        <translation>Es existiert bereits ein Event mit dieser Startzeit!</translation>
+        <translation type="obsolete">Es existiert bereits ein Event mit dieser Startzeit!</translation>
     </message>
 </context>
 <context>
@@ -549,35 +623,35 @@ Gruppe des ausgewählten Service!</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Starte um:</translation>
+        <translation type="obsolete">Starte um:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>Aktion wenn vorheriges Event noch läuft</translation>
+        <translation type="obsolete">Aktion wenn vorheriges Event noch läuft</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Sofort starten</translation>
+        <translation type="obsolete">Sofort starten</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Als Nächstes</translation>
+        <translation type="obsolete">Als Nächstes</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Warte bis zu</translation>
+        <translation type="obsolete">Warte bis zu</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Abspielen</translation>
+        <translation type="obsolete">Abspielen</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Übergang</translation>
+        <translation type="obsolete">Übergang</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Stop</translation>
+        <translation type="obsolete">Stop</translation>
     </message>
     <message>
         <source>Comment</source>
@@ -589,19 +663,19 @@ Gruppe des ausgewählten Service!</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>Abbre&amp;chen</translation>
+        <translation type="obsolete">Abbre&amp;chen</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Übergang wenn der vorheriger Cart eher aufhört</translation>
+        <translation type="obsolete">Übergang wenn der vorheriger Cart eher aufhört</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Übergangstyp:</translation>
+        <translation type="obsolete">Übergangstyp:</translation>
     </message>
 </context>
 <context>
@@ -612,35 +686,35 @@ Gruppe des ausgewählten Service!</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Starte um:</translation>
+        <translation type="obsolete">Starte um:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>Aktion wenn vorheriges Event noch läuft</translation>
+        <translation type="obsolete">Aktion wenn vorheriges Event noch läuft</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Sofort starten</translation>
+        <translation type="obsolete">Sofort starten</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Als Nächstes</translation>
+        <translation type="obsolete">Als Nächstes</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Warte bis zu</translation>
+        <translation type="obsolete">Warte bis zu</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Abspielen</translation>
+        <translation type="obsolete">Abspielen</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Übergang</translation>
+        <translation type="obsolete">Übergang</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Stop</translation>
+        <translation type="obsolete">Stop</translation>
     </message>
     <message>
         <source>Comment</source>
@@ -648,19 +722,19 @@ Gruppe des ausgewählten Service!</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>Abbre&amp;chen</translation>
+        <translation type="obsolete">Abbre&amp;chen</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Übergang wenn der vorheriger Cart eher aufhört</translation>
+        <translation type="obsolete">Übergang wenn der vorheriger Cart eher aufhört</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Übergangstyp:</translation>
+        <translation type="obsolete">Übergangstyp:</translation>
     </message>
 </context>
 <context>
@@ -694,7 +768,7 @@ Gruppe des ausgewählten Service!</translation>
     <name>ListReports</name>
     <message>
         <source>RDLibrary Reports</source>
-        <translation>RDLibrary Reports</translation>
+        <translation type="obsolete">RDLibrary Reports</translation>
     </message>
     <message>
         <source>Log Listing</source>
@@ -736,6 +810,10 @@ Gruppe des ausgewählten Service!</translation>
         <source>&amp;Select</source>
         <translation>Au&amp;swählen</translation>
     </message>
+    <message>
+        <source>Reports</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWidget</name>
@@ -749,55 +827,55 @@ Gruppe des ausgewählten Service!</translation>
     </message>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation>Kann nicht verbinden</translation>
+        <translation type="obsolete">Kann nicht verbinden</translation>
     </message>
     <message>
         <source>LOG NAME</source>
-        <translation>LOGNAME</translation>
+        <translation type="obsolete">LOGNAME</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>BESCHREIBUNG</translation>
+        <translation type="obsolete">BESCHREIBUNG</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SERVICE</translation>
+        <translation type="obsolete">SERVICE</translation>
     </message>
     <message>
         <source>MUSIC</source>
-        <translation>MUSIK</translation>
+        <translation type="obsolete">MUSIK</translation>
     </message>
     <message>
         <source>TRAFFIC</source>
-        <translation>TRAFFIC</translation>
+        <translation type="obsolete">TRAFFIC</translation>
     </message>
     <message>
         <source>TRACKS</source>
-        <translation>TRACKS</translation>
+        <translation type="obsolete">TRACKS</translation>
     </message>
     <message>
         <source>VALID FROM</source>
-        <translation>GÜLTIG VON</translation>
+        <translation type="obsolete">GÜLTIG VON</translation>
     </message>
     <message>
         <source>VALID TO</source>
-        <translation>GÜLTIG BIS</translation>
+        <translation type="obsolete">GÜLTIG BIS</translation>
     </message>
     <message>
         <source>AUTO REFRESH</source>
-        <translation>AUTO REFRESH</translation>
+        <translation type="obsolete">AUTO REFRESH</translation>
     </message>
     <message>
         <source>ORIGIN</source>
-        <translation>HERKUNFT</translation>
+        <translation type="obsolete">HERKUNFT</translation>
     </message>
     <message>
         <source>LAST LINKED</source>
-        <translation>ZULETZT GELINKT</translation>
+        <translation type="obsolete">ZULETZT GELINKT</translation>
     </message>
     <message>
         <source>LAST MODIFIED</source>
-        <translation>ZULETZT GEÄNDERT</translation>
+        <translation type="obsolete">ZULETZT GEÄNDERT</translation>
     </message>
     <message>
         <source>&amp;Add</source>
@@ -877,15 +955,6 @@ Fortfahren?</translation>
         <source>Unable to delete log, audio deletion error!</source>
         <translation type="obsolete">Kann Logdatei nicht löschen, Audiolöschfehler!</translation>
     </message>
-    <message>
-        <source>RDLogEdit -- Database Skew</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>This version of RDLogEdit is incompatible with the version installed on the server.
-See your system administrator for an update!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Host</source>
         <translation type="unfinished"></translation>
@@ -934,10 +1003,6 @@ See your system administrator for an update!</source>
         <source>audio deletion error!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Windows</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Log</source>
         <translation type="unfinished"></translation>
@@ -946,6 +1011,58 @@ See your system administrator for an update!</source>
         <source>is in use by</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Unknown command option</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log Name</source>
+        <translation type="unfinished">Logname</translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Music</source>
+        <translation type="unfinished">Musik</translation>
+    </message>
+    <message>
+        <source>Traffic</source>
+        <translation type="unfinished">Traffic</translation>
+    </message>
+    <message>
+        <source>Tracks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Valid From</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Valid To</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto Refresh</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Origin</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Linked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Modified</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RenderDialog</name>
@@ -1108,31 +1225,31 @@ Track</source>
     </message>
     <message>
         <source>TIME</source>
-        <translation type="unfinished">Zeit</translation>
+        <translation type="obsolete">Zeit</translation>
     </message>
     <message>
         <source>TRANS</source>
-        <translation type="unfinished">ÜBERGANG</translation>
+        <translation type="obsolete">ÜBERGANG</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation type="unfinished">CART</translation>
+        <translation type="obsolete">CART</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation type="unfinished">GRUPPE</translation>
+        <translation type="obsolete">GRUPPE</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation type="unfinished">LÄNGE</translation>
+        <translation type="obsolete">LÄNGE</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation type="unfinished">TITEL</translation>
+        <translation type="obsolete">TITEL</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation type="unfinished">KÜNSTLER</translation>
+        <translation type="obsolete">KÜNSTLER</translation>
     </message>
     <message>
         <source>Do Over</source>
@@ -1261,13 +1378,9 @@ therefore only existing transitions will be editable.</source>
         <source>This cart cannot contain any additional cuts!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>ALBUM</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>LABEL</source>
-        <translation type="unfinished">LABEL</translation>
+        <translation type="obsolete">LABEL</translation>
     </message>
     <message>
         <source>Log Locked</source>
@@ -1277,5 +1390,41 @@ therefore only existing transitions will be editable.</source>
         <source>Log already being edited by</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Talk</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished">Cart</translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished">Titel</translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished">Künstler</translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished">Label</translation>
+    </message>
 </context>
 </TS>
