@@ -1,10 +1,8 @@
 // add_event.cpp
 //
-// Add a Rivendell Service
+// Add a Rivendell LogManager Event
 //
-//   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: add_event.cpp,v 1.9.2.1 2008-10-24 12:58:16 fredg Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,46 +18,23 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
-#include <qstring.h>
-#include <qpushbutton.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
-#include <qlabel.h>
-#include <qpainter.h>
-#include <qevent.h>
-#include <qmessagebox.h>
-#include <qcheckbox.h>
-#include <qbuttongroup.h>
-#include <qsqldatabase.h>
-
 #include <rdtextvalidator.h>
-#include <rdpasswd.h>
 
-#include <edit_event.h>
-#include <add_event.h>
+#include "add_event.h"
+#include "edit_event.h"
 
-
-AddEvent::AddEvent(QString *logname,QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+AddEvent::AddEvent(QString *logname,QWidget *parent)
+  : RDDialog(parent)
 {
   event_name=logname;
 
+  setWindowTitle("RDLogManager - "+tr("Add Log Event"));
+
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-  setMaximumHeight(sizeHint().height());
-
-  setCaption(tr("Add Log Event"));
-
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
+  setMinimumSize(sizeHint());
+  setMaximumSize(sizeHint());
 
   //
   // Create Validators
@@ -90,37 +65,42 @@ AddEvent::AddEvent(QString *logname,QWidget *parent,const char *name)
   validator->addBannedChar('-');
   validator->addBannedChar('_');
   validator->addBannedChar('/');
+  validator->addBannedChar('+');
+  validator->addBannedChar('=');
+  validator->addBannedChar('~');
+  validator->addBannedChar('?');
+  validator->addBannedChar('|');
 
   //
   // Event Name
   //
-  event_name_edit=new QLineEdit(this,"event_name_edit");
+  event_name_edit=new QLineEdit(this);
   event_name_edit->setGeometry(145,11,sizeHint().width()-155,19);
   event_name_edit->setMaxLength(58);  // MySQL limitation!
   event_name_edit->setValidator(validator);
-  QLabel *event_name_label=new QLabel(event_name_edit,tr("&New Event Name:"),
-				      this,"event_name_label");
+  QLabel *event_name_label=
+    new QLabel(event_name_edit,tr("&New Event Name:"),this);
   event_name_label->setGeometry(10,11,130,19);
-  event_name_label->setFont(font);
-  event_name_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  event_name_label->setFont(labelFont());
+  event_name_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   //  Ok Button
   //
-  QPushButton *ok_button=new QPushButton(this,"ok_button");
+  QPushButton *ok_button=new QPushButton(this);
   ok_button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   ok_button->setDefault(true);
-  ok_button->setFont(font);
+  ok_button->setFont(buttonFont());
   ok_button->setText(tr("&OK"));
   connect(ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
   //
   //  Cancel Button
   //
-  QPushButton *cancel_button=new QPushButton(this,"cancel_button");
+  QPushButton *cancel_button=new QPushButton(this);
   cancel_button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,
 			     80,50);
-  cancel_button->setFont(font);
+  cancel_button->setFont(buttonFont());
   cancel_button->setText(tr("&Cancel"));
   connect(cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
@@ -161,3 +141,9 @@ void AddEvent::cancelData()
 {
   done(-1);
 }
+
+
+void AddEvent::closeEvent(QCloseEvent *e)
+{
+  cancelData();
+}
