@@ -2,7 +2,7 @@
 //
 // List Rivendell Log Clocks
 //
-//   (C) Copyright 2002-2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,19 +18,10 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
-#include <qstring.h>
-#include <qtextedit.h>
-#include <qpainter.h>
 #include <qmessagebox.h>
-#include <qpixmap.h>
 #include <qpainter.h>
 
-#include <rddb.h>
-#include <rd.h>
 #include <rdescape_string.h>
-#include <rdevent.h>
-#include <rdcreate_log.h>
 
 #include "add_clock.h"
 #include "edit_clock.h"
@@ -39,57 +30,47 @@
 #include "rename_item.h"
 
 ListClocks::ListClocks(QString *clockname,QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
   QStringList services_list;
-  QString str1=tr("Log Clocks - User: ");
-  setCaption(QString().sprintf("%s%s",(const char *)str1,
-			       (const char *)rdripc->user()));
   edit_clockname=clockname;
 
+  setWindowTitle("RDLogManager - "+tr("Log Clocks"));
+
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-
-  //
-  // Create Fonts
-  //
-  QFont bold_font=QFont("Helvetica",12,QFont::Bold);
-  bold_font.setPixelSize(12);
-  QFont font=QFont("Helvetica",12,QFont::Normal);
-  font.setPixelSize(12);
+  setMinimumSize(sizeHint());
 
   //
   // Event Filter
   //
   edit_filter_box=new QComboBox(this);
   edit_filter_label=new QLabel(edit_filter_box,tr("Filter:"),this);
-  edit_filter_label->setFont(bold_font);
-  edit_filter_label->setAlignment(AlignRight|AlignVCenter);
+  edit_filter_label->setFont(labelFont());
+  edit_filter_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   connect(edit_filter_box,SIGNAL(activated(int)),
 	  this,SLOT(filterActivatedData(int)));
 
   //
   // Clocks List
   //
-  edit_clocks_list=new QListView(this);
+  edit_clocks_list=new Q3ListView(this);
   edit_clocks_list->setAllColumnsShowFocus(true);
   edit_clocks_list->setItemMargin(5);
   edit_clocks_list->addColumn(tr("Name"));
   edit_clocks_list->addColumn(tr("Code"));
   edit_clocks_list->addColumn(tr("Color"));
-  edit_clocks_list->setColumnAlignment(2,AlignCenter);
+  edit_clocks_list->setColumnAlignment(2,Qt::AlignCenter);
   connect(edit_clocks_list,
-	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
-	  this,SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
+	  SIGNAL(doubleClicked(Q3ListViewItem *,const QPoint &,int)),
+	  this,SLOT(doubleClickedData(Q3ListViewItem *,const QPoint &,int)));
 
   //
   //  Add Button
   //
   edit_add_button=new QPushButton(this);
-  edit_add_button->setFont(bold_font);
+  edit_add_button->setFont(buttonFont());
   edit_add_button->setText(tr("&Add"));
   connect(edit_add_button,SIGNAL(clicked()),this,SLOT(addData()));
     
@@ -97,7 +78,7 @@ ListClocks::ListClocks(QString *clockname,QWidget *parent)
   //  Edit Button
   //
   edit_edit_button=new QPushButton(this);
-  edit_edit_button->setFont(bold_font);
+  edit_edit_button->setFont(buttonFont());
   edit_edit_button->setText(tr("&Edit"));
   connect(edit_edit_button,SIGNAL(clicked()),this,SLOT(editData()));
     
@@ -105,7 +86,7 @@ ListClocks::ListClocks(QString *clockname,QWidget *parent)
   //  Delete Button
   //
   edit_delete_button=new QPushButton(this);
-  edit_delete_button->setFont(bold_font);
+  edit_delete_button->setFont(buttonFont());
   edit_delete_button->setText(tr("&Delete"));
   connect(edit_delete_button,SIGNAL(clicked()),this,SLOT(deleteData()));
     
@@ -113,7 +94,7 @@ ListClocks::ListClocks(QString *clockname,QWidget *parent)
   //  Rename Button
   //
   edit_rename_button=new QPushButton(this);
-  edit_rename_button->setFont(bold_font);
+  edit_rename_button->setFont(buttonFont());
   edit_rename_button->setText(tr("&Rename"));
   connect(edit_rename_button,SIGNAL(clicked()),this,SLOT(renameData()));
     
@@ -121,7 +102,7 @@ ListClocks::ListClocks(QString *clockname,QWidget *parent)
   //  Close Button
   //
   edit_close_button=new QPushButton(this);
-  edit_close_button->setFont(bold_font);
+  edit_close_button->setFont(buttonFont());
   edit_close_button->setText(tr("C&lose"));
   connect(edit_close_button,SIGNAL(clicked()),this,SLOT(closeData()));
 
@@ -129,7 +110,7 @@ ListClocks::ListClocks(QString *clockname,QWidget *parent)
   //  Clear Button
   //
   edit_clear_button=new QPushButton(this);
-  edit_clear_button->setFont(bold_font);
+  edit_clear_button->setFont(buttonFont());
   edit_clear_button->setText(tr("C&lear"));
   connect(edit_clear_button,SIGNAL(clicked()),this,SLOT(clearData()));
 
@@ -137,7 +118,7 @@ ListClocks::ListClocks(QString *clockname,QWidget *parent)
   //  OK Button
   //
   edit_ok_button=new QPushButton(this);
-  edit_ok_button->setFont(bold_font);
+  edit_ok_button->setFont(buttonFont());
   edit_ok_button->setText(tr("&OK"));
   connect(edit_ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
@@ -145,7 +126,7 @@ ListClocks::ListClocks(QString *clockname,QWidget *parent)
   //  Cancel Button
   //
   edit_cancel_button=new QPushButton(this);
-  edit_cancel_button->setFont(bold_font);
+  edit_cancel_button->setFont(buttonFont());
   edit_cancel_button->setText(tr("&Cancel"));
   connect(edit_cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
@@ -188,7 +169,7 @@ ListClocks::ListClocks(QString *clockname,QWidget *parent)
   RefreshList();
 
   if(edit_clockname!=NULL) {
-    QListViewItem *item=edit_clocks_list->firstChild();
+    Q3ListViewItem *item=edit_clocks_list->firstChild();
     while(item!=NULL) {
       if(item->text(0)==*edit_clockname) {
 	edit_clocks_list->setSelected(item,true);
@@ -213,8 +194,7 @@ QSizePolicy ListClocks::sizePolicy() const
 
 void ListClocks::addData()
 {
-  QString clockname;
-  QString clockname_esc;
+  QString clockname;  
   QString sql;
   RDSqlQuery *q;
   RDSqlQuery *q1;
@@ -242,19 +222,13 @@ void ListClocks::addData()
     "ARTISTSEP=15";
   q=new RDSqlQuery(sql);
   delete q;
-  sql=RDCreateClockTableSql(RDClock::tableName(clockname),log_config);
-  q=new RDSqlQuery(sql);
-  delete q;
   EditClock *clock_dialog=new EditClock(clockname,true,&new_clocks,this);
   if(clock_dialog->exec()<0) {
-    clockname_esc=clockname;
-    clockname_esc.replace(" ","_");
-    clockname_esc+="_CLK";
-    sql=QString().sprintf("drop table %s",(const char *)clockname_esc);
-    q=new RDSqlQuery(sql);
-    delete q;
-    sql=QString().sprintf("delete from CLOCKS where NAME=\"%s\"",
-			  (const char *)clockname);
+    sql=QString("delete from CLOCK_LINES where ")+
+      "CLOCK_NAME=\""+RDEscapeString(clockname)+"\"";
+    RDSqlQuery::apply(sql);
+    sql=QString("delete from CLOCKS where ")+
+      "NAME=\""+RDEscapeString(clockname)+"\"";
     q=new RDSqlQuery(sql);
     delete q;
   }
@@ -263,27 +237,22 @@ void ListClocks::addData()
       sql="select NAME from SERVICES";
       q=new RDSqlQuery(sql);
       while(q->next()) {
-        // FIXME: not sure if the usersec service filter should be applied
-        // here, or if all services should be brought over and later filtered
-        // by edit_perms.cpp dialog.
-	sql=QString().sprintf("insert into CLOCK_PERMS set\
-                               CLOCK_NAME=\"%s\",SERVICE_NAME=\"%s\"",
-			      (const char *)clockname,
-			      (const char *)q->value(0).toString());
+	sql=QString("insert into CLOCK_PERMS set ")+
+	  "CLOCK_NAME=\""+RDEscapeString(clockname)+"\","+
+	  "SERVICE_NAME=\""+RDEscapeString(q->value(0).toString())+"\"";
 	q1=new RDSqlQuery(sql);
 	delete q1;
       }
       delete q;
     }
     else {
-      sql=QString().sprintf("insert into CLOCK_PERMS set\
-                             CLOCK_NAME=\"%s\",SERVICE_NAME=\"%s\"",
-			    (const char *)clockname,
-			    (const char *)edit_filter_box->currentText());
+      sql=QString("insert into CLOCK_PERMS set ")+
+	"CLOCK_NAME=\""+RDEscapeString(clockname)+"\","+
+	"SERVICE_NAME=\""+RDEscapeString(edit_filter_box->currentText())+"\"";
       q=new RDSqlQuery(sql);
       delete q;
     }
-    QListViewItem *item=new QListViewItem(edit_clocks_list);
+    Q3ListViewItem *item=new Q3ListViewItem(edit_clocks_list);
     item->setText(0,clockname);
     RefreshItem(item,&new_clocks);
     edit_clocks_list->setSelected(item,true);
@@ -295,7 +264,7 @@ void ListClocks::addData()
 void ListClocks::editData()
 {
   std::vector<QString> new_clocks;
-  QListViewItem *item=edit_clocks_list->selectedItem();
+  Q3ListViewItem *item=edit_clocks_list->selectedItem();
   if(item==NULL) {
     return;
   }
@@ -311,31 +280,25 @@ void ListClocks::editData()
 
 void ListClocks::deleteData()
 {
-  QString str1;
-  QString str2;
   int n;
   QString svc_list;
-  QListViewItem *item=edit_clocks_list->selectedItem();
+  Q3ListViewItem *item=edit_clocks_list->selectedItem();
   if(item==NULL) {
     return;
   }
-  str1=QString(tr("Are you sure you want to\ndelete"));
-  if(QMessageBox::question(this,tr("Delete Clock"),
-			   QString().sprintf("%s \'%s\'?",(const char *)str1,
-			 (const char *)item->text(0)),
+  if(QMessageBox::question(this,"RDLogManager - "+tr("Delete Clock"),
+			   tr("Are you sure you want to delete")+" \""+
+			   item->text(0)+"\"?",
 			  QMessageBox::Yes,QMessageBox::No)
      !=QMessageBox::Yes) {
     return;
   }
   if((n=ActiveClocks(item->text(0),&svc_list))>0) {
-    str1=QString(tr("is in use in the following grid(s):"));
-    str2=QString(tr("Do you still want to delete it?"));
-    if(QMessageBox::warning(this,tr("Clock In Use"),
-			 QString().sprintf("\'%s\' %s:\n\n%s\n%s",
-					   (const char *)item->text(0),
-					   (const char *)str1,
-					   (const char *)svc_list,
-					   (const char *)str2),
+    if(QMessageBox::warning(this,"RDLogManager - "+tr("Clock In Use"),
+			    "\""+item->text(0)+"\" "+
+			    tr("is in use in the following grid(s)")+":\n\n"+
+			    svc_list+"\n"+
+			    tr("Do you still want to delete it?"),
 			    QMessageBox::Yes,
 			    QMessageBox::No)!=QMessageBox::Yes) {
       return;
@@ -351,7 +314,7 @@ void ListClocks::renameData()
   QString sql;
   RDSqlQuery *q;
   RDSqlQuery *q1;
-  QListViewItem *item=edit_clocks_list->selectedItem();
+  Q3ListViewItem *item=edit_clocks_list->selectedItem();
   if(item==NULL) {
     return;
   }
@@ -384,37 +347,32 @@ void ListClocks::renameData()
   //
   // Rename Meta Table
   //
-  QString old_name_esc=item->text(0);
-  old_name_esc.replace(" ","_");
-  QString new_name_esc=new_name;
-  new_name_esc.replace(" ","_");
-  sql=QString().sprintf("alter table %s_CLK rename to %s_CLK",
-			(const char *)old_name_esc,
-			(const char *)new_name_esc);
-  q=new RDSqlQuery(sql);
-  delete q;
-  sql=QString().sprintf("alter table %s_RULES rename to %s_RULES",
-			(const char *)old_name_esc,
-			(const char *)new_name_esc);
+  sql=QString("update CLOCK_LINES set ")+
+    "CLOCK_NAME=\""+RDEscapeString(new_name)+"\" where "+
+    "CLOCK_NAME=\""+RDEscapeString(item->text(0))+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 
+  sql=QString("update RULE_LINES set ")+
+    "CLOCK_NAME=\""+RDEscapeString(new_name)+"\" where "+
+    "CLOCK_NAME=\""+RDEscapeString(item->text(0))+"\"";
+  RDSqlQuery::apply(sql);
+
   //
   // Rename Service Permissions
   //
-  sql=QString().sprintf("update CLOCK_PERMS set CLOCK_NAME=\"%s\"\
-                         where CLOCK_NAME=\"%s\"",
-			(const char *)new_name,
-			(const char *)item->text(0));
+  sql=QString("update CLOCK_PERMS set ")+
+    "CLOCK_NAME=\""+RDEscapeString(new_name)+"\" where "+
+    "CLOCK_NAME=\""+RDEscapeString(item->text(0))+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 
   //
   // Rename Primary Key
   //
-  sql=QString().sprintf("update CLOCKS set NAME=\"%s\" where NAME=\"%s\"",
-			(const char *)new_name,
-			(const char *)item->text(0));
+  sql=QString("update CLOCKS set ")+
+    "NAME=\""+RDEscapeString(new_name)+"\" where "+
+    "NAME=\""+RDEscapeString(item->text(0))+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 
@@ -429,7 +387,7 @@ void ListClocks::filterActivatedData(int id)
 }
 
 
-void ListClocks::doubleClickedData(QListViewItem *item,const QPoint &,int)
+void ListClocks::doubleClickedData(Q3ListViewItem *item,const QPoint &,int)
 {
   if(edit_clockname==NULL) {
     editData();
@@ -449,7 +407,7 @@ void ListClocks::closeData()
 
 void ListClocks::clearData()
 {
-  QListViewItem *item=edit_clocks_list->selectedItem();
+  Q3ListViewItem *item=edit_clocks_list->selectedItem();
   if(item!=NULL) {
     edit_clocks_list->setSelected(item,false);
   }
@@ -458,7 +416,7 @@ void ListClocks::clearData()
 
 void ListClocks::okData()
 {
-  QListViewItem *item=edit_clocks_list->selectedItem();
+  Q3ListViewItem *item=edit_clocks_list->selectedItem();
   *clock_filter=edit_filter_box->currentText();
   if(item==NULL) {
     *edit_clockname="";
@@ -516,28 +474,31 @@ void ListClocks::RefreshList()
   }
 
   edit_clocks_list->clear();
-  QString sql=QString().sprintf("select NAME,SHORT_NAME,COLOR from CLOCKS %s",
-				(const char *)filter);
+  QString sql=QString("select ")+
+    "NAME,"+        // 00
+    "SHORT_NAME,"+  // 01
+    "COLOR "+       // 02
+    "from CLOCKS "+filter;
   RDSqlQuery *q=new RDSqlQuery(sql);
-  QListViewItem *item=NULL;
+  Q3ListViewItem *item=NULL;
   while(q->next()) {
-    item=new QListViewItem(edit_clocks_list);
+    item=new Q3ListViewItem(edit_clocks_list);
     WriteItem(item,q);
   }
   delete q;
 }
 
 
-void ListClocks::RefreshItem(QListViewItem *item,
+void ListClocks::RefreshItem(Q3ListViewItem *item,
 			     std::vector<QString> *new_clocks)
 {
-  QListViewItem *new_item;
+  Q3ListViewItem *new_item;
   UpdateItem(item,item->text(0));
 
   if(new_clocks!=NULL) {
     for(unsigned i=0;i<new_clocks->size();i++) {
       if((new_item=edit_clocks_list->findItem(new_clocks->at(i),0))==NULL) {
-	new_item=new QListViewItem(edit_clocks_list);
+	new_item=new Q3ListViewItem(edit_clocks_list);
       }
       UpdateItem(new_item,new_clocks->at(i));
     }
@@ -545,10 +506,14 @@ void ListClocks::RefreshItem(QListViewItem *item,
 }
 
 
-void ListClocks::UpdateItem(QListViewItem *item,QString name)
+void ListClocks::UpdateItem(Q3ListViewItem *item,QString name)
 {
-  QString sql=QString().sprintf("select NAME,SHORT_NAME,COLOR from CLOCKS\
-                                 where NAME=\"%s\"",(const char *)name);
+  QString sql=QString("select ")+
+    "NAME,"+        // 00
+    "SHORT_NAME,"+  // 01
+    "COLOR "+       // 02
+    "from CLOCKS where "+
+    "NAME=\""+RDEscapeString(name)+"\"";
   RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->next()) {
     item->setText(0,name);
@@ -558,7 +523,7 @@ void ListClocks::UpdateItem(QListViewItem *item,QString name)
 }
 
 
-void ListClocks::WriteItem(QListViewItem *item,RDSqlQuery *q)
+void ListClocks::WriteItem(Q3ListViewItem *item,RDSqlQuery *q)
 {
   QPixmap *pix;
   QPainter *p=new QPainter();
@@ -592,7 +557,7 @@ int ListClocks::ActiveClocks(QString clockname,QString *svc_list)
     }
   }
   delete q;
-  for(unsigned i=0;i<svcs.size();i++) {
+  for(int i=0;i<svcs.size();i++) {
     n++;
     *svc_list+="    "+svcs[i]+"\n";
   }
@@ -609,9 +574,10 @@ void ListClocks::DeleteClock(QString clockname)
   base_name.replace(" ","_");
 
   //
-  // Delete Active Clocks
+  // Clear Active Clocks
   //
-  sql=QString("delete from SERVICE_CLOCKS where ")+
+  sql=QString("update SERVICE_CLOCKS set ")+
+    "CLOCK_NAME=null where "+
     "CLOCK_NAME=\""+RDEscapeString(clockname)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
@@ -619,38 +585,37 @@ void ListClocks::DeleteClock(QString clockname)
   //
   // Delete Service Associations
   //
-  sql=QString().sprintf("delete from CLOCK_PERMS where CLOCK_NAME=\"%s\"",
-			(const char *)clockname);
+  sql=QString("delete from CLOCK_PERMS where ")+
+    "CLOCK_NAME=\""+RDEscapeString(clockname)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 
   //
   // Delete Clock Definition
   //
-  sql=QString().sprintf("delete from CLOCKS where NAME=\"%s\"",
-				(const char *)clockname);
-  q=new RDSqlQuery(sql);
-  delete q;
-  sql=QString().sprintf("drop table %s_CLK",(const char *)base_name);
-  q=new RDSqlQuery(sql);
-  delete q;
-  sql=QString().sprintf("drop table %s_RULES",(const char *)base_name);
-  q=new RDSqlQuery(sql);
-  delete q;
+  sql=QString("delete from CLOCKS where ")+
+    "NAME=\""+RDEscapeString(clockname)+"\"";
+  RDSqlQuery::apply(sql);
+  sql=QString("delete from CLOCK_LINES where ")+
+    "CLOCK_NAME=\""+RDEscapeString(clockname)+"\"";
+  RDSqlQuery::apply(sql);
+
+  sql=QString("delete from RULE_LINES where ")+
+    "CLOCK_NAME=\""+RDEscapeString(clockname)+"\"";
+  RDSqlQuery::apply(sql);
 }
 
 
 QString ListClocks::GetClockFilter(QString svc_name)
 {
   QString filter="where ";
-  QString sql=QString().sprintf("select CLOCK_NAME from CLOCK_PERMS\
-                                 where SERVICE_NAME=\"%s\"",
-				(const char *)svc_name);
+  QString sql=QString("select CLOCK_NAME from CLOCK_PERMS where ")+
+    "SERVICE_NAME=\""+RDEscapeString(svc_name)+"\"";
   RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->size()>0) {
     while(q->next()) {
-      filter+=QString().sprintf("(NAME=\"%s\")||",
-				(const char *)q->value(0).toString());
+      filter+=QString("(NAME=\"")+
+	RDEscapeString(q->value(0).toString())+"\")||";
     }
     filter=filter.left(filter.length()-2);
   }
@@ -675,8 +640,7 @@ QString ListClocks::GetNoneFilter()
     filter="where ";
   }
   while(q->next()) {
-    filter+=QString().sprintf("(NAME!=\"%s\")&&",
-			      (const char *)q->value(0).toString());
+    filter+=QString("(NAME!=\"")+RDEscapeString(q->value(0).toString())+"\")&&";
   }
   if(q->size()>0) {
     filter=filter.left(filter.length()-2);
