@@ -1136,7 +1136,7 @@ Opětovné sloučení tato data smaže. Sloučit znovu?</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>STOP Transition</source>
+        <source>[auto]</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
