@@ -1136,7 +1136,7 @@ Einbinden wird diese entfernen. Fortfahren?</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>STOP Transition</source>
+        <source>[auto]</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
