@@ -2,7 +2,7 @@
 //
 // Test the Rivendell file format converter.
 //
-//   (C) Copyright 2010-2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2010-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,8 +20,7 @@
 
 #include <qapplication.h>
 
-#include <rddb.h>
-#include <rdcmd_switch.h>
+#include <rdapplication.h>
 #include <rdaudioconvert.h>
 
 #include <audio_convert_test.h>
@@ -29,48 +28,53 @@
 MainObject::MainObject(QObject *parent)
   :QObject(parent)
 {
-  unsigned schema=0;
+  QString err_msg;
+  RDWaveData *wavedata=NULL;
 
   destination_settings=new RDSettings();
   start_point=-1;
   end_point=-1;
   speed_ratio=1.0;
+  metadata_cart=0;
   bool ok=false;
   RDAudioConvert::ErrorCode conv_err;
 
   //
-  // Read Command Options
+  // Open the Database
   //
-  RDCmdSwitch *cmd=
-    new RDCmdSwitch(qApp->argc(),qApp->argv(),"audio_convert_test",
-  		    AUDIO_CONVERT_TEST_USAGE);
-  for(unsigned i=0;i<cmd->keys();i++) {
-    if(cmd->key(i)=="--source-file") {
-      source_filename=cmd->value(i);
-      cmd->setProcessed(i,true);
+  rda=new RDApplication("audio_convert_test","audio_convert_test",
+			AUDIO_CONVERT_TEST_USAGE,this);
+  if(!rda->open(&err_msg)) {
+    fprintf(stderr,"audio_convert_test: %s\n",(const char *)err_msg.toUtf8());
+    exit(1);
+  }
+  for(unsigned i=0;i<rda->cmdSwitch()->keys();i++) {
+    if(rda->cmdSwitch()->key(i)=="--source-file") {
+      source_filename=rda->cmdSwitch()->value(i);
+      rda->cmdSwitch()->setProcessed(i,true);
     }
-    if(cmd->key(i)=="--destination-file") {
-      destination_filename=cmd->value(i);
-      cmd->setProcessed(i,true);
+    if(rda->cmdSwitch()->key(i)=="--destination-file") {
+      destination_filename=rda->cmdSwitch()->value(i);
+      rda->cmdSwitch()->setProcessed(i,true);
     }
-    if(cmd->key(i)=="--start-point") {
-      start_point=cmd->value(i).toInt(&ok);
+    if(rda->cmdSwitch()->key(i)=="--start-point") {
+      start_point=rda->cmdSwitch()->value(i).toInt(&ok);
       if(!ok) {
 	fprintf(stderr,"audio_convert_test: invalid start point\n");
 	exit(256);
       }
-      cmd->setProcessed(i,true);
+      rda->cmdSwitch()->setProcessed(i,true);
     }
-    if(cmd->key(i)=="--end-point") {
-      end_point=cmd->value(i).toInt(&ok);
+    if(rda->cmdSwitch()->key(i)=="--end-point") {
+      end_point=rda->cmdSwitch()->value(i).toInt(&ok);
       if(!ok) {
 	fprintf(stderr,"audio_convert_test: invalid end point\n");
 	exit(256);
       }
-      cmd->setProcessed(i,true);
+      rda->cmdSwitch()->setProcessed(i,true);
     }
-    if(cmd->key(i)=="--destination-format") {
-      RDSettings::Format format=(RDSettings::Format)cmd->value(i).toInt(&ok);
+    if(rda->cmdSwitch()->key(i)=="--destination-format") {
+      RDSettings::Format format=(RDSettings::Format)rda->cmdSwitch()->value(i).toInt(&ok);
       if(!ok) {
 	fprintf(stderr,"audio_convert_test: invalid destination format\n");
 	exit(256);
@@ -84,7 +88,7 @@ MainObject::MainObject(QObject *parent)
       case RDSettings::Flac:
       case RDSettings::OggVorbis:
 	destination_settings->setFormat(format);
-	cmd->setProcessed(i,true);
+	rda->cmdSwitch()->setProcessed(i,true);
 	break;
 
       default:
@@ -93,58 +97,66 @@ MainObject::MainObject(QObject *parent)
       }
       destination_settings->setFormat(format);
     }
-    if(cmd->key(i)=="--destination-channels") {
-      unsigned channels=cmd->value(i).toInt(&ok);
+    if(rda->cmdSwitch()->key(i)=="--destination-channels") {
+      unsigned channels=rda->cmdSwitch()->value(i).toInt(&ok);
       if(!ok) {
 	fprintf(stderr,"audio_convert_test: invalid destination channels\n");
 	exit(256);
       }
       destination_settings->setChannels(channels);
-      cmd->setProcessed(i,true);
+      rda->cmdSwitch()->setProcessed(i,true);
     }
-    if(cmd->key(i)=="--destination-sample-rate") {
-      unsigned sample_rate=cmd->value(i).toInt(&ok);
+    if(rda->cmdSwitch()->key(i)=="--destination-sample-rate") {
+      unsigned sample_rate=rda->cmdSwitch()->value(i).toInt(&ok);
       if(!ok) {
 	fprintf(stderr,"audio_convert_test: invalid destination sample rate\n");
 	exit(256);
       }
       destination_settings->setSampleRate(sample_rate);
-      cmd->setProcessed(i,true);
+      rda->cmdSwitch()->setProcessed(i,true);
     }
-    if(cmd->key(i)=="--destination-bit-rate") {
-      unsigned bit_rate=cmd->value(i).toInt(&ok);
+    if(rda->cmdSwitch()->key(i)=="--destination-bit-rate") {
+      unsigned bit_rate=rda->cmdSwitch()->value(i).toInt(&ok);
       if(!ok) {
 	fprintf(stderr,"audio_convert_test: invalid destination bit rate\n");
 	exit(256);
       }
       destination_settings->setBitRate(bit_rate);
-      cmd->setProcessed(i,true);
+      rda->cmdSwitch()->setProcessed(i,true);
     }
-    if(cmd->key(i)=="--quality") {
-      unsigned quality=cmd->value(i).toInt(&ok);
+    if(rda->cmdSwitch()->key(i)=="--quality") {
+      unsigned quality=rda->cmdSwitch()->value(i).toInt(&ok);
       if(!ok) {
 	fprintf(stderr,"audio_convert_test: invalid destination quality\n");
 	exit(256);
       }
       destination_settings->setQuality(quality);
-      cmd->setProcessed(i,true);
+      rda->cmdSwitch()->setProcessed(i,true);
     }
-    if(cmd->key(i)=="--normalization-level") {
-      int normalization_level=cmd->value(i).toInt(&ok);
+    if(rda->cmdSwitch()->key(i)=="--metadata-cart") {
+      metadata_cart=rda->cmdSwitch()->value(i).toUInt(&ok);
+      if((!ok)||(metadata_cart==0)||(metadata_cart>RD_MAX_CART_NUMBER)) {
+	fprintf(stderr,"audio_convert_test: invalid --metadata-cart\n");
+	exit(256);
+      }
+      rda->cmdSwitch()->setProcessed(i,true);
+    }
+    if(rda->cmdSwitch()->key(i)=="--normalization-level") {
+      int normalization_level=rda->cmdSwitch()->value(i).toInt(&ok);
       if((!ok)||(normalization_level>0)) {
 	fprintf(stderr,"audio_convert_test: invalid normalization level\n");
 	exit(256);
       }
       destination_settings->setNormalizationLevel(normalization_level);
-      cmd->setProcessed(i,true);
+      rda->cmdSwitch()->setProcessed(i,true);
     }
-    if(cmd->key(i)=="--speed-ratio") {
-      speed_ratio=cmd->value(i).toFloat(&ok);
+    if(rda->cmdSwitch()->key(i)=="--speed-ratio") {
+      speed_ratio=rda->cmdSwitch()->value(i).toFloat(&ok);
       if((!ok)||(speed_ratio<=0)) {
 	fprintf(stderr,"audio_convert_test: invalid speed-ratio\n");
 	exit(256);
       }
-      cmd->setProcessed(i,true);
+      rda->cmdSwitch()->setProcessed(i,true);
     }
   }
   if(source_filename.isEmpty()) {
@@ -160,28 +172,23 @@ MainObject::MainObject(QObject *parent)
     fprintf(stderr,"audio_convert_test: --destination-bit-rate and --destination-quality are mutually exclusive\n");
     exit(256);
   }
-
-  //
-  // Read Configuration
-  //
-  rdconfig=new RDConfig();
-  rdconfig->load();
-
-  //
-  // Open Database
-  //
-  QString err (tr("audio_convert_test: "));
-  QSqlDatabase *db=RDInitDb(&schema,&err);
-  if(!db) {
-    fprintf(stderr,err.ascii());
-    delete cmd;
-    exit(256);
+  if(metadata_cart>0) {
+    RDCart *cart=new RDCart(metadata_cart);
+    if(!cart->exists()) {
+      fprintf(stderr,"audio_convert_test: --metadata-cart does not exist\n");
+      exit(256);
+    }
+    wavedata=new RDWaveData();
+    cart->getMetadata(wavedata);
+    wavedata->setCutNumber(1);
+    delete cart;
   }
 
-  RDAudioConvert *conv=new RDAudioConvert(rdconfig->stationName(),this);
+  RDAudioConvert *conv=new RDAudioConvert(this);
   conv->setSourceFile(source_filename);
   conv->setDestinationFile(destination_filename);
   conv->setDestinationSettings(destination_settings);
+  conv->setDestinationWaveData(wavedata);
   conv->setRange(start_point,end_point);
   conv->setSpeedRatio(speed_ratio);
   printf("Converting...\n");
