@@ -2,7 +2,7 @@
 //
 // A command-line log editor for Rivendell
 //
-//   (C) Copyright 2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2016-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,8 +20,11 @@
 
 #include <stdlib.h>
 
+#include <rdapplication.h>
 #include <rdweb.h>
 
+#include <rddatetime.h>
+
 #include "rdclilogedit.h"
 
 void MainObject::DispatchCommand(QString cmd)
@@ -39,14 +42,14 @@ void MainObject::DispatchCommand(QString cmd)
     overwrite=true;
     cmd=cmd.left(cmd.length()-1).stripWhiteSpace();
   }
-  cmds=cmds.split(" ",cmd);
+  cmds=cmd.split(" ",QString::SkipEmptyParts);
   verb=cmds[0].lower();
 
   //
   // No loaded log needed for these
   //
   if(verb=="deletelog") {
-    if(edit_user->deleteLog()) {
+    if(rda->user()->deleteLog()) {
       if(cmds.size()==2) {
 	Deletelog(cmds[1]);
       }
@@ -123,7 +126,7 @@ void MainObject::DispatchCommand(QString cmd)
   //
   if((processed)||(edit_log_event!=NULL)) {
     if(verb=="addcart") {
-      if(edit_user->addtoLog()) {
+      if(rda->user()->addtoLog()) {
 	if(cmds.size()==3) {
 	  line=cmds[1].toInt(&ok);
 	  if(ok&&(line>=0)) {
@@ -150,7 +153,7 @@ void MainObject::DispatchCommand(QString cmd)
     }
 
     if(verb=="addchain") {
-      if(edit_user->addtoLog()) {
+      if(rda->user()->addtoLog()) {
 	if(cmds.size()==3) {
 	  line=cmds[1].toInt(&ok);
 	  if(ok&&(line>=0)) {
@@ -171,7 +174,7 @@ void MainObject::DispatchCommand(QString cmd)
     }
     
     if(verb=="addmarker") {
-      if(edit_user->addtoLog()) {
+      if(rda->user()->addtoLog()) {
 	if(cmds.size()==2) {
 	  line=cmds[1].toInt(&ok);
 	  if(ok&&(line>=0)) {
@@ -192,7 +195,7 @@ void MainObject::DispatchCommand(QString cmd)
     }
     
     if(verb=="addtrack") {
-      if(edit_user->addtoLog()) {
+      if(rda->user()->addtoLog()) {
 	if(cmds.size()==2) {
 	  line=cmds[1].toInt(&ok);
 	  if(ok&&(line>=0)) {
@@ -223,7 +226,7 @@ void MainObject::DispatchCommand(QString cmd)
     }
 
     if(verb=="remove") {
-      if(edit_user->removefromLog()) {
+      if(rda->user()->removefromLog()) {
 	if(cmds.size()==2) {
 	  line=cmds[1].toInt(&ok);
 	  if(ok&&(line>=0)&&(line<edit_log_event->size())) {
@@ -244,7 +247,7 @@ void MainObject::DispatchCommand(QString cmd)
     }
 
     if(verb=="save") {
-      if(edit_user->arrangeLog()) {
+      if(rda->user()->arrangeLog()) {
 	Save();
       }
       else {
@@ -254,7 +257,7 @@ void MainObject::DispatchCommand(QString cmd)
     }
 
     if(verb=="saveas") {
-      if(edit_user->arrangeLog()) {
+      if(rda->user()->arrangeLog()) {
 	if(cmds.size()==2) {
 	if(cmds[1].length()>64) {
 	  fprintf(stderr,"saveas: log name too long\n");
@@ -273,7 +276,7 @@ void MainObject::DispatchCommand(QString cmd)
     }
 
     if(verb=="setautorefresh") {
-      if(edit_user->arrangeLog()) {
+      if(rda->user()->arrangeLog()) {
 	if(cmds.size()==2) {
 	  QString arg=cmds[1].lower();
 	  if((arg=="yes")||(arg=="true")||(arg=="y")) {
@@ -300,7 +303,7 @@ void MainObject::DispatchCommand(QString cmd)
     }
 
     if(verb=="setcart") {
-      if(edit_user->arrangeLog()) {
+      if(rda->user()->arrangeLog()) {
 	if(cmds.size()==3) {
 	  line=cmds[1].toInt(&ok);
 	  if(ok&&(line>=0)&&(line<edit_log_event->size())) {
@@ -328,7 +331,7 @@ void MainObject::DispatchCommand(QString cmd)
     }
 
     if(verb=="setcomment") {
-      if(edit_user->arrangeLog()) {
+      if(rda->user()->arrangeLog()) {
 	if(cmds.size()>=3) {
 	  line=cmds[1].toInt(&ok);
 	  if(ok&&(line>=0)&&(line<edit_log_event->size())) {
@@ -352,7 +355,7 @@ void MainObject::DispatchCommand(QString cmd)
     }
 
     if(verb=="setdesc") {
-      if(edit_user->arrangeLog()) {
+      if(rda->user()->arrangeLog()) {
 	if(cmds.size()>=2) {
 	  cmds.erase(cmds.begin());
 	  Setdesc(cmds.join(" "));
@@ -369,7 +372,7 @@ void MainObject::DispatchCommand(QString cmd)
     }
 
     if(verb=="setenddate") {
-      if(edit_user->arrangeLog()) {
+      if(rda->user()->arrangeLog()) {
 	if(cmds.size()==1) {
 	  Setenddate(QDate());
 	}
@@ -396,7 +399,7 @@ void MainObject::DispatchCommand(QString cmd)
     }
 
     if(verb=="setlabel") {
-      if(edit_user->arrangeLog()) {
+      if(rda->user()->arrangeLog()) {
 	if(cmds.size()==3) {
 	  line=cmds[1].toInt(&ok);
 	  if(ok&&(line>=0)&&(line<edit_log_event->size())) {
@@ -418,7 +421,7 @@ void MainObject::DispatchCommand(QString cmd)
     }
 
     if(verb=="setpurgedate") {
-      if(edit_user->arrangeLog()) {
+      if(rda->user()->arrangeLog()) {
 	if(cmds.size()==1) {
 	  Setpurgedate(QDate());
 	}
@@ -445,7 +448,7 @@ void MainObject::DispatchCommand(QString cmd)
     }
 
     if(verb=="setservice") {
-      if(edit_user->arrangeLog()) {
+      if(rda->user()->arrangeLog()) {
 	if(cmds.size()==2) {
 	  Setservice(cmds[1]);
 	}
@@ -461,7 +464,7 @@ void MainObject::DispatchCommand(QString cmd)
     }
 
     if(verb=="setstartdate") {
-      if(edit_user->arrangeLog()) {
+      if(rda->user()->arrangeLog()) {
 	if(cmds.size()==1) {
 	  Setstartdate(QDate());
 	}
@@ -488,7 +491,7 @@ void MainObject::DispatchCommand(QString cmd)
     }
 
     if(verb=="settime") {
-      if(edit_user->arrangeLog()) {
+      if(rda->user()->arrangeLog()) {
 	if(cmds.size()>=3) {
 	  line=cmds[1].toInt(&ok);
 	  if(ok&&(line>=0)&&(line<edit_log_event->size())) {
@@ -502,7 +505,7 @@ void MainObject::DispatchCommand(QString cmd)
 	    switch(ttype) {
 	    case RDLogLine::Hard:
 	      if(cmds.size()>=4) {
-		time=RDGetWebTime(cmds[3],&ok);
+		time=RDParseXmlTime(cmds[3],&ok);
 		if(ok) {
 		  Settime(line,ttype,time);
 		}
@@ -540,7 +543,7 @@ void MainObject::DispatchCommand(QString cmd)
     }
 
     if(verb=="settrans") {
-      if(edit_user->arrangeLog()) {
+      if(rda->user()->arrangeLog()) {
 	if(cmds.size()==3) {
 	  line=cmds[1].toInt(&ok);
 	  if(ok&&(line>=0)&&(line<edit_log_event->size())) {
