@@ -2,9 +2,7 @@
 //
 // A Utility for running periodic system maintenance.
 //
-//   (C) Copyright 2008 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdmaint.h,v 1.6 2010/09/08 20:38:01 cvs Exp $
+//   (C) Copyright 2008,2016-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,25 +18,21 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-
 #ifndef RDMAINT_H
 #define RDMAINT_H
 
 #include <qobject.h>
-#include <qsqldatabase.h>
-
-#include <rdconfig.h>
-#include <rduser.h>
-#include <rdstation.h>
-#include <rdcmd_switch.h>
 
 #define RDMAINT_USAGE "[--help] [--verbose] [--system]\n\nRun Rivendell maintenance routines.\n"
 
-
 class MainObject : public QObject
 {
+  Q_OBJECT;
  public:
-  MainObject(QObject *parent=0,const char *name=0);
+  MainObject(QObject *parent=0);
+
+ private slots:
+  void userData();
 
  private:
   void RunSystemMaintenance();
@@ -47,12 +41,12 @@ class MainObject : public QObject
   void PurgeLogs();
   void PurgeElr();
   void PurgeDropboxes();
-  RDConfig *maint_config;
+  void PurgeGpioEvents();
+  void PurgeWebapiAuths();
+  void PurgeStacks();
+  void RehashCuts();
   bool maint_verbose;
   bool maint_system;
-  RDCmdSwitch *maint_cmd;
-  RDStation *maint_station;
-  RDUser *maint_user;
 };
 
 
