@@ -2,7 +2,7 @@
 //
 // A Utility to Purge Expired Podcasts.
 //
-//   (C) Copyright 2007,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2007,2016-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,65 +31,60 @@
 #include <qdir.h>
 
 #include <rd.h>
-#include <rdconf.h>
-#include <rdpurgecasts.h>
-#include <rdlibrary_conf.h>
-#include <rdescape_string.h>
 #include <rddb.h>
-#include <rdurl.h>
+#include <rdapplication.h>
+#include <rdconf.h>
+#include <rdescape_string.h>
 #include <rdfeed.h>
+#include <rdlibrary_conf.h>
 #include <rdpodcast.h>
+#include <rdurl.h>
 
+#include "rdpurgecasts.h"
 
 MainObject::MainObject(QObject *parent)
   :QObject(parent)
 {
   QString sql;
   RDSqlQuery *q;
-  unsigned schema=0;
+  QString err_msg;
 
   //
   // Initialize Data Structures
   //
   purge_verbose=false;
 
+  //
+  // Open the Database
+  //
+  rda=new RDApplication("rdpurgecasts","rdpurgecasts",RDPURGECASTS_USAGE,this);
+  if(!rda->open(&err_msg)) {
+    fprintf(stderr,"rdpurgecasts: %s\n",(const char *)err_msg);
+    exit(1);
+  }
+
   //
   // Read Command Options
   //
-  purge_cmd=new RDCmdSwitch(qApp->argc(),qApp->argv(),
-			     "rdpurgecasts",RDPURGECASTS_USAGE);
-  if(purge_cmd->keys()>2) {
+  if(rda->cmdSwitch()->keys()>2) {
     fprintf(stderr,"\n");
     fprintf(stderr,"%s",RDPURGECASTS_USAGE);
     fprintf(stderr,"\n");
-    delete purge_cmd;
     exit(256);
   }
-  for(unsigned i=0;i<purge_cmd->keys();i++) {
-    if(purge_cmd->key(i)=="--verbose") {
+  for(unsigned i=0;i<rda->cmdSwitch()->keys();i++) {
+    if(rda->cmdSwitch()->key(i)=="--verbose") {
       purge_verbose=true;
+      rda->cmdSwitch()->setProcessed(i,true);
+    }
+
+    if(!rda->cmdSwitch()->processed(i)) {
+      fprintf(stderr,"rdpurgecasts: unknown command option \"%s\"\n",
+	      (const char *)rda->cmdSwitch()->key(i));
+      exit(2);
     }
   }
 
-  //
-  // Read Configuration
-  //
-  purge_config=new RDConfig();
-  purge_config->load();
-  purge_config->setModuleName("rdpurgecasts");
-
-  //
-  // Open Database
-  //
-  QString err (tr("rdpurgecasts: "));
-  QSqlDatabase *db=RDInitDb(&schema,&err);
-  if(!db) {
-    fprintf(stderr,err.ascii());
-    delete purge_cmd;
-    exit(256);
-  }
-  delete purge_cmd;
-
   //
   // Scan Podcasts
   //
@@ -123,44 +118,47 @@ void MainObject::PurgeCast(unsigned id)
   RDPodcast *cast=NULL;
   QString errs;
 
-  sql=QString().sprintf("select FEEDS.ID,FEEDS.KEEP_METADATA,FEEDS.KEY_NAME \
-                         from PODCASTS left join FEEDS \
-                         on(PODCASTS.FEED_ID=FEEDS.ID) \
-                         where PODCASTS.ID=%u",id);
+  sql=QString("select ")+
+    "FEEDS.ID,"+             // 00
+    "FEEDS.KEEP_METADATA,"+  // 01
+    "FEEDS.KEY_NAME "+       // 02
+    "from PODCASTS left join FEEDS "+
+    "on(PODCASTS.FEED_ID=FEEDS.ID) where "+
+    QString().sprintf("PODCASTS.ID=%u",id);
   q=new RDSqlQuery(sql);
   while(q->next()) {
-    feed=new RDFeed(q->value(0).toUInt(),purge_config);
-    cast=new RDPodcast(purge_config,id);
-    cast->removeAudio(feed,&errs,purge_config->logXloadDebugData());
+    feed=new RDFeed(q->value(0).toUInt(),rda->config());
+    cast=new RDPodcast(rda->config(),id);
+    cast->removeAudio(feed,&errs,rda->config()->logXloadDebugData());
     if(purge_verbose) {
       printf("purging cast: ID=%d,cmd=\"%s\"\n",id,(const char *)cmd);
     }
     delete cast;
     delete feed;
     if(RDBool(q->value(1).toString())) {
-      sql=QString().sprintf("update PODCASTS set STATUS=%u \
-                             where ID=%u",
-			    RDPodcast::StatusExpired,id);
+      sql=QString("update PODCASTS set ")+
+	QString().sprintf("STATUS=%u where ",RDPodcast::StatusExpired)+
+	QString().sprintf("ID=%u",id);
       q1=new RDSqlQuery(sql);
       delete q1;
     }
     else {
-      QString keyname=q->value(2).toString();
-      keyname.replace(" ","_");
-      sql=QString().sprintf("delete from %s_FLG where CAST_ID=%d",
-			    (const char *)keyname,id);
+      sql=QString("delete from CAST_DOWNLOADS where ")+
+	"FEED_KEY_NAME=\""+RDEscapeString(q->value(2).toString())+"\" && "+
+	QString().sprintf("CAST_ID=%d",id);
       q1=new RDSqlQuery(sql);
       delete q1;
 
-      sql=QString().sprintf("delete from PODCASTS where ID=%d",id);
+      sql=QString("delete from PODCASTS where ")+
+	QString().sprintf("ID=%d",id);
       q1=new RDSqlQuery(sql);
       delete q1;
     }
-    sql=QString().sprintf("update FEEDS set LAST_BUILD_DATETIME=\"%s\" \
-                           where ID=%u",
-			  (const char *)current_datetime.
-			  toString("yyyy-MM-dd hh:mm:ss"),
-			  q->value(0).toUInt());
+    sql=QString("update FEEDS set ")+
+      "LAST_BUILD_DATETIME=\""+
+      RDEscapeString(current_datetime.toString("yyyy-MM-dd hh:mm:ss"))+
+      "\" where "+
+      QString().sprintf("ID=%u",q->value(0).toUInt());
     q1=new RDSqlQuery(sql);
     delete q1;
 
